.Icon-danger-epvdL {
  color: var(--dangerColor);
}

.Icon-default-ZpHc_ {
  color: inherit;
}

.Icon-disabled-cwrUJ {
  color: var(--disabledColor);
}

.Icon-info-GEXUJ {
  color: var(--infoColor);
}

.Icon-pink-xAGBW {
  color: var(--pink);
}

.Icon-success-J799D {
  color: var(--successColor);
}

.Icon-warning-wE4s6 {
  color: var(--warningColor);
}

.Icon-primary-f0nsY {
  color: var(--primaryColor);
}

.Icon-purple-roI8D {
  color: var(--purple);
}

.Link-link-RInnp {
  margin: 0;
  padding: 0;
  outline: none;
  border: 0;
  background: none;
  color: inherit;
  text-align: inherit;
  text-decoration: none;
  cursor: pointer;
}

  .Link-link-RInnp.isDisabled {
    cursor: default;
  }

.Link-to-kylTi {
  color: var(--linkColor);
}

.Link-to-kylTi:hover {
    color: var(--linkHoverColor);
    text-decoration: underline;
  }

.Link-link-RInnp {
  margin: 0;
  padding: 0;
  outline: none;
  border: 0;
  background: none;
  color: inherit;
  text-align: inherit;
  text-decoration: none;
  cursor: pointer;
}

  .Link-link-RInnp.isDisabled {
    cursor: default;
  }

.Link-to-kylTi {
  color: var(--linkColor);
}

.Link-to-kylTi:hover {
    color: var(--linkHoverColor);
    text-decoration: underline;
  }

.IconButton-button-t4C5V {

  display: inline-block;
  margin: 0 2px;
  width: 22px;
  border-radius: 4px;
  background-color: transparent;
  text-align: center;
  font-size: inherit;
}

  .IconButton-button-t4C5V:hover {
    border: none;
    background-color: inherit;
    color: var(--iconButtonHoverColor);
  }

  .IconButton-button-t4C5V.IconButton-isDisabled-qx70J {
    color: var(--iconButtonDisabledColor);
  }

.ErrorBoundaryError-container-u1Yk8 {
  text-align: center;
}

.ErrorBoundaryError-message-YnXdu {
  margin: 50px 0;
  text-align: center;
  font-weight: 300;
  font-size: 36px;
}

.ErrorBoundaryError-imageContainer-GMwwj {
  display: flex;
  justify-content: center;
  flex: 0 0 auto;
}

.ErrorBoundaryError-image-jfjKW {
  height: 350px;
}

.ErrorBoundaryError-details-c3TVO {
  margin: 20px;
  text-align: left;
  white-space: pre-wrap;
}

.ErrorBoundaryError-version-KXhFf {
  margin-top: 20px;
}

@media only screen and (max-width: 992px) {
  .ErrorBoundaryError-image-jfjKW {
    height: 250px;
  }
}

@media only screen and (max-width: 768px) {
  .ErrorBoundaryError-image-jfjKW {
    height: 150px;
  }
}

.Button-button-paJ9a {

  overflow: hidden;
  border: 1px solid;
  border-radius: 4px;
  vertical-align: middle;
  text-align: center;
  white-space: nowrap;
  line-height: normal;
}

  .Button-button-paJ9a.isDisabled {
    opacity: 0.65;
  }

  .Button-button-paJ9a:hover {
    text-decoration: none;
  }

.Button-danger-vthZW {
  border-color: var(--dangerBorderColor);
  background-color: var(--dangerBackgroundColor);
  color: var(--white);
}

.Button-danger-vthZW:hover {
    border-color: var(--dangerHoverBorderColor);
    background-color: var(--dangerHoverBackgroundColor);
    color: var(--white);
  }

.Button-default-UXlBi {
  border-color: var(--defaultBorderColor);
  background-color: var(--defaultBackgroundColor);
  color: var(--defaultColor);
}

.Button-default-UXlBi:hover {
    border-color: var(--defaultHoverBorderColor);
    background-color: var(--defaultHoverBackgroundColor);
    color: var(--defaultColor);
  }

.Button-primary-MZWFG {
  border-color: var(--primaryBorderColor);
  background-color: var(--primaryBackgroundColor);
  color: var(--white);
}

.Button-primary-MZWFG:hover {
    border-color: var(--primaryHoverBorderColor);
    background-color: var(--primaryHoverBackgroundColor);
    color: var(--white);
  }

.Button-success-MO1fp {
  border-color: var(--successBorderColor);
  background-color: var(--successBackgroundColor);
  color: var(--white);
}

.Button-success-MO1fp:hover {
    border-color: var(--successHoverBorderColor);
    background-color: var(--successHoverBackgroundColor);
    color: var(--white);
  }

.Button-warning-Ta5XG {
  border-color: var(--warningBorderColor);
  background-color: var(--warningBackgroundColor);
  color: var(--white);
}

.Button-warning-Ta5XG:hover {
    border-color: var(--warningHoverBorderColor);
    background-color: var(--warningHoverBackgroundColor);
    color: var(--white);
  }

/*
 * Sizes
 */

.Button-small-aExXc {
  padding: 1px 5px;
  font-size: 12px;
}

.Button-medium-ZwfFe {
  padding: 6px 16px;
  font-size: 14px;
}

.Button-large-W5TD4 {
  padding: 10px 20px;
  font-size: 16px;
}

/*
 * Sizes
*/

.Button-left-XRzO_ {
  margin-left: -1px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.Button-center-tF4Zr {
  margin-left: -1px;
  border-radius: 0;
}

.Button-right-zEjWk {
  margin-left: -1px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.Scroller-scroller-lhubq {
  scrollbar-color: var(--scrollbarBackgroundColor) transparent;
  scrollbar-width: thin;
}
  .Scroller-scroller-lhubq::-webkit-scrollbar {
    width: 10px;
    height: 10px;
  }
  .Scroller-scroller-lhubq::-webkit-scrollbar-track {
    background-color: transparent;
  }
  .Scroller-scroller-lhubq::-webkit-scrollbar-thumb {
    min-height: 100px;
    border: 1px solid transparent;
    border-radius: 5px;
    background-color: var(--scrollbarBackgroundColor);
    background-clip: padding-box;
  }
  .Scroller-scroller-lhubq::-webkit-scrollbar-thumb:hover {
      background-color: var(--scrollbarHoverBackgroundColor);
    }
  .Scroller-scroller-lhubq {
  -webkit-overflow-scrolling: touch;
}

.Scroller-none-lIEhI {
  overflow-x: hidden;
  overflow-y: hidden;
}

.Scroller-vertical-OLDmS {
  overflow-x: hidden;
  overflow-y: scroll;
}

.Scroller-vertical-OLDmS.Scroller-autoScroll-RVZ6m {
    overflow-y: auto;
  }

.Scroller-horizontal-Od7JK {
  overflow-x: scroll;
  overflow-y: hidden;
}

.Scroller-horizontal-Od7JK.Scroller-autoScroll-RVZ6m {
    overflow-x: auto;
  }

.Scroller-both-u6blh {
  overflow: scroll;
}

.Scroller-both-u6blh.Scroller-autoScroll-RVZ6m {
    overflow: auto;
  }

.ModalBody-modalBody-RVK6D {
  flex: 1 0 1px;
  padding: 30px;
}

.ModalBody-modalScroller-Oqq2l {
  flex-grow: 1;
}

.ModalBody-innerModalBody-XiTXT {
  padding: 30px;
}

.ModalContent-modalContent-bdTLe {
  position: relative;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  width: 100%;
  background-color: var(--modalBackgroundColor);
}

.ModalContent-closeButton-GYCdL {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  width: 60px;
  height: 60px;
  text-align: center;
  line-height: 60px;
}

.ModalContent-closeButton-GYCdL:hover {
    color: var(--modalCloseButtonHoverColor);
  }

.ModalFooter-modalFooter-wjkx5 {
  display: flex;
  align-items: center;
  justify-content: flex-end;
  flex-shrink: 0;
  padding: 15px 30px;
  border-top: 1px solid var(--borderColor);
}

  .ModalFooter-modalFooter-wjkx5 a,
  .ModalFooter-modalFooter-wjkx5 button {
    margin-left: 10px;
  }

  .ModalFooter-modalFooter-wjkx5 a:first-child, .ModalFooter-modalFooter-wjkx5 button:first-child {
      margin-left: 0;
    }

@media only screen and (max-width: 768px) {
  .ModalFooter-modalFooter-wjkx5 {
    padding: 15px;
  }
}

.ModalHeader-modalHeader-THPud {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex-shrink: 0;
  padding: 15px 50px 15px 30px;
  border-bottom: 1px solid var(--borderColor);
  font-size: 18px;
}

.ErrorBoundaryError-container-u1Yk8 {
  text-align: center;
}

.ErrorBoundaryError-message-YnXdu {
  margin: 50px 0;
  text-align: center;
  font-weight: 300;
  font-size: 36px;
}

.ErrorBoundaryError-imageContainer-GMwwj {
  display: flex;
  justify-content: center;
  flex: 0 0 auto;
}

.ErrorBoundaryError-image-jfjKW {
  height: 350px;
}

.ErrorBoundaryError-details-c3TVO {
  margin: 20px;
  text-align: left;
  white-space: pre-wrap;
}

.ErrorBoundaryError-version-KXhFf {
  margin-top: 20px;
}

@media only screen and (max-width: 992px) {
  .ErrorBoundaryError-image-jfjKW {
    height: 250px;
  }
}

@media only screen and (max-width: 768px) {
  .ErrorBoundaryError-image-jfjKW {
    height: 150px;
  }
}

.ModalError-message-HZzN5 {

  margin: 0;
  margin-bottom: 30px;
  font-weight: normal;
  font-size: 26px;
}

.ModalError-details-bpGAW {

  margin: 0;
  margin-top: 20px;
}

.Modal-modalContainer-xTUsI {
  position: absolute;
  top: 0;
  z-index: 1000;
  width: 100%;
  height: 100%;
}

.Modal-modalBackdrop-XqzNZ {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  background-color: var(--modalBackdropBackgroundColor);
  opacity: 1;
}

.Modal-modal-_3qBG {
  position: relative;
  display: flex;
  max-width: 90%;
  max-height: 90%;
  border-radius: 6px;
  opacity: 1;
}

.Modal-modalOpen-pzkAX {
  /* Prevent the body from scrolling when the modal is open */
  overflow: hidden !important;
}

.Modal-modalOpenIOS-_maM4 {
  position: fixed;
  right: 0;
  left: 0;
}

/*
 * Sizes
 */

.Modal-extraSmall-Xevz2 {

  width: 320px;
}

.Modal-small-oEjjG {

  width: 480px;
}

.Modal-medium-keEoF {

  width: 720px;
}

.Modal-large-EKpkE {

  width: 1080px;
}

.Modal-extraLarge-wEJo5 {

  width: 1280px;
}

.Modal-extraExtraLarge-NtrWr {

  width: 1600px;
}

@media only screen and (max-width: 1450px) {
  .Modal-modal-_3qBG.Modal-extraLarge-wEJo5 {
    width: 90%;
  }
}

@media only screen and (max-width: 1200px) {
  .Modal-modal-_3qBG.Modal-large-EKpkE {
    width: 90%;
  }
}

@media only screen and (max-width: 992px) {
  .Modal-modalContainer-xTUsI {
    position: fixed;
  }

  .Modal-modal-_3qBG.Modal-small-oEjjG,
  .Modal-modal-_3qBG.Modal-medium-keEoF,
  .Modal-modal-_3qBG.Modal-large-EKpkE,
  .Modal-modal-_3qBG.Modal-extraLarge-wEJo5,
  .Modal-modal-_3qBG.Modal-extraExtraLarge-NtrWr {
    max-height: 100%;
    width: 100%;
    height: 100% !important;
  }
}

.LoadingIndicator-loading-DWfav {
  margin-top: 20px;
  text-align: center;
}

.LoadingIndicator-rippleContainer-b3h1D {
  position: relative;
  display: inline-block;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(0) {
  animation-delay: -0.8s;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(1) {
  animation-delay: -0.6s;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(2) {
  animation-delay: -0.4s;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(3) {
  animation-delay: -0.2s;
}

.LoadingIndicator-ripple-Dn9J1 {
  position: absolute;
  border: 2px solid var(--themeDarkColor);
  border-radius: 100%;
  animation: LoadingIndicator-rippleContainer-b3h1D 1.25s 0s infinite cubic-bezier(0.21, 0.53, 0.56, 0.8);
  animation-fill-mode: both;
}

@keyframes LoadingIndicator-rippleContainer-b3h1D {
  0% {
    opacity: 1;
    transform: scale(0.1);
  }

  70% {
    opacity: 0.7;
    transform: scale(1);
  }

  100% {
    opacity: 0;
  }
}

.UpdateChanges-title-iaqWz {
  margin-top: 10px;
  font-size: 16px;
}

.AppUpdatedModalContent-version-FNMj4 {
  margin: 0 3px;
  font-weight: bold;
  font-family: var(--defaultFontFamily);
}

.AppUpdatedModalContent-maintenance-icjTi {
  margin-top: 20px;
}

.AppUpdatedModalContent-changes-pxSEa {
  margin-top: 20px;
  padding-bottom: 5px;
  border-bottom: 1px solid #e5e5e5;
  font-size: 18px;
}

.ConnectionLostModal-automatic-O5Z3a {
  margin-top: 20px;
}

.Alert-alert-_KgnQ {
  display: block;
  margin: 5px;
  padding: 15px;
  border: 1px solid transparent;
  border-radius: 4px;
}

.Alert-danger-nugZ_ {
  border-color: var(--alertDangerBorderColor);
  background-color: var(--alertDangerBackgroundColor);
  color: var(--alertDangerColor);
}

.Alert-info-BFcpa {
  border-color: var(--alertInfoBorderColor);
  background-color: var(--alertInfoBackgroundColor);
  color: var(--alertInfoColor);
}

.Alert-success-DPVBw {
  border-color: var(--alertSuccessBorderColor);
  background-color: var(--alertSuccessBackgroundColor);
  color: var(--alertSuccessColor);
}

.Alert-warning-K7oQl {
  border-color: var(--alertWarningBorderColor);
  background-color: var(--alertWarningBackgroundColor);
  color: var(--alertWarningColor);
}

.FormGroup-group-UkYsg {
  display: flex;
  margin-bottom: 20px;
}

/* Sizes */

.FormGroup-extraSmall-Xgs0f {
  max-width: 550px;
}

.FormGroup-small-cZTV8 {
  max-width: 650px;
}

.FormGroup-medium-HIpH5 {
  max-width: 800px;
}

.FormGroup-large-qJv2k {
  max-width: 1200px;
}

@media only screen and (max-width: 1200px) {
  .FormGroup-group-UkYsg {
    display: block;
  }
}

.Input-input-KWeec {
  padding: 6px 16px;
  width: 100%;
  height: 35px;
  border: 1px solid var(--inputBorderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
  box-shadow: inset 0 1px 1px var(--inputBoxShadowColor);
  color: var(--textColor);
}

  .Input-input-KWeec:focus {
    outline: 0;
    border-color: var(--inputFocusBorderColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor), 0 0 8px var(--inputFocusBoxShadowColor);
  }

.Input-hasError-_3DW5 {
  border-color: var(--inputErrorBorderColor);
  box-shadow: inset 0 1px 1px var(--inputBoxShadowColor), 0 0 8px var(--inputErrorBoxShadowColor);
}

.Input-hasWarning-K_6E_ {
  border-color: var(--inputWarningBorderColor);
  box-shadow: inset 0 1px 1px var(--inputBoxShadowColor), 0 0 8px var(--inputWarningBoxShadowColor);
}

.Input-hasButton-XcYCR {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.AutoSuggestInput-input-Irz_T {
}

.AutoSuggestInput-hasError-TzeMk {
}

.AutoSuggestInput-hasWarning-c6pm0 {
}

.AutoSuggestInput-inputContainer-MKwJ1 {
  flex-grow: 1;
}

.AutoSuggestInput-suggestionsContainer-IdHtU {
  scrollbar-color: var(--scrollbarBackgroundColor) transparent;
  scrollbar-width: thin;
}

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar {
    width: 10px;
    height: 10px;
  }

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar-track {
    background-color: transparent;
  }

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar-thumb {
    min-height: 100px;
    border: 1px solid transparent;
    border-radius: 5px;
    background-color: var(--scrollbarBackgroundColor);
    background-clip: padding-box;
  }

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar-thumb:hover {
      background-color: var(--scrollbarHoverBackgroundColor);
    }

.AutoSuggestInput-suggestionsContainerOpen-qrEjQ {
  z-index: 2000;
}

.AutoSuggestInput-suggestionsContainerOpen-qrEjQ .AutoSuggestInput-suggestionsContainer-IdHtU {
    overflow-y: auto;
    max-height: 200px;
    width: 100%;
    border: 1px solid var(--inputBorderColor);
    border-radius: 4px;
    background-color: var(--inputBackgroundColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor);
  }

.AutoSuggestInput-suggestionsList-Uq7sG {
  margin: 5px 0;
  padding-left: 0;
  max-height: 200px;
  list-style-type: none;
}

.AutoSuggestInput-suggestion-zjy1f {
  padding: 0 16px;
}

.AutoSuggestInput-suggestionHighlighted-KrGhN {
  background-color: var(--menuItemHoverBackgroundColor);
}

.Button-button-paJ9a {

  overflow: hidden;
  border: 1px solid;
  border-radius: 4px;
  vertical-align: middle;
  text-align: center;
  white-space: nowrap;
  line-height: normal;
}

  .Button-button-paJ9a.isDisabled {
    opacity: 0.65;
  }

  .Button-button-paJ9a:hover {
    text-decoration: none;
  }

.Button-danger-vthZW {
  border-color: var(--dangerBorderColor);
  background-color: var(--dangerBackgroundColor);
  color: var(--white);
}

.Button-danger-vthZW:hover {
    border-color: var(--dangerHoverBorderColor);
    background-color: var(--dangerHoverBackgroundColor);
    color: var(--white);
  }

.Button-default-UXlBi {
  border-color: var(--defaultBorderColor);
  background-color: var(--defaultBackgroundColor);
  color: var(--defaultColor);
}

.Button-default-UXlBi:hover {
    border-color: var(--defaultHoverBorderColor);
    background-color: var(--defaultHoverBackgroundColor);
    color: var(--defaultColor);
  }

.Button-primary-MZWFG {
  border-color: var(--primaryBorderColor);
  background-color: var(--primaryBackgroundColor);
  color: var(--white);
}

.Button-primary-MZWFG:hover {
    border-color: var(--primaryHoverBorderColor);
    background-color: var(--primaryHoverBackgroundColor);
    color: var(--white);
  }

.Button-success-MO1fp {
  border-color: var(--successBorderColor);
  background-color: var(--successBackgroundColor);
  color: var(--white);
}

.Button-success-MO1fp:hover {
    border-color: var(--successHoverBorderColor);
    background-color: var(--successHoverBackgroundColor);
    color: var(--white);
  }

.Button-warning-Ta5XG {
  border-color: var(--warningBorderColor);
  background-color: var(--warningBackgroundColor);
  color: var(--white);
}

.Button-warning-Ta5XG:hover {
    border-color: var(--warningHoverBorderColor);
    background-color: var(--warningHoverBackgroundColor);
    color: var(--white);
  }

/*
 * Sizes
 */

.Button-small-aExXc {
  padding: 1px 5px;
  font-size: 12px;
}

.Button-medium-ZwfFe {
  padding: 6px 16px;
  font-size: 14px;
}

.Button-large-W5TD4 {
  padding: 10px 20px;
  font-size: 16px;
}

/*
 * Sizes
*/

.Button-left-XRzO_ {
  margin-left: -1px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.Button-center-tF4Zr {
  margin-left: -1px;
  border-radius: 0;
}

.Button-right-zEjWk {
  margin-left: -1px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.SpinnerButton-button-uE9hL {

  position: relative;
}

.SpinnerButton-spinnerContainer-GOQ2V {
  position: absolute;
  top: 50%;
  left: -100%;
  display: inline-flex;
  visibility: hidden;
  transition: left 0.2s;
  transform: translateX(-50%) translateY(-50%);
}

.SpinnerButton-spinner-hbCOH {
  z-index: 1;
}

.SpinnerButton-label-YD8Ey {
  position: relative;
  left: 0;
  transition: left 0.2s, opacity 0.2s;
}

.SpinnerButton-isSpinning-DGQnw .SpinnerButton-spinnerContainer-GOQ2V {
    left: 50%;
    visibility: visible;
  }

.SpinnerButton-isSpinning-DGQnw .SpinnerButton-label-YD8Ey {
    left: 100%;
    visibility: hidden;
  }

.FormInputButton-button-qvTt5 {

  border-left: none;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.FormInputButton-middleButton-n2rOv {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.TextInput-input-svfXu {
}

.TextInput-readOnly-WH5Lg {
  background-color: var(--inputReadOnlyBackgroundColor);
}

.TextInput-hasError-Gbw0Q {
}

.TextInput-hasWarning-ZPiVp {
}

.TextInput-hasButton-Z1LGV {
}

.CaptchaInput-captchaInputWrapper-SGGbE {
  display: flex;
}

.CaptchaInput-input-hZojs {
}

.CaptchaInput-hasError-vrVc9 {
}

.CaptchaInput-hasWarning-gqCgC {
}

.CaptchaInput-hasButton-JL2W4 {
}

.CaptchaInput-recaptchaWrapper-edEg_ {
  margin-top: 10px;
}

.FormInputHelpText-helpText-Z2REp {
  margin-top: 5px;
  color: var(--helpTextColor);
  line-height: 20px;
}

.FormInputHelpText-isError-JjyAg {
  color: var(--dangerColor);
}

.FormInputHelpText-isError-JjyAg .FormInputHelpText-link-YQ2vD {
    color: var(--dangerColor);
  }

.FormInputHelpText-isError-JjyAg .FormInputHelpText-link-YQ2vD:hover {
      color: #e01313;
    }

.FormInputHelpText-isWarning-f3T6M {
  color: var(--warningColor);
}

.FormInputHelpText-isWarning-f3T6M .FormInputHelpText-link-YQ2vD {
    color: var(--warningColor);
  }

.FormInputHelpText-isWarning-f3T6M .FormInputHelpText-link-YQ2vD:hover {
      color: #e36c00;
    }

.FormInputHelpText-isCheckInput-zYt2f {
  padding-left: 30px;
}

.FormInputHelpText-link-YQ2vD {

  margin-left: 5px;
}

.FormInputHelpText-details-sqWRq {
  margin-left: 5px;
}

.FormInputHelpText-helpText-Z2REp {
  margin-top: 5px;
  color: var(--helpTextColor);
  line-height: 20px;
}

.FormInputHelpText-isError-JjyAg {
  color: var(--dangerColor);
}

.FormInputHelpText-isError-JjyAg .FormInputHelpText-link-YQ2vD {
    color: var(--dangerColor);
  }

.FormInputHelpText-isError-JjyAg .FormInputHelpText-link-YQ2vD:hover {
      color: #e01313;
    }

.FormInputHelpText-isWarning-f3T6M {
  color: var(--warningColor);
}

.FormInputHelpText-isWarning-f3T6M .FormInputHelpText-link-YQ2vD {
    color: var(--warningColor);
  }

.FormInputHelpText-isWarning-f3T6M .FormInputHelpText-link-YQ2vD:hover {
      color: #e36c00;
    }

.FormInputHelpText-isCheckInput-zYt2f {
  padding-left: 30px;
}

.FormInputHelpText-link-YQ2vD {

  margin-left: 5px;
}

.FormInputHelpText-details-sqWRq {
  margin-left: 5px;
}

.CheckInput-container-FXKYv {
  position: relative;
  display: flex;
  flex: 1 1 65%;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.CheckInput-label-JQ5QV {
  display: flex;
  margin-bottom: 0;
  min-height: 21px;
  font-weight: normal;
  cursor: pointer;
}

.CheckInput-checkbox-WEQ3S {
  position: absolute;
  opacity: 0;
  cursor: pointer;
  pointer-events: none;
}

.CheckInput-checkbox-WEQ3S.isDisabled {
    cursor: not-allowed;
  }

.CheckInput-input-VAM1T {
  flex: 1 0 auto;
  margin-top: 7px;
  margin-right: 5px;
  width: 20px;
  height: 20px;
  border: 1px solid #ccc;
  border-radius: 2px;
  background-color: var(--white);
  color: var(--white);
  text-align: center;
  line-height: 20px;
}

.CheckInput-checkbox-WEQ3S:focus + .CheckInput-input-VAM1T {
  outline: 0;
  border-color: var(--inputFocusBorderColor);
  box-shadow: inset 0 1px 1px var(--inputBoxShadowColor),
    0 0 8px var(--inputFocusBoxShadowColor);
}

.CheckInput-danger-NmIbW {
  border-color: var(--dangerColor);
  background-color: var(--dangerColor);
}

.CheckInput-danger-NmIbW.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-primary-SOm2w {
  border-color: var(--primaryColor);
  background-color: var(--primaryColor);
}

.CheckInput-primary-SOm2w.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-success-MqYT9 {
  border-color: var(--successColor);
  background-color: var(--successColor);
}

.CheckInput-success-MqYT9.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-warning-JHcsu {
  border-color: var(--warningColor);
  background-color: var(--warningColor);
}

.CheckInput-warning-JHcsu.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-isNotChecked-DeQ7b.CheckInput-isDisabled-DGdm7 {
    border-color: var(--disabledCheckInputColor);
    background-color: var(--disabledCheckInputColor);
    opacity: 0.7;
  }

.CheckInput-isIndeterminate-YIxOB {
  border-color: var(--gray);
  background-color: var(--gray);
}

.CheckInput-helpText-Cofbn {

  margin-top: 8px;
  margin-left: 5px;
}

.CheckInput-isDisabled-DGdm7 {
  cursor: not-allowed;
}

.KeyValueListInputItem-itemContainer-ZADcc {
  display: flex;
  margin-bottom: 3px;
  border-bottom: 1px solid var(--inputBorderColor);
}

  .KeyValueListInputItem-itemContainer-ZADcc:last-child {
    margin-bottom: 0;
    border-bottom: 0;
  }

.KeyValueListInputItem-keyInputWrapper-fZcHE {
  flex: 1 0 0;
}

.KeyValueListInputItem-valueInputWrapper-UxoQW {
  flex: 1 0 0;
  min-width: 40px;
}

.KeyValueListInputItem-buttonWrapper-URTxg {
  flex: 0 0 22px;
}

.KeyValueListInputItem-keyInput-Fwwg9,
.KeyValueListInputItem-valueInput-jTI0x {
  width: 100%;
  border: none;
  background-color: transparent;
  color: var(--textColor);
}

.KeyValueListInputItem-keyInput-Fwwg9::-moz-placeholder, .KeyValueListInputItem-valueInput-jTI0x::-moz-placeholder {
    color: var(--helpTextColor);
  }

.KeyValueListInputItem-keyInput-Fwwg9::placeholder, .KeyValueListInputItem-valueInput-jTI0x::placeholder {
    color: var(--helpTextColor);
  }

.KeyValueListInput-inputContainer-CTTl0 {

  position: relative;
  min-height: 35px;
  height: auto;
}

  .KeyValueListInput-inputContainer-CTTl0.KeyValueListInput-isFocused-FfsJJ {
    outline: 0;
    border-color: var(--inputFocusBorderColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor), 0 0 8px var(--inputFocusBoxShadowColor);
  }

.KeyValueListInput-hasError-ASy4m {
}

.KeyValueListInput-hasWarning-FACms {
}

.SpinnerButton-button-uE9hL {

  position: relative;
}

.SpinnerButton-spinnerContainer-GOQ2V {
  position: absolute;
  top: 50%;
  left: -100%;
  display: inline-flex;
  visibility: hidden;
  transition: left 0.2s;
  transform: translateX(-50%) translateY(-50%);
}

.SpinnerButton-spinner-hbCOH {
  z-index: 1;
}

.SpinnerButton-label-YD8Ey {
  position: relative;
  left: 0;
  transition: left 0.2s, opacity 0.2s;
}

.SpinnerButton-isSpinning-DGQnw .SpinnerButton-spinnerContainer-GOQ2V {
    left: 50%;
    visibility: visible;
  }

.SpinnerButton-isSpinning-DGQnw .SpinnerButton-label-YD8Ey {
    left: 100%;
    visibility: hidden;
  }

.SpinnerErrorButton-iconContainer-0zupp {
}

.SpinnerErrorButton-icon-QGBUe {
  z-index: 1;
}

.SpinnerErrorButton-label-BnsYP {
}

.SpinnerErrorButton-showIcon-ZPhkZ .SpinnerErrorButton-iconContainer-0zupp {
    left: 50%;
    visibility: visible;
  }

.SpinnerErrorButton-showIcon-ZPhkZ .SpinnerErrorButton-label-BnsYP {
    left: 100%;
    opacity: 0;
  }

.Form-validationFailures-wVc3a {
  margin-bottom: 20px;
}

.FormLabel-label-gwvhu {
  display: flex;
  justify-content: flex-end;
  margin-right: 20px;
  padding-top: 8px;
  min-height: 35px;
  text-align: end;
  font-weight: bold;
}

.FormLabel-hasError-Q3yuI {
  color: var(--dangerColor);
}

.FormLabel-isAdvanced-EuOsg {
  color: var(--advancedFormLabelColor);
}

@media only screen and (max-width: 1200px) {
  .FormLabel-label-gwvhu {
    justify-content: flex-start;
  }
}

.FormLabel-small-SkLXp {
  flex: 0 0 150px;
}

.FormLabel-large-KjVUJ {
  flex: 0 0 250px;
}

.TableOptionsColumn-column-Ek0f4 {
  display: flex;
  align-items: stretch;
  width: 100%;
  border: 1px solid #aaa;
  border-radius: 4px;
  background: var(--inputBackgroundColor);
}

.TableOptionsColumn-checkContainer-y0Oh2 {
  position: relative;
  margin-right: 4px;
  margin-bottom: 7px;
  margin-left: 8px;
}

.TableOptionsColumn-label-Dye87 {
  display: flex;
  flex-grow: 1;
  margin-bottom: 0;
  margin-left: 2px;
  font-weight: normal;
  line-height: 36px;
  cursor: pointer;
}

.TableOptionsColumn-dragHandle-LrZSw {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-left: auto;
  width: 40px;
  text-align: center;
  cursor: grab;
}

.TableOptionsColumn-dragIcon-sjJF_ {
  top: 0;
}

.TableOptionsColumn-isDragging-Zz7RX {
  opacity: 0.25;
}

.TableOptionsColumn-notDragable-nSG4k {
  padding: 4px 0;
}

.DragPreviewLayer-dragLayer-lJxaW {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 9999;
  width: 100%;
  height: 100%;
  pointer-events: none;
}

.TableOptionsColumnDragPreview-dragPreview-rMhuQ {
  width: 380px;
  opacity: 0.75;
}

.TableOptionsColumnDragSource-columnDragSource-AJsPg {
  padding: 4px 0;
}

.TableOptionsColumnDragSource-columnPlaceholder-CGz6l {
  width: 100%;
  height: 36px;
  border: 1px dotted #aaa;
  border-radius: 4px;
}

.TableOptionsColumnDragSource-columnPlaceholderBefore-O5xwl {
  margin-bottom: 8px;
}

.TableOptionsColumnDragSource-columnPlaceholderAfter-rdEel {
  margin-top: 8px;
}

.TableOptionsModal-columns-PtB2N {
  margin-top: 10px;
  width: 100%;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.TableHeaderCell-headerCell-aJDuw {
  padding: 8px;
  border: none !important;
  text-align: left;
  font-weight: bold;
}

.TableHeaderCell-sortIcon-zaT8O {
  margin-left: 10px;
}

@media only screen and (max-width: 992px) {
  .TableHeaderCell-headerCell-aJDuw {
    white-space: nowrap;
  }
}

.VirtualTableHeaderCell-headerCell-oq_lz {
  padding: 8px;
  border: none !important;
  text-align: left;
  font-weight: bold;
}

.VirtualTableHeaderCell-sortIcon-IdM2s {
  margin-left: 10px;
}

@media only screen and (max-width: 992px) {
  .VirtualTableHeaderCell-headerCell-oq_lz {
    white-space: nowrap;
  }
}

.CheckInput-container-FXKYv {
  position: relative;
  display: flex;
  flex: 1 1 65%;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.CheckInput-label-JQ5QV {
  display: flex;
  margin-bottom: 0;
  min-height: 21px;
  font-weight: normal;
  cursor: pointer;
}

.CheckInput-checkbox-WEQ3S {
  position: absolute;
  opacity: 0;
  cursor: pointer;
  pointer-events: none;
}

.CheckInput-checkbox-WEQ3S.isDisabled {
    cursor: not-allowed;
  }

.CheckInput-input-VAM1T {
  flex: 1 0 auto;
  margin-top: 7px;
  margin-right: 5px;
  width: 20px;
  height: 20px;
  border: 1px solid #ccc;
  border-radius: 2px;
  background-color: var(--white);
  color: var(--white);
  text-align: center;
  line-height: 20px;
}

.CheckInput-checkbox-WEQ3S:focus + .CheckInput-input-VAM1T {
  outline: 0;
  border-color: var(--inputFocusBorderColor);
  box-shadow: inset 0 1px 1px var(--inputBoxShadowColor),
    0 0 8px var(--inputFocusBoxShadowColor);
}

.CheckInput-danger-NmIbW {
  border-color: var(--dangerColor);
  background-color: var(--dangerColor);
}

.CheckInput-danger-NmIbW.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-primary-SOm2w {
  border-color: var(--primaryColor);
  background-color: var(--primaryColor);
}

.CheckInput-primary-SOm2w.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-success-MqYT9 {
  border-color: var(--successColor);
  background-color: var(--successColor);
}

.CheckInput-success-MqYT9.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-warning-JHcsu {
  border-color: var(--warningColor);
  background-color: var(--warningColor);
}

.CheckInput-warning-JHcsu.CheckInput-isDisabled-DGdm7 {
    opacity: 0.7;
  }

.CheckInput-isNotChecked-DeQ7b.CheckInput-isDisabled-DGdm7 {
    border-color: var(--disabledCheckInputColor);
    background-color: var(--disabledCheckInputColor);
    opacity: 0.7;
  }

.CheckInput-isIndeterminate-YIxOB {
  border-color: var(--gray);
  background-color: var(--gray);
}

.CheckInput-helpText-Cofbn {

  margin-top: 8px;
  margin-left: 5px;
}

.CheckInput-isDisabled-DGdm7 {
  cursor: not-allowed;
}

.TableSelectAllHeaderCell-selectAllHeaderCell-jSJyZ {

  width: 30px;
}

.TableSelectAllHeaderCell-input-UDHSn {

  margin: 0;
}

.Table-tableContainer-QgrKY.Table-horizontalScroll-pEqaG {
    overflow-x: auto;
  }

.Table-table-uAtH3 {
  max-width: 100%;
  width: 100%;
  border-collapse: collapse;
}

@media only screen and (max-width: 992px) {
  .Table-tableContainer-QgrKY {
    min-width: 100%;
    width: -moz-fit-content;
    width: fit-content;
  }

    .Table-tableContainer-QgrKY.Table-horizontalScroll-pEqaG {
      overflow-y: hidden;
      width: 100%;
    }
}

.TableRowCell-cell-giPrj {
  padding: 8px;
  border-top: 1px solid var(--borderColor);
  line-height: 1.52857143;
}

@media only screen and (max-width: 992px) {
  .TableRowCell-cell-giPrj {
    white-space: nowrap;
  }
}

.TableRow-row-lgbLy {
  transition: background-color 500ms;
}

  .TableRow-row-lgbLy:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

.TableRow-row-lgbLy {
  transition: background-color 500ms;
}

  .TableRow-row-lgbLy:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

.TableRowButton-row-dh_T6 {
}

.TableRowCell-cell-giPrj {
  padding: 8px;
  border-top: 1px solid var(--borderColor);
  line-height: 1.52857143;
}

@media only screen and (max-width: 992px) {
  .TableRowCell-cell-giPrj {
    white-space: nowrap;
  }
}

.FileBrowserRow-type-WduSE {

  width: 32px;
}

.ModalBody-modalBody-RVK6D {
  flex: 1 0 1px;
  padding: 30px;
}

.ModalBody-modalScroller-Oqq2l {
  flex-grow: 1;
}

.ModalBody-innerModalBody-XiTXT {
  padding: 30px;
}

.Alert-alert-_KgnQ {
  display: block;
  margin: 5px;
  padding: 15px;
  border: 1px solid transparent;
  border-radius: 4px;
}

.Alert-danger-nugZ_ {
  border-color: var(--alertDangerBorderColor);
  background-color: var(--alertDangerBackgroundColor);
  color: var(--alertDangerColor);
}

.Alert-info-BFcpa {
  border-color: var(--alertInfoBorderColor);
  background-color: var(--alertInfoBackgroundColor);
  color: var(--alertInfoColor);
}

.Alert-success-DPVBw {
  border-color: var(--alertSuccessBorderColor);
  background-color: var(--alertSuccessBackgroundColor);
  color: var(--alertSuccessColor);
}

.Alert-warning-K7oQl {
  border-color: var(--alertWarningBorderColor);
  background-color: var(--alertWarningBackgroundColor);
  color: var(--alertWarningColor);
}

.AutoSuggestInput-input-Irz_T {
}

.AutoSuggestInput-hasError-TzeMk {
}

.AutoSuggestInput-hasWarning-c6pm0 {
}

.AutoSuggestInput-inputContainer-MKwJ1 {
  flex-grow: 1;
}

.AutoSuggestInput-suggestionsContainer-IdHtU {
  scrollbar-color: var(--scrollbarBackgroundColor) transparent;
  scrollbar-width: thin;
}

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar {
    width: 10px;
    height: 10px;
  }

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar-track {
    background-color: transparent;
  }

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar-thumb {
    min-height: 100px;
    border: 1px solid transparent;
    border-radius: 5px;
    background-color: var(--scrollbarBackgroundColor);
    background-clip: padding-box;
  }

.AutoSuggestInput-suggestionsContainer-IdHtU::-webkit-scrollbar-thumb:hover {
      background-color: var(--scrollbarHoverBackgroundColor);
    }

.AutoSuggestInput-suggestionsContainerOpen-qrEjQ {
  z-index: 2000;
}

.AutoSuggestInput-suggestionsContainerOpen-qrEjQ .AutoSuggestInput-suggestionsContainer-IdHtU {
    overflow-y: auto;
    max-height: 200px;
    width: 100%;
    border: 1px solid var(--inputBorderColor);
    border-radius: 4px;
    background-color: var(--inputBackgroundColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor);
  }

.AutoSuggestInput-suggestionsList-Uq7sG {
  margin: 5px 0;
  padding-left: 0;
  max-height: 200px;
  list-style-type: none;
}

.AutoSuggestInput-suggestion-zjy1f {
  padding: 0 16px;
}

.AutoSuggestInput-suggestionHighlighted-KrGhN {
  background-color: var(--menuItemHoverBackgroundColor);
}

.FormInputButton-button-qvTt5 {

  border-left: none;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.FormInputButton-middleButton-n2rOv {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.PathInput-hasFileBrowser-EHxWx {
}

.PathInput-inputWrapper-tZDyS {
  display: flex;
}

.PathInput-pathMatch-zp2Sr {
  font-weight: bold;
}

.PathInput-fileBrowserButton-Zi80W {

  height: 35px;
}

.PathInput-fileBrowserMiddleButton-SEN7j {
}

.FileBrowserModalContent-modalBody-kXPlo {

  display: flex;
  flex-direction: column;
}

.FileBrowserModalContent-mappedDrivesWarning-Mu33l {

  margin: 0;
  margin-bottom: 20px;
}

.FileBrowserModalContent-faqLink-M0Z1P {
  color: var(--alertWarningColor);
  font-weight: bold;
}

.FileBrowserModalContent-pathInput-niMXM {

  flex: 0 0 auto;
}

.FileBrowserModalContent-scroller-KsfcP {
  margin-top: 20px;
}

.FileBrowserModalContent-loading-qSfj8 {
  display: inline-block;
  margin-right: auto;
}

.Modal-modalContainer-xTUsI {
  position: absolute;
  top: 0;
  z-index: 1000;
  width: 100%;
  height: 100%;
}

.Modal-modalBackdrop-XqzNZ {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  background-color: var(--modalBackdropBackgroundColor);
  opacity: 1;
}

.Modal-modal-_3qBG {
  position: relative;
  display: flex;
  max-width: 90%;
  max-height: 90%;
  border-radius: 6px;
  opacity: 1;
}

.Modal-modalOpen-pzkAX {
  /* Prevent the body from scrolling when the modal is open */
  overflow: hidden !important;
}

.Modal-modalOpenIOS-_maM4 {
  position: fixed;
  right: 0;
  left: 0;
}

/*
 * Sizes
 */

.Modal-extraSmall-Xevz2 {

  width: 320px;
}

.Modal-small-oEjjG {

  width: 480px;
}

.Modal-medium-keEoF {

  width: 720px;
}

.Modal-large-EKpkE {

  width: 1080px;
}

.Modal-extraLarge-wEJo5 {

  width: 1280px;
}

.Modal-extraExtraLarge-NtrWr {

  width: 1600px;
}

@media only screen and (max-width: 1450px) {
  .Modal-modal-_3qBG.Modal-extraLarge-wEJo5 {
    width: 90%;
  }
}

@media only screen and (max-width: 1200px) {
  .Modal-modal-_3qBG.Modal-large-EKpkE {
    width: 90%;
  }
}

@media only screen and (max-width: 992px) {
  .Modal-modalContainer-xTUsI {
    position: fixed;
  }

  .Modal-modal-_3qBG.Modal-small-oEjjG,
  .Modal-modal-_3qBG.Modal-medium-keEoF,
  .Modal-modal-_3qBG.Modal-large-EKpkE,
  .Modal-modal-_3qBG.Modal-extraLarge-wEJo5,
  .Modal-modal-_3qBG.Modal-extraExtraLarge-NtrWr {
    max-height: 100%;
    width: 100%;
    height: 100% !important;
  }
}

.FileBrowserModal-modal-XB8yQ {

  height: 600px;
}

.PathInput-hasFileBrowser-EHxWx {
}

.PathInput-inputWrapper-tZDyS {
  display: flex;
}

.PathInput-pathMatch-zp2Sr {
  font-weight: bold;
}

.PathInput-fileBrowserButton-Zi80W {

  height: 35px;
}

.PathInput-fileBrowserMiddleButton-SEN7j {
}

.EnhancedSelectInputOption-option-VZhzN {
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 5px 10px;
  width: 100%;
  cursor: default;
}

  .EnhancedSelectInputOption-option-VZhzN:hover {
    background-color: var(--inputHoverBackgroundColor);
  }

  .EnhancedSelectInputOption-option-VZhzN.EnhancedSelectInputOption-isDisabled-yjAjV {
    cursor: not-allowed;
  }

.EnhancedSelectInputOption-optionCheck-H1VE8 {

  flex: 0 0 0;
}

.EnhancedSelectInputOption-optionCheckInput-hLn9q {

  margin-top: 0;
}

.EnhancedSelectInputOption-isSelected-cltSy {
  background-color: var(--inputSelectedBackgroundColor);
}

.EnhancedSelectInputOption-isSelected-cltSy:hover {
    background-color: var(--inputSelectedBackgroundColor);
  }

.EnhancedSelectInputOption-isSelected-cltSy.EnhancedSelectInputOption-isMobile-Ue97s {
    background-color: inherit;
  }

.EnhancedSelectInputOption-isSelected-cltSy.EnhancedSelectInputOption-isMobile-Ue97s .EnhancedSelectInputOption-iconContainer-M2HTL {
      color: var(--primaryColor);
    }

.EnhancedSelectInputOption-isDisabled-yjAjV {
  background-color: #aaa;
}

.EnhancedSelectInputOption-isHidden-DRQ_I {
  display: none;
}

.EnhancedSelectInputOption-isMobile-Ue97s {
  height: 50px;
  border-bottom: 1px solid var(--borderColor);
}

.EnhancedSelectInputOption-isMobile-Ue97s:last-child {
    border: none;
  }

.EnhancedSelectInputOption-isMobile-Ue97s:hover {
    background-color: unset;
  }

.HintedSelectInputOption-optionText-X0Jgb {
  display: flex;
  align-items: center;
  justify-content: space-between;
  flex: 1 0 0;
  min-width: 0;
}

  .HintedSelectInputOption-optionText-X0Jgb.HintedSelectInputOption-isMobile-Z0naC {
    display: block;
  }

  .HintedSelectInputOption-optionText-X0Jgb.HintedSelectInputOption-isMobile-Z0naC .HintedSelectInputOption-hintText-U49D1 {
      margin-left: 0;
    }

.HintedSelectInputOption-hintText-U49D1 {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-left: 15px;
  color: var(--darkGray);
  font-size: 12px;
}

.HintedSelectInputOption-divider-OWEa8 {
  border: none;
  border-bottom: 1px solid var(--lightGray);
}

.Label-label-DYldh {
  display: inline-block;
  margin: 2px;
  border: 1px solid;
  border-radius: 2px;
  color: var(--white);
  text-align: center;
  white-space: nowrap;
  line-height: 1;
  cursor: default;
}

/** Kinds **/

.Label-danger-NLIVv {
  border-color: var(--dangerColor);
  background-color: var(--dangerColor);
}

.Label-danger-NLIVv.Label-outline-Xn6SE {
    color: var(--dangerColor);
  }

.Label-danger-NLIVv.colorImpaired {
    background: repeating-linear-gradient(90deg, color(var(--dangerColor) shade(5%)), color(var(--dangerColor) shade(5%)) 5px, color(var(--dangerColor) shade(15%)) 5px, color(var(--dangerColor) shade(15%)) 10px);
  }

.Label-default-PeYXO {
  border-color: var(--themeLightColor);
  background-color: var(--themeLightColor);
}

.Label-default-PeYXO.Label-outline-Xn6SE {
    color: var(--themeLightColor);
  }

.Label-disabled-zzPjC {
  border-color: var(--disabledColor);
  background-color: var(--disabledColor);
}

.Label-disabled-zzPjC.Label-outline-Xn6SE {
    color: var(--offWhite);
  }

.Label-info-QWFsu {
  border-color: var(--infoColor);
  background-color: var(--infoColor);
  color: var(--infoTextColor);
}

.Label-info-QWFsu.Label-outline-Xn6SE {
    color: var(--infoColor);
  }

.Label-inverse-gByCz {
  border-color: var(--inverseLabelColor);
  background-color: var(--inverseLabelColor);
  color: var(--inverseLabelTextColor);
}

.Label-inverse-gByCz.Label-outline-Xn6SE {
    background-color: var(--inverseLabelTextColor) !important;
    color: var(--inverseLabelColor);
  }

.Label-primary-oG9By {
  border-color: var(--primaryColor);
  background-color: var(--primaryColor);
}

.Label-primary-oG9By.Label-outline-Xn6SE {
    color: var(--primaryColor);
  }

.Label-success-KHmdj {
  border-color: var(--successColor);
  background-color: var(--successColor);
  color: #eee;
}

.Label-success-KHmdj.Label-outline-Xn6SE {
    color: var(--successColor);
  }

.Label-warning-UhdwP {
  border-color: var(--warningColor);
  background-color: var(--warningColor);
}

.Label-warning-UhdwP.Label-outline-Xn6SE {
    color: var(--warningColor);
  }

.Label-warning-UhdwP.colorImpaired {
    background: repeating-linear-gradient(45deg, var(--warningColor), var(--warningColor) 5px, color(var(--warningColor) tint(15%)) 5px, color(var(--warningColor) tint(15%)) 10px);
  }

.Label-queue-aakku {
  border-color: var(--queueColor);
  background-color: var(--queueColor);
}

.Label-queue-aakku.Label-outline-Xn6SE {
    color: var(--queueColor);
  }

/** Sizes **/

.Label-small-DLxDw {
  padding: 1px 3px;
  font-size: 11px;
}

.Label-medium-Vxy3t {
  padding: 2px 5px;
  font-size: 12px;
}

.Label-large-qZ9AP {
  padding: 3px 7px;
  font-weight: bold;
  font-size: 14px;
}

/** Outline **/

.Label-outline-Xn6SE {
  background-color: var(--disabledLabelColor);
}

.EnhancedSelectInputSelectedValue-selectedValue-wuC2J {
  flex: 1 1 auto;
}

.EnhancedSelectInputSelectedValue-isDisabled-T9spS {
  color: var(--disabledInputColor);
}

.EnhancedSelectInputSelectedValue-selectedValue-wuC2J {
  flex: 1 1 auto;
}

.EnhancedSelectInputSelectedValue-isDisabled-T9spS {
  color: var(--disabledInputColor);
}

.HintedSelectInputSelectedValue-selectedValue-ys8w8 {

  display: flex;
  align-items: center;
  justify-content: space-between;
  overflow: hidden;
}

.HintedSelectInputSelectedValue-valueText-RqVEn {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 0 0 auto;
}

.HintedSelectInputSelectedValue-hintText-GmPCH {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 1 10 0;
  margin-left: 15px;
  color: var(--gray);
  text-align: right;
  font-size: 12px;
}

.Scroller-scroller-lhubq {
  scrollbar-color: var(--scrollbarBackgroundColor) transparent;
  scrollbar-width: thin;
}
  .Scroller-scroller-lhubq::-webkit-scrollbar {
    width: 10px;
    height: 10px;
  }
  .Scroller-scroller-lhubq::-webkit-scrollbar-track {
    background-color: transparent;
  }
  .Scroller-scroller-lhubq::-webkit-scrollbar-thumb {
    min-height: 100px;
    border: 1px solid transparent;
    border-radius: 5px;
    background-color: var(--scrollbarBackgroundColor);
    background-clip: padding-box;
  }
  .Scroller-scroller-lhubq::-webkit-scrollbar-thumb:hover {
      background-color: var(--scrollbarHoverBackgroundColor);
    }
  .Scroller-scroller-lhubq {
  -webkit-overflow-scrolling: touch;
}

.Scroller-none-lIEhI {
  overflow-x: hidden;
  overflow-y: hidden;
}

.Scroller-vertical-OLDmS {
  overflow-x: hidden;
  overflow-y: scroll;
}

.Scroller-vertical-OLDmS.Scroller-autoScroll-RVZ6m {
    overflow-y: auto;
  }

.Scroller-horizontal-Od7JK {
  overflow-x: scroll;
  overflow-y: hidden;
}

.Scroller-horizontal-Od7JK.Scroller-autoScroll-RVZ6m {
    overflow-x: auto;
  }

.Scroller-both-u6blh {
  overflow: scroll;
}

.Scroller-both-u6blh.Scroller-autoScroll-RVZ6m {
    overflow: auto;
  }

.EnhancedSelectInput-enhancedSelect-U5iFw {

  display: flex;
  align-items: center;
}

.EnhancedSelectInput-editableContainer-zePNM {
  width: 100%;
}

.EnhancedSelectInput-hasError-ucMeh {
}

.EnhancedSelectInput-hasWarning-k1HjT {
}

.EnhancedSelectInput-isDisabled-UxRuC {
  opacity: 0.7;
  cursor: not-allowed !important;
}

.EnhancedSelectInput-dropdownArrowContainer-UtiTt {
  margin-left: 12px;
}

.EnhancedSelectInput-dropdownArrowContainerEditable-m3w_n {
  position: absolute;
  top: 0;
  right: 0;
  padding-right: 17px;
  width: 30%;
  height: 35px;
  text-align: right;
}

.EnhancedSelectInput-dropdownArrowContainerDisabled-D1tHz {

  color: var(--disabledInputColor);
}

.EnhancedSelectInput-optionsContainer-SohjR {
  z-index: 2000;
  width: auto;
}

.EnhancedSelectInput-options-srgXq {

  border: 1px solid var(--inputBorderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
}

.EnhancedSelectInput-optionsModal-Dq0Iv {
  display: flex;
  justify-content: center;
  max-width: 90%;
  max-height: 100%;
  width: 350px !important;
  height: auto !important;
}

.EnhancedSelectInput-optionsModalBody-iknpF {

  display: flex;
  justify-content: center;
  flex-direction: column;
  padding: 10px 0;
}

.EnhancedSelectInput-optionsInnerModalBody-MOrRm {

  padding: 0;
}

.EnhancedSelectInput-optionsModalScroller-HbbSI {

  border: 1px solid var(--inputBorderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
}

.EnhancedSelectInput-loading-HUcfB {
  display: inline-block;
  margin: 5px -5px 5px 0;
}

.EnhancedSelectInput-mobileCloseButtonContainer-i1KT8 {
  display: flex;
  justify-content: flex-end;
  height: 40px;
  border-bottom: 1px solid var(--borderColor);
}

.EnhancedSelectInput-mobileCloseButton-NyrHK {
  width: 40px;
  height: 40px;
  text-align: center;
  line-height: 40px;
}

.EnhancedSelectInput-mobileCloseButton-NyrHK:hover {
    color: var(--modalCloseButtonHoverColor);
  }

.RootFolderSelectInputOption-optionText-OQJPI {
  display: flex;
  align-items: center;
  justify-content: space-between;
  flex: 1 0 0;
}

  .RootFolderSelectInputOption-optionText-OQJPI.RootFolderSelectInputOption-isMobile-pJarV {
    display: block;
  }

  .RootFolderSelectInputOption-optionText-OQJPI.RootFolderSelectInputOption-isMobile-pJarV .RootFolderSelectInputOption-freeSpace-CgOKC {
      margin-left: 0;
    }

.RootFolderSelectInputOption-value-IhVgu {
  display: flex;
  max-width: 500px;
}

.RootFolderSelectInputOption-movieFolder-tWALW {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  color: var(--disabledColor);
}

.RootFolderSelectInputOption-freeSpace-CgOKC {
  margin-left: 15px;
  color: var(--darkGray);
  font-size: 12px;
}

.RootFolderSelectInputOption-isMissing-xemut {
  margin-left: 15px;
  color: var(--dangerColor);
  font-size: 12px;
}

.RootFolderSelectInputSelectedValue-selectedValue-l8ie2 {

  display: flex;
  align-items: center;
  justify-content: space-between;
  overflow: hidden;
}

.RootFolderSelectInputSelectedValue-pathContainer-A8LPA {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
  display: flex;
  flex: 1 0 0;
}

.RootFolderSelectInputSelectedValue-path-eafF_ {
  flex: 0 1 auto;
}

.RootFolderSelectInputSelectedValue-movieFolder-NnXMi {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
  flex: 0 1 auto;
  color: var(--disabledColor);
}

.RootFolderSelectInputSelectedValue-freeSpace-wZd2e {
  flex: 0 0 auto;
  margin-left: 15px;
  color: var(--gray);
  text-align: right;
  font-size: 12px;
}

.RootFolderSelectInputSelectedValue-isMissing-NpWGZ {
  flex: 0 0 auto;
  margin-left: 15px;
  color: var(--dangerColor);
  text-align: right;
  font-size: 12px;
}

.FormInputGroup-inputGroupContainer-YhfqJ {
  flex: 1 1 auto;
  min-width: 0;
}

.FormInputGroup-inputGroup-Yqmkv {
  display: flex;
  flex: 1 1 auto;
  flex-wrap: wrap;
}

.FormInputGroup-inputContainer-yauGG {
  position: relative;
  flex: 1 1 auto;
  min-width: 0;
}

.FormInputGroup-inputUnit-rRSCN {
  position: absolute;
  top: 0;
  right: 20px;
  margin-top: 7px;
  width: 75px;
  color: #c6c6c6;
  text-align: right;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.FormInputGroup-inputUnitNumber-oqRfn {

  right: 40px;
}

.FormInputGroup-pendingChangesContainer-BLt9I {
  display: flex;
  justify-content: flex-end;
  width: 30px;
}

.FormInputGroup-pendingChangesIcon-XrqHM {
  color: var(--warningColor);
  font-size: 20px;
  line-height: 35px;
}

.FormInputGroup-helpLink-uIwQR {
  margin-top: 5px;
  line-height: 20px;
}

.UMaskInput-inputWrapper-gZAUR {
  display: flex;
}

.UMaskInput-inputFolder-SoLdd {

  max-width: 100px;
}

.UMaskInput-inputUnitWrapper-Zz_gQ {
  position: relative;
  width: 100%;
}

.UMaskInput-inputUnit-YN1WR {

  right: 40px;
  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.UMaskInput-unit-i6iil {
  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.UMaskInput-details-_aggk {
  margin-top: 5px;
  margin-left: 17px;
  line-height: 20px;
}

.UMaskInput-details-_aggk > div {
    display: flex;
  }

.UMaskInput-details-_aggk > div label {
      flex: 0 0 50px;
    }

.UMaskInput-details-_aggk > div .UMaskInput-value-ptfG9 {
      width: 50px;
      text-align: right;
    }

.UMaskInput-details-_aggk > div .UMaskInput-unit-i6iil {
      width: 90px;
      text-align: right;
    }

.UMaskInput-readOnly-JD3zT {
  background-color: var(--inputReadOnlyBackgroundColor);
}

.TagInputInput-inputContainer-VMO2U {
  inset: -1px;
  display: flex;
  align-items: start;
  flex-wrap: wrap;
  padding: 1px 16px;
  min-height: 33px;
  cursor: default;
}

.IconButton-button-t4C5V {

  display: inline-block;
  margin: 0 2px;
  width: 22px;
  border-radius: 4px;
  background-color: transparent;
  text-align: center;
  font-size: inherit;
}

  .IconButton-button-t4C5V:hover {
    border: none;
    background-color: inherit;
    color: var(--iconButtonHoverColor);
  }

  .IconButton-button-t4C5V.IconButton-isDisabled-qx70J {
    color: var(--iconButtonDisabledColor);
  }

.Label-label-DYldh {
  display: inline-block;
  margin: 2px;
  border: 1px solid;
  border-radius: 2px;
  color: var(--white);
  text-align: center;
  white-space: nowrap;
  line-height: 1;
  cursor: default;
}

/** Kinds **/

.Label-danger-NLIVv {
  border-color: var(--dangerColor);
  background-color: var(--dangerColor);
}

.Label-danger-NLIVv.Label-outline-Xn6SE {
    color: var(--dangerColor);
  }

.Label-danger-NLIVv.colorImpaired {
    background: repeating-linear-gradient(90deg, color(var(--dangerColor) shade(5%)), color(var(--dangerColor) shade(5%)) 5px, color(var(--dangerColor) shade(15%)) 5px, color(var(--dangerColor) shade(15%)) 10px);
  }

.Label-default-PeYXO {
  border-color: var(--themeLightColor);
  background-color: var(--themeLightColor);
}

.Label-default-PeYXO.Label-outline-Xn6SE {
    color: var(--themeLightColor);
  }

.Label-disabled-zzPjC {
  border-color: var(--disabledColor);
  background-color: var(--disabledColor);
}

.Label-disabled-zzPjC.Label-outline-Xn6SE {
    color: var(--offWhite);
  }

.Label-info-QWFsu {
  border-color: var(--infoColor);
  background-color: var(--infoColor);
  color: var(--infoTextColor);
}

.Label-info-QWFsu.Label-outline-Xn6SE {
    color: var(--infoColor);
  }

.Label-inverse-gByCz {
  border-color: var(--inverseLabelColor);
  background-color: var(--inverseLabelColor);
  color: var(--inverseLabelTextColor);
}

.Label-inverse-gByCz.Label-outline-Xn6SE {
    background-color: var(--inverseLabelTextColor) !important;
    color: var(--inverseLabelColor);
  }

.Label-primary-oG9By {
  border-color: var(--primaryColor);
  background-color: var(--primaryColor);
}

.Label-primary-oG9By.Label-outline-Xn6SE {
    color: var(--primaryColor);
  }

.Label-success-KHmdj {
  border-color: var(--successColor);
  background-color: var(--successColor);
  color: #eee;
}

.Label-success-KHmdj.Label-outline-Xn6SE {
    color: var(--successColor);
  }

.Label-warning-UhdwP {
  border-color: var(--warningColor);
  background-color: var(--warningColor);
}

.Label-warning-UhdwP.Label-outline-Xn6SE {
    color: var(--warningColor);
  }

.Label-warning-UhdwP.colorImpaired {
    background: repeating-linear-gradient(45deg, var(--warningColor), var(--warningColor) 5px, color(var(--warningColor) tint(15%)) 5px, color(var(--warningColor) tint(15%)) 10px);
  }

.Label-queue-aakku {
  border-color: var(--queueColor);
  background-color: var(--queueColor);
}

.Label-queue-aakku.Label-outline-Xn6SE {
    color: var(--queueColor);
  }

/** Sizes **/

.Label-small-DLxDw {
  padding: 1px 3px;
  font-size: 11px;
}

.Label-medium-Vxy3t {
  padding: 2px 5px;
  font-size: 12px;
}

.Label-large-qZ9AP {
  padding: 3px 7px;
  font-weight: bold;
  font-size: 14px;
}

/** Outline **/

.Label-outline-Xn6SE {
  background-color: var(--disabledLabelColor);
}

.TagInputTag-tag-WPj1a {
  display: flex;
  justify-content: center;
  flex-direction: column;
  max-width: 100%;
  height: 31px;
}

.TagInputTag-link-quC0h {
  max-width: 100%;
}

.TagInputTag-linkWithEdit-uoC8p {
  max-width: calc(100% - 9px - 4px - 2px);
}

.TagInputTag-editContainer-G8zHE {
  display: inline-block;
  margin-left: 4px;
  padding-left: 2px;
  border-left: 1px solid #eee;
}

.TagInputTag-editButton-ItWkt {

  width: 9px;
}

.TagInputTag-label-kQqU3 {

  display: flex;
  max-width: 100%;
}

.TagInput-input-qmB1l {

  padding: 0;
  min-height: 35px;
  height: auto;
}

  .TagInput-input-qmB1l.TagInput-isFocused-rveQ8 {
    outline: 0;
    border-color: var(--inputFocusBorderColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor),
      0 0 8px var(--inputFocusBoxShadowColor);
  }

.TagInput-hasError-XoQQY {
}

.TagInput-hasWarning-ZgSvj {
}

.TagInput-internalInput-FmeIP {
  flex: 1 1 0%;
  margin-left: 3px;
  min-width: 20%;
  max-width: 100%;
  width: 0%;
  height: 31px;
  border: none;
  background-color: var(--inputBackground);
  color: var(--textColor);
}

.TagInput-input-qmB1l {

  padding: 0;
  min-height: 35px;
  height: auto;
}

  .TagInput-input-qmB1l.TagInput-isFocused-rveQ8 {
    outline: 0;
    border-color: var(--inputFocusBorderColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor),
      0 0 8px var(--inputFocusBoxShadowColor);
  }

.TagInput-hasError-XoQQY {
}

.TagInput-hasWarning-ZgSvj {
}

.TagInput-internalInput-FmeIP {
  flex: 1 1 0%;
  margin-left: 3px;
  min-width: 20%;
  max-width: 100%;
  width: 0%;
  height: 31px;
  border: none;
  background-color: var(--inputBackground);
  color: var(--textColor);
}

.DeviceInput-deviceInputWrapper-CC67q {
  display: flex;
}

.DeviceInput-input-xVA8v {
}

.TextArea-input-E794O {

  flex-grow: 1;
  min-height: 200px;
  resize: vertical;
}

.TextArea-readOnly-ysBOQ {
  background-color: #eee;
}

.TextArea-hasError-tL5zd {
}

.TextArea-hasWarning-qW1kz {
}

.FormInputGroup-inputGroupContainer-YhfqJ {
  flex: 1 1 auto;
  min-width: 0;
}

.FormInputGroup-inputGroup-Yqmkv {
  display: flex;
  flex: 1 1 auto;
  flex-wrap: wrap;
}

.FormInputGroup-inputContainer-yauGG {
  position: relative;
  flex: 1 1 auto;
  min-width: 0;
}

.FormInputGroup-inputUnit-rRSCN {
  position: absolute;
  top: 0;
  right: 20px;
  margin-top: 7px;
  width: 75px;
  color: #c6c6c6;
  text-align: right;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.FormInputGroup-inputUnitNumber-oqRfn {

  right: 40px;
}

.FormInputGroup-pendingChangesContainer-BLt9I {
  display: flex;
  justify-content: flex-end;
  width: 30px;
}

.FormInputGroup-pendingChangesIcon-XrqHM {
  color: var(--warningColor);
  font-size: 20px;
  line-height: 35px;
}

.FormInputGroup-helpLink-uIwQR {
  margin-top: 5px;
  line-height: 20px;
}

.FieldSet-fieldSet-CMapa {
  margin: 0;
  margin-bottom: 20px;
  padding: 0;
  min-width: 0;
  border: 0;
}

.FieldSet-legend-M8__d {
  display: block;
  margin-bottom: 21px;
  padding: 0;
  width: 100%;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
  color: var(--textColor);
  font-size: 21px;
  line-height: inherit;
}

.FieldSet-legend-M8__d.FieldSet-small-SxwJl {
    color: #909293;
    font-size: 18px;
  }

.ClipboardButton-button-u0nGA {

  position: relative;
}

.ClipboardButton-stateIconContainer-AejXw {
  position: absolute;
  top: 50%;
  left: -100%;
  display: inline-flex;
  visibility: hidden;
  transition: left 0.2s;
  transform: translateX(-50%) translateY(-50%);
}

.ClipboardButton-clipboardIconContainer-cs16L {
  position: relative;
  left: 0;
  transition: left 0.2s, opacity 0.2s;
}

.ClipboardButton-showStateIcon-Abpza .ClipboardButton-stateIconContainer-AejXw {
    left: 50%;
    visibility: visible;
  }

.ClipboardButton-showStateIcon-Abpza .ClipboardButton-clipboardIconContainer-cs16L {
    left: 100%;
    opacity: 0;
  }

.AuthenticationRequiredModalContent-authRequiredAlert-E7Mqx {

  margin-bottom: 20px;
}

.Page-page-TorHA {
  display: flex;
  flex-direction: column;
  height: 100%;
}

.Page-main-Swphf {
  position: relative; /* need this to position inner content - is this really needed? */
  display: flex;
  flex: 1 1 auto;
}

@media only screen and (max-width: 768px) {
  .Page-page-TorHA {
    flex-grow: 1;
    height: initial;
  }
}

.ErrorPage-page-Jiv2O {

  margin-top: 20px;
  text-align: center;
  font-size: 20px;
}

.ErrorPage-version-PGaC9 {
  margin-top: 20px;
  font-size: 16px;
}

.KeyboardShortcutsModalContent-shortcut-nblFz {
  display: flex;
  justify-content: space-between;
  padding: 5px 20px;
  font-size: 18px;
}

.KeyboardShortcutsModalContent-key-zJf3y {
  padding: 2px 4px;
  border-radius: 3px;
  background-color: var(--defaultColor);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
  color: var(--white);
  font-size: 16px;
}

.MovieSearchResult-result-yov2e {
  display: flex;
  padding: 3px;
  cursor: pointer;
}

.MovieSearchResult-poster-gII_F {
  width: 35px;
  height: 50px;
}

.MovieSearchResult-titles-pbTOS {
  flex: 1 1 1px;
}

.MovieSearchResult-title-alR_9 {
  flex: 1 1 1px;
  margin-left: 5px;
}

.MovieSearchResult-alternateTitle-JvltE {

  color: var(--disabledColor);
  font-size: 12px;
}

.MovieSearchResult-tagContainer-fFqud {
}

@media only screen and (max-width: 768px) {
  .MovieSearchResult-titles-pbTOS,
  .MovieSearchResult-title-alR_9,
  .MovieSearchResult-alternateTitle-JvltE {
    overflow: hidden !important;
    max-width: 100%;
    /* 1 */
    text-overflow: ellipsis !important;
    white-space: nowrap !important;
  }
}

.LoadingIndicator-loading-DWfav {
  margin-top: 20px;
  text-align: center;
}

.LoadingIndicator-rippleContainer-b3h1D {
  position: relative;
  display: inline-block;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(0) {
  animation-delay: -0.8s;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(1) {
  animation-delay: -0.6s;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(2) {
  animation-delay: -0.4s;
}

.LoadingIndicator-ripple-Dn9J1:nth-child(3) {
  animation-delay: -0.2s;
}

.LoadingIndicator-ripple-Dn9J1 {
  position: absolute;
  border: 2px solid var(--themeDarkColor);
  border-radius: 100%;
  animation: LoadingIndicator-rippleContainer-b3h1D 1.25s 0s infinite cubic-bezier(0.21, 0.53, 0.56, 0.8);
  animation-fill-mode: both;
}

@keyframes LoadingIndicator-rippleContainer-b3h1D {
  0% {
    opacity: 1;
    transform: scale(0.1);
  }

  70% {
    opacity: 0.7;
    transform: scale(1);
  }

  100% {
    opacity: 0;
  }
}

.MovieSearchInput-wrapper-p_2ZQ {
  display: flex;
  align-items: center;
}

.MovieSearchInput-loading-C0Dhh {
  position: absolute;
  display: inline-block;
  margin-left: 5px;
}

.MovieSearchInput-ripple-a8fp1 {

  border: 1px solid var(--toolbarColor);
}

.MovieSearchInput-input-TKyuc {
  margin-left: 8px;
  width: 200px;
  border: none;
  border-bottom: solid 1px var(--white);
  border-radius: 0;
  background-color: transparent;
  box-shadow: none;
  color: var(--white);
  transition: border 0.3s ease-out;
}

.MovieSearchInput-input-TKyuc::-moz-placeholder {
    color: var(--white);
    -moz-transition: color 0.3s ease-out;
    transition: color 0.3s ease-out;
  }

.MovieSearchInput-input-TKyuc::placeholder {
    color: var(--white);
    transition: color 0.3s ease-out;
  }

.MovieSearchInput-input-TKyuc:focus {
    outline: 0;
    border-bottom-color: transparent;
  }

.MovieSearchInput-input-TKyuc:focus::-moz-placeholder {
      color: transparent;
    }

.MovieSearchInput-input-TKyuc:focus::placeholder {
      color: transparent;
    }

.MovieSearchInput-container-nrOKz {
  position: relative;
  flex-grow: 1;
}

.MovieSearchInput-movieContainer-kuKIB {
  scrollbar-color: var(--scrollbarBackgroundColor) transparent;
  scrollbar-width: thin;
}

.MovieSearchInput-movieContainer-kuKIB::-webkit-scrollbar {
    width: 10px;
    height: 10px;
  }

.MovieSearchInput-movieContainer-kuKIB::-webkit-scrollbar-track {
    background-color: transparent;
  }

.MovieSearchInput-movieContainer-kuKIB::-webkit-scrollbar-thumb {
    min-height: 100px;
    border: 1px solid transparent;
    border-radius: 5px;
    background-color: var(--scrollbarBackgroundColor);
    background-clip: padding-box;
  }

.MovieSearchInput-movieContainer-kuKIB::-webkit-scrollbar-thumb:hover {
      background-color: var(--scrollbarHoverBackgroundColor);
    }

.MovieSearchInput-containerOpen-iE3oK .MovieSearchInput-movieContainer-kuKIB {
    position: absolute;
    top: 42px;
    z-index: 1;
    overflow-y: auto;
    min-width: 100%;
    max-height: 230px;
    border: 1px solid var(--themeDarkColor);
    border-radius: 4px;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    background-color: var(--themeDarkColor);
    box-shadow: inset 0 1px 1px var(--inputBoxShadowColor);
    color: var(--menuItemColor);
  }

.MovieSearchInput-list-Gc2So {
  margin: 5px 0;
  padding-left: 0;
  list-style-type: none;
}

.MovieSearchInput-listItem-_Kyrf {
  padding: 0 16px;
  white-space: nowrap;
}

.MovieSearchInput-highlighted-InlUx {
  background-color: var(--themeLightColor);
}

.MovieSearchInput-sectionTitle-rt3kk {
  padding: 5px 8px;
  color: var(--disabledColor);
}

.MovieSearchInput-addNewMovieSuggestion-qXQCY {
  padding: 5px 3px;
  cursor: pointer;
}

@media only screen and (max-width: 768px) {
  .MovieSearchInput-input-TKyuc {
    min-width: 150px;
    max-width: 200px;
  }

  .MovieSearchInput-container-nrOKz {
    min-width: 0;
    max-width: 200px;
  }
}

.Menu-menu-Uz3_0 {
  position: relative;
}

.MenuButton-menuButton-Jl5Je {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
}

  .MenuButton-menuButton-Jl5Je::after {
    margin-left: 5px;
    content: '\25BE';
  }

  .MenuButton-menuButton-Jl5Je:hover {
    color: var(--toobarButtonHoverColor);
  }

.MenuButton-isDisabled-x0tG4 {
  color: var(--disabledColor);

  pointer-events: none;
}

.MenuContent-menuContent-_1J_h {
  z-index: 2000;
  display: flex;
  flex-direction: column;
  background-color: var(--toolbarMenuItemBackgroundColor);
  line-height: 20px;
}

.MenuContent-scroller-n5RM_ {
  display: flex;
  flex-direction: column;
}

.MenuItem-menuItem-XlMdU {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
  display: block;
  flex-shrink: 0;
  padding: 10px 20px;
  min-width: 150px;
  max-width: 250px;
  background-color: var(--toolbarMenuItemBackgroundColor);
  color: var(--menuItemColor);
  line-height: 20px;
}

  .MenuItem-menuItem-XlMdU:hover,
  .MenuItem-menuItem-XlMdU:focus {
    background-color: var(--toolbarMenuItemHoverBackgroundColor);
    color: var(--menuItemHoverColor);
    text-decoration: none;
  }

.MenuItem-isDisabled-iQzs8 {
  color: var(--disabledColor);
  pointer-events: none;
}

.MenuItemSeparator-separator-umWCF {
  overflow: hidden;
  min-height: 1px;
  height: 1px;
  background-color: var(--themeDarkColor);
}

.PageHeaderActionsMenu-menuButton-uj_V6 {
  margin-right: 15px;
  width: 30px;
  height: 60px;
  text-align: center;
}

  .PageHeaderActionsMenu-menuButton-uj_V6:hover {
    color: var(--toobarButtonHoverColor);
  }

.PageHeaderActionsMenu-itemIcon-NCa7f {
  margin-right: 8px;
}

@media only screen and (max-width: 768px) {
  .PageHeaderActionsMenu-menuButton-uj_V6 {
    margin-right: 5px;
  }
}

.PageHeader-header-yG8lh {
  z-index: 3;
  display: flex;
  align-items: center;
  flex: 0 0 auto;
  height: 60px;
  background-color: var(--pageHeaderBackgroundColor);
  color: var(--white);
}

.PageHeader-logoContainer-w6Bht {
  display: flex;
  align-items: center;
  flex: 0 0 210px;
  padding-left: 20px;
}

.PageHeader-logoLink-dJA7B {
  line-height: 0;
}

.PageHeader-logoFull-XjP3T,
.PageHeader-logo-WW_El {
  vertical-align: middle;
}

.PageHeader-logoFull-XjP3T {
  margin-left: 15px;
  width: 120px;
  height: 40px;
}

.PageHeader-logo-WW_El {
  width: 32px;
  height: 32px;
}

.PageHeader-sidebarToggleContainer-s7QPv {
  display: none;
  justify-content: center;
  flex: 0 0 45px;
  margin-right: 14px;
}

.PageHeader-right-e8LU4 {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
}

.PageHeader-translate-otp7Q {

  display: flex;
  align-items: center;
  justify-content: center;
  width: 35px;
  color: #fff;
  text-align: center;
  line-height: 60px;
}

.PageHeader-translate-otp7Q:hover {
    color: var(--toobarButtonHoverColor);
  }

.PageHeader-donate-FT1Kz {

  display: flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  color: var(--themeRed);
  text-align: center;
  line-height: 60px;
}

.PageHeader-donate-FT1Kz:hover {
    color: #9c1f30;
  }

@media only screen and (max-width: 768px) {
  .PageHeader-logoContainer-w6Bht {
    flex: 0 0 60px;
  }

  .PageHeader-sidebarToggleContainer-s7QPv {
    display: flex;
  }
}

@media only screen and (max-width: 480px) {
  .PageHeader-donate-FT1Kz,
  .PageHeader-translate-otp7Q {
    display: none;
  }
}

.LoadingMessage-loadingMessage-WU8sQ {
  margin: 10px 10px 0;
  text-align: center;
  font-weight: 300;
  font-size: 36px;
}

.LoadingPage-page-TN4QY {

  background-color: var(--pageBackground);
}

.LoadingPage-logoFull-_XCIG {
  margin-top: 50px;
  margin-right: auto;
  margin-left: auto;
  width: 120px;
  height: 40px;
}

.OverlayScroller-scroller-Qv2oP {
  /* Placeholder */
}

.OverlayScroller-track-NpAah {
  /* Placeholder */
}

.OverlayScroller-thumb-IKMmD {
  min-height: 100px;
  border: 1px solid transparent;
  border-radius: 5px;
  background-color: var(--scrollbarBackgroundColor);
  background-clip: padding-box;
}

.OverlayScroller-thumb-IKMmD:hover {
    background-color: var(--scrollbarHoverBackgroundColor);
  }

.Message-message-alKx2 {
  display: flex;
  border-left: 3px solid var(--infoColor);
}

.Message-iconContainer-rjS_1,
.Message-text-j_4_k {
  display: flex;
  justify-content: center;
  flex-direction: column;
  padding: 2px 0;
  color: var(--sidebarColor);
}

.Message-iconContainer-rjS_1 {
  flex: 0 0 25px;
  margin-left: 24px;
  padding: 10px 0;
}

.Message-text-j_4_k {
  margin-right: 24px;
  font-size: 13px;
}

/* Types */

.Message-error-QCmrh {
  border-left-color: var(--dangerColor);
}

.Message-info-ihK_M {
  border-left-color: var(--infoColor);
}

.Message-success-KGG76 {
  border-left-color: var(--successColor);
}

.Message-warning-Bn1Qs {
  border-left-color: var(--warningColor);
}

.Messages-messages-FTWzW {
  margin-top: auto;
  margin-bottom: 20px;
  padding-top: 20px;
}

@media only screen and (max-width: 768px) {
  .Messages-messages-FTWzW {
    margin-bottom: 0;
  }
}

.PageSidebarItem-item-uOV0R {
  border-left: 3px solid transparent;
  color: var(--sidebarColor);
  transition: border-left 0.3s ease-in-out;
}

.PageSidebarItem-isActiveItem-ylMFV {
  border-left: 3px solid var(--themeBlue);
}

.PageSidebarItem-link-O9qjW {
  display: block;
  padding: 12px 24px;
  color: var(--sidebarColor);
}

.PageSidebarItem-link-O9qjW:hover,
  .PageSidebarItem-link-O9qjW:focus {
    color: var(--themeBlue);
    text-decoration: none;
  }

.PageSidebarItem-childLink-YTr30 {

  padding: 10px 24px;
  padding-left: 35px;
}

.PageSidebarItem-isActiveLink-_3fm9 {
  color: var(--themeBlue);
}

.PageSidebarItem-isActiveParentLink-pAp3F {
  background-color: var(--sidebarActiveBackgroundColor);
}

.PageSidebarItem-iconContainer-hoWhE {
  display: inline-block;
  margin-right: 7px;
  width: 18px;
  text-align: center;
}

.PageSidebarItem-status-CisPT {
  float: right;
}

.PageSidebar-sidebarContainer-aQa5n {
  flex: 0 0 210px;
  overflow: hidden;
  width: 210px;
  background-color: var(--sidebarBackgroundColor);
  transition: transform 300ms ease-in-out;
  transform: translateX(0);
}

.PageSidebar-sidebar-KUJeR {
  display: flex;
  flex-direction: column;
  overflow: hidden;
  background-color: var(--sidebarBackgroundColor);
  color: var(--white);
}

@media only screen and (max-width: 768px) {
  .PageSidebar-sidebarContainer-aQa5n {
    position: fixed;
    top: 0;
    z-index: 2;
    height: 100vh;
  }

  .PageSidebar-sidebar-KUJeR {
    position: fixed;
    z-index: 2;
    overflow-y: auto;
    width: 100%;
    height: 100%;
  }
}

.Page-page-TorHA {
  display: flex;
  flex-direction: column;
  height: 100%;
}

.Page-main-Swphf {
  position: relative; /* need this to position inner content - is this really needed? */
  display: flex;
  flex: 1 1 auto;
}

@media only screen and (max-width: 768px) {
  .Page-page-TorHA {
    flex-grow: 1;
    height: initial;
  }
}

.SelectedMenuItem-item-q3JrL {
  display: flex;
  justify-content: space-between;
  white-space: nowrap;
}

.SelectedMenuItem-isSelected-tocvz {
  visibility: visible;
  margin-left: 20px;
}

.SelectedMenuItem-isNotSelected-UNRlj {
  visibility: hidden;
  margin-left: 20px;
}

.MenuButton-menuButton-Jl5Je {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
}

  .MenuButton-menuButton-Jl5Je::after {
    margin-left: 5px;
    content: '\25BE';
  }

  .MenuButton-menuButton-Jl5Je:hover {
    color: var(--toobarButtonHoverColor);
  }

.MenuButton-isDisabled-x0tG4 {
  color: var(--disabledColor);

  pointer-events: none;
}

.PageToolbarButton-toolbarButton-j8a_b {

  padding-top: 4px;
  min-width: 60px;
  width: -moz-min-content;
  width: min-content;
  text-align: center;
}

  .PageToolbarButton-toolbarButton-j8a_b:hover {
    color: var(--toobarButtonHoverColor);
  }

  .PageToolbarButton-toolbarButton-j8a_b.PageToolbarButton-isDisabled-s8dE7 {
    color: var(--disabledColor);
  }

.PageToolbarButton-isDisabled-s8dE7 {
  color: var(--disabledColor);
}

.PageToolbarButton-labelContainer-QhTz_ {
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  height: 24px;
}

.PageToolbarButton-label-QIVQh {
  padding: 0 3px;
  max-width: 100%;
  max-height: 100%;
  color: var(--toolbarLabelColor);
  font-size: 11px;
  line-height: calc(11px + 1px);
}

.ToolbarMenuButton-menuButton-U1XFl {

  padding-top: 4px;
  width: 60px;
  height: 60px;
  text-align: center;
}

.ToolbarMenuButton-indicatorContainer-pM1GQ {
  position: absolute;
  top: 10px;
  right: 12px;
}

.ToolbarMenuButton-labelContainer-pVdy2 {
}

.ToolbarMenuButton-label-8FLaf {
}

.Menu-menu-Uz3_0 {
  position: relative;
}

.FilterMenu-filterMenu-vFvai {
}

@media only screen and (max-width: 768px) {
  .FilterMenu-filterMenu-vFvai {
    margin-right: 10px;
  }
}

.PageContentBody-contentBody-Hetrs {
  /* 1px for flex-basis so the div grows correctly in Edge/Firefox */
  flex: 1 0 1px;
}

.PageContentBody-innerContentBody-PtigL {
  padding: 20px;
}

@media only screen and (max-width: 768px) {
  .PageContentBody-contentBody-Hetrs {
    flex-basis: auto;
    overflow-y: hidden !important;
  }

  .PageContentBody-innerContentBody-PtigL {
    padding: 10px;
  }
}

.PageContent-content-C67P9 {
  position: relative;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  overflow-x: hidden;
  width: 100%;
}

.PageContentError-content-qmaXw {
}

.PageContent-content-C67P9 {
  position: relative;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  overflow-x: hidden;
  width: 100%;
}

.PageToolbar-toolbar-YMl38 {
  display: flex;
  justify-content: space-between;
  flex: 0 0 auto;
  padding: 0 20px;
  height: 60px;
  background-color: var(--toolbarBackgroundColor);
  color: var(--toolbarColor);
  line-height: 60px;
}

@media only screen and (max-width: 768px) {
  .PageToolbar-toolbar-YMl38 {
    padding: 0 10px;
  }
}

.PageToolbarButton-toolbarButton-j8a_b {

  padding-top: 4px;
  min-width: 60px;
  width: -moz-min-content;
  width: min-content;
  text-align: center;
}

  .PageToolbarButton-toolbarButton-j8a_b:hover {
    color: var(--toobarButtonHoverColor);
  }

  .PageToolbarButton-toolbarButton-j8a_b.PageToolbarButton-isDisabled-s8dE7 {
    color: var(--disabledColor);
  }

.PageToolbarButton-isDisabled-s8dE7 {
  color: var(--disabledColor);
}

.PageToolbarButton-labelContainer-QhTz_ {
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  height: 24px;
}

.PageToolbarButton-label-QIVQh {
  padding: 0 3px;
  max-width: 100%;
  max-height: 100%;
  color: var(--toolbarLabelColor);
  font-size: 11px;
  line-height: calc(11px + 1px);
}

.PageToolbarOverflowMenuItem-icon-FSmml {
  margin-right: 8px;
}

.ToolbarMenuButton-menuButton-U1XFl {

  padding-top: 4px;
  width: 60px;
  height: 60px;
  text-align: center;
}

.ToolbarMenuButton-indicatorContainer-pM1GQ {
  position: absolute;
  top: 10px;
  right: 12px;
}

.ToolbarMenuButton-labelContainer-pVdy2 {
}

.ToolbarMenuButton-label-8FLaf {
}

.PageToolbarSection-sectionContainer-dcxFs {
  display: flex;
  flex: 1 1 auto;
  overflow: hidden;
}

.PageToolbarSection-section-hL6TV {
  display: flex;
  align-items: stretch;
  flex-grow: 1;
}

.PageToolbarSection-left-E_sPJ {
  justify-content: flex-start;
}

.PageToolbarSection-center-hVR9U {
  justify-content: center;
}

.PageToolbarSection-right-w45zk {
  justify-content: flex-end;
}

.PageToolbarSection-overflowMenuButton-zBG01 {
}

.PageToolbarSection-overflowMenuItemIcon-qXSpK {
  margin-right: 8px;
}

@media only screen and (max-width: 768px) {
    .PageToolbarSection-overflowMenuButton-zBG01::after {
      margin-left: 0;
      content: '\25BE';
    }
}

.SelectInput-select-M6gsU {

  padding: 0 11px;
}

.SelectInput-hasError-e0Agk {
}

.SelectInput-hasWarning-zCkL1 {
}

.SelectInput-isDisabled-OTdBg {
  opacity: 0.7;
  cursor: not-allowed;
}

.SelectInput-select-M6gsU {

  padding: 0 11px;
}

.SelectInput-hasError-e0Agk {
}

.SelectInput-hasWarning-zCkL1 {
}

.SelectInput-isDisabled-OTdBg {
  opacity: 0.7;
  cursor: not-allowed;
}

.TablePager-pager-sW7hO {
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.TablePager-loadingContainer-mEsEn,
.TablePager-controlsContainer-zSMU8,
.TablePager-recordsContainer-yz1LG {
  flex: 0 1 33%;
}

.TablePager-controlsContainer-zSMU8 {
  display: flex;
  justify-content: center;
}

.TablePager-recordsContainer-yz1LG {
  display: flex;
  justify-content: flex-end;
}

.TablePager-loading-T4oAA {

  margin: 0;
  margin-left: 5px;
  text-align: left;
}

.TablePager-controls-hlpsq {
  display: flex;
  align-items: center;
  text-align: center;
}

.TablePager-pageNumber-tj2Ps {
  line-height: 30px;
}

.TablePager-pageLink-AAJga {
  padding: 0;
  width: 30px;
  height: 30px;
  line-height: 30px;
}

.TablePager-records-JiV_8 {
  color: var(--disabledColor);
}

.TablePager-disabledPageButton-f9ct7 {
  color: var(--disabledColor);
}

.TablePager-pageSelect-E2Iie {

  padding: 0 2px;
  height: 25px;
}

@media only screen and (max-width: 992px) {
  .TablePager-pager-sW7hO {
    flex-wrap: wrap;
  }

  .TablePager-loadingContainer-mEsEn,
  .TablePager-recordsContainer-yz1LG {
    flex: 0 1 50%;
  }

  .TablePager-controlsContainer-zSMU8 {
    flex: 0 1 100%;
    order: -1;
  }
}

.FilterBuilderRowValueTag-tag-hWm2U {
  display: flex;
}

  .FilterBuilderRowValueTag-tag-hWm2U.FilterBuilderRowValueTag-isLastTag-fHFF3 .FilterBuilderRowValueTag-or-SwTRv {
      display: none;
    }

.FilterBuilderRowValueTag-label-U_MN0 {

  border-style: none;
  font-size: 13px;
}

.FilterBuilderRowValueTag-or-SwTRv {
  margin: 0 3px;
  color: var(--themeDarkColor);
  line-height: 31px;
}

.TextInput-input-svfXu {
}

.TextInput-readOnly-WH5Lg {
  background-color: var(--inputReadOnlyBackgroundColor);
}

.TextInput-hasError-Gbw0Q {
}

.TextInput-hasWarning-ZPiVp {
}

.TextInput-hasButton-Z1LGV {
}

.DateFilterBuilderRowValue-container-O7izS {
  display: flex;
}

.DateFilterBuilderRowValue-numberInput-UmOYr {

  margin-right: 3px;
}

.DateFilterBuilderRowValue-selectInput-LWocC {

  margin-left: 3px;
}

.FilterBuilderRow-filterRow-q1nvx {
  display: flex;
  margin-bottom: 5px;
}

  .FilterBuilderRow-filterRow-q1nvx:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

.FilterBuilderRow-inputContainer-mJ6US {
  flex: 0 1 200px;
  margin-right: 10px;
}

.FilterBuilderRow-valueInputContainer-wN_TZ {
  flex: 0 1 300px;
  margin-right: 10px;
}

.FilterBuilderRow-actionsContainer-cYvae {
  display: flex;
}

@media only screen and (max-width: 768px) {
  .FilterBuilderRow-filterRow-q1nvx {
    display: block;
  }

  .FilterBuilderRow-inputContainer-mJ6US {
    margin-bottom: 10px;
  }
}

.FilterBuilderModalContent-labelContainer-_6W6j {
  margin-bottom: 20px;
}

.FilterBuilderModalContent-label-aJpFi {
  margin-bottom: 5px;
  font-weight: bold;
}

.FilterBuilderModalContent-labelInputContainer-khdZ8 {
  width: 300px;
}

.FilterBuilderModalContent-rows-PzMnR {
  margin-bottom: 100px;
}

.CustomFilter-customFilter-eI_Cq {
  display: flex;
  margin-bottom: 5px;
  padding: 5px;
}

  .CustomFilter-customFilter-eI_Cq:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

.CustomFilter-label-lHwLr {
  flex: 0 1 300px;
}

.CustomFilter-actions-Wjx7G {
  flex: 0 0 60px;
}

.CustomFiltersModalContent-addButtonContainer-CcXAj {
  margin-top: 15px;
}

.RelativeDateCell-cell-_hShQ {

  width: 180px;
}

.TableSelectCell-selectCell-ip5ko {

  width: 30px;
}

.TableSelectCell-input-YHSWy {

  margin: 0;
}

.Tooltip-tooltipContainer-gDO7_ {
  z-index: 2000;
  margin: 10px;
}

.Tooltip-tooltip-qMfbq {
  position: relative;
}

.Tooltip-tooltip-qMfbq.Tooltip-default-esYBk {
    background-color: var(--popoverBodyBackgroundColor);
    box-shadow: 0 5px 10px var(--popoverShadowColor);
  }

.Tooltip-tooltip-qMfbq.Tooltip-inverse-Tdtfn {
    background-color: var(--themeDarkColor);
    box-shadow: 0 5px 10px var(--popoverShadowInverseColor);
    color: var(--white);
  }

.Tooltip-arrow-EePNR,
.Tooltip-arrow-EePNR::after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-width: 11px;
  border-style: solid;
  border-color: transparent;
}

.Tooltip-arrowDisabled-TxV9g {
  display: none;
}

.Tooltip-arrow-EePNR::after {
  border-width: 10px;
  content: '';
}

.Tooltip-top-yIoOO {
  bottom: -11px;
  margin-left: -11px;
  border-bottom-width: 0;
}

.Tooltip-top-yIoOO::after {
    bottom: 1px;
    margin-left: -10px;
    border-bottom-width: 0;
    content: ' ';
  }

.Tooltip-top-yIoOO::after.Tooltip-default-esYBk {
      border-top-color: var(--popoverArrowBorderColor);
    }

.Tooltip-top-yIoOO::after.Tooltip-inverse-Tdtfn {
      border-top-color: var(--popoverArrowBorderInverseColor);
    }

.Tooltip-top-yIoOO.Tooltip-default-esYBk {
    border-top-color: var(--popoverArrowBorderColor);
  }

.Tooltip-top-yIoOO.Tooltip-inverse-Tdtfn {
    border-top-color: var(--popoverArrowBorderInverseColor);
  }

.Tooltip-right-clP43 {
  left: -11px;
  margin-top: -11px;
  border-left-width: 0;
}

.Tooltip-right-clP43::after {
    bottom: -10px;
    left: 1px;
    border-left-width: 0;
    content: ' ';
  }

.Tooltip-right-clP43::after.Tooltip-default-esYBk {
      border-right-color: var(--popoverArrowBorderColor);
    }

.Tooltip-right-clP43::after.Tooltip-inverse-Tdtfn {
      border-right-color: var(--popoverArrowBorderInverseColor);
    }

.Tooltip-right-clP43.Tooltip-default-esYBk {
    border-right-color: var(--popoverArrowBorderColor);
  }

.Tooltip-right-clP43.Tooltip-inverse-Tdtfn {
    border-right-color: var(--popoverArrowBorderInverseColor);
  }

.Tooltip-bottom-awZ3q {
  top: -11px;
  margin-left: -11px;
  border-top-width: 0;
}

.Tooltip-bottom-awZ3q::after {
    top: 1px;
    margin-left: -10px;
    border-top-width: 0;
    content: ' ';
  }

.Tooltip-bottom-awZ3q::after.Tooltip-default-esYBk {
      border-bottom-color: var(--popoverArrowBorderColor);
    }

.Tooltip-bottom-awZ3q::after.Tooltip-inverse-Tdtfn {
      border-bottom-color: var(--popoverArrowBorderInverseColor);
    }

.Tooltip-bottom-awZ3q.Tooltip-default-esYBk {
    border-bottom-color: var(--popoverArrowBorderColor);
  }

.Tooltip-bottom-awZ3q.Tooltip-inverse-Tdtfn {
    border-bottom-color: var(--popoverArrowBorderInverseColor);
  }

.Tooltip-left-WEn0f {
  right: -11px;
  margin-top: -11px;
  border-right-width: 0;
}

.Tooltip-left-WEn0f::after {
    right: 1px;
    bottom: -10px;
    border-right-width: 0;
    content: ' ';
  }

.Tooltip-left-WEn0f::after.Tooltip-default-esYBk {
      border-left-color: var(--popoverArrowBorderColor);
    }

.Tooltip-left-WEn0f::after.Tooltip-inverse-Tdtfn {
      border-left-color: var(--popoverArrowBorderInverseColor);
    }

.Tooltip-left-WEn0f.Tooltip-default-esYBk {
    border-left-color: var(--popoverArrowBorderColor);
  }

.Tooltip-left-WEn0f.Tooltip-inverse-Tdtfn {
    border-left-color: var(--popoverArrowBorderInverseColor);
  }

.Tooltip-body-EY7l7 {
  padding: 5px;
}

.Tooltip-verticalContainer-Q9BQj {
  max-height: 300px;
}

.Tooltip-horizontalContainer-vrDdq {
  max-width: calc(480px - 20px);
}

@media only screen and (min-width: 480px) {
  .Tooltip-horizontalContainer-vrDdq {
    max-width: calc(768px * 0.8);
  }
}

@media only screen and (min-width: 768px) {
  .Tooltip-horizontalContainer-vrDdq {
    max-width: calc(992px * 0.8);
  }
}

@media only screen and (min-width: 992px) {
  .Tooltip-horizontalContainer-vrDdq {
    max-width: calc(1200px * 0.8);
  }
}

/* @media only screen and (max-width: $breakpointLarge) {
  .horizontalContainer {
    max-width: calc($breakpointLarge * 0.8);
  }
} */

.Popover-title-GAfA1 {
  padding: 10px 20px;
  border-bottom: 1px solid var(--popoverTitleBorderColor);
  background-color: var(--popoverTitleBackgroundColor);
  font-size: 16px;
}

.Popover-body-nroDV {
  overflow: auto;
  padding: 10px;
  background-color: var(--popoverBodyBackgroundColor);
}

.Popover-tooltipBody-VJBHk {
  padding: 0;
}

.DescriptionList-descriptionList-o7bt3 {
  margin-top: 0;
  margin-bottom: 0;
}

.DescriptionListItemDescription-description-IZlGY {
  margin-left: 0;
  line-height: 1.528571429;
  overflow-wrap: break-word;
}

@media (min-width: 768px) {
  .DescriptionListItemDescription-description-IZlGY {
    margin-left: 180px;
  }
}

.DescriptionListItemTitle-title-br1UE {
  line-height: 1.528571429;
}

.DescriptionListItemTitle-title-br1UE {
  font-weight: bold;
}

@media (min-width: 768px) {
  .DescriptionListItemTitle-title-br1UE {
    overflow: hidden !important;
    max-width: 100%;
    /* 1 */
    text-overflow: ellipsis !important;
    white-space: nowrap !important;

    float: left;
    clear: left;
    width: 160px;
    text-align: right;
  }
}

.BlocklistRow-languages-Sn3Zx,
.BlocklistRow-quality-DFEgf {

  width: 100px;
}

.BlocklistRow-indexer-LARqS {

  width: 80px;
}

.BlocklistRow-actions-EYLsy {

  width: 70px;
}

.DescriptionListItemDescription-description-IZlGY {
  margin-left: 0;
  line-height: 1.528571429;
  overflow-wrap: break-word;
}

@media (min-width: 768px) {
  .DescriptionListItemDescription-description-IZlGY {
    margin-left: 180px;
  }
}

.HistoryDetails-description-tZwCD {

  overflow-wrap: break-word;
}

.HistoryDetailsModal-markAsFailedButton-P9sG9 {

  margin-right: auto;
}

.HistoryEventTypeCell-cell-Q8TMw {

  width: 35px;
  text-align: center;
}

.HistoryRow-downloadClient-bHUPB {

  width: 120px;
}

.HistoryRow-indexer-gwnyu {

  width: 80px;
}

.HistoryRow-customFormatScore-xkDCa {

  width: 55px;
}

.HistoryRow-releaseGroup-Py4iD {

  width: 110px;
}

.HistoryRow-details-XUSQz {

  width: 30px;
}

.PageToolbarSeparator-separator-N1WHF {
  margin: 10px 20px;
  height: 40px;
  border-right: 1px solid #e5e5e5;
  opacity: 0.35;
}

@media only screen and (max-width: 768px) {
  .PageToolbarSeparator-separator-N1WHF {
    margin: 10px 5px;
  }
}

.ProtocolLabel-torrent-Fhltw {

  border-color: var(--torrentColor);
  background-color: var(--torrentColor);
}

.ProtocolLabel-usenet-HVp5Y {

  border-color: var(--usenetColor);
  background-color: var(--usenetColor);
}

.ProtocolLabel-unknown-gwrqY {
}

.ProgressBar-container-VCeFi {
  position: relative;
  overflow: hidden;
  width: 100%;
  border-radius: 4px;
  background-color: var(--progressBarBackgroundColor);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}

.ProgressBar-progressBar-xAcCf {
  position: relative;
  z-index: 1;
  float: left;
  width: 0;
  height: 100%;
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  color: var(--white);
  transition: width 0.6s ease;
}

.ProgressBar-progressBar-xAcCf.ProgressBar-default-HtiNn {
    background-color: var(--darkGray);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-inverse-Zalm9 {
    background-color: var(--inverseLabelColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-primary-ev7yC {
    background-color: var(--primaryColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-danger-c24TF {
    background-color: var(--dangerColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-danger-c24TF.colorImpaired {
      background: repeating-linear-gradient(90deg, rgb(228, 76, 76), rgb(228, 76, 76) 5px, rgb(204, 68, 68) 5px, rgb(204, 68, 68) 10px);
    }

.ProgressBar-progressBar-xAcCf.ProgressBar-success-l1duR {
    background-color: var(--successColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-purple-P2P7Z {
    background-color: var(--purple);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-warning-vai87 {
    background-color: var(--warningColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-warning-vai87.colorImpaired {
      background: repeating-linear-gradient(45deg, #ffa500, #ffa500 5px, rgb(255, 179, 38) 5px, rgb(255, 179, 38) 10px);
    }

.ProgressBar-progressBar-xAcCf.ProgressBar-info-OnZQe {
    background-color: var(--infoColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-queue-yKtQI {
    background-color: var(--queueColor);
  }

.ProgressBar-frontTextContainer-zt7hp {
  z-index: 1;
  color: var(--progressBarFrontTextColor);
}

.ProgressBar-frontTextContainer-zt7hp.ProgressBar-inverse-Zalm9 {
    color: var(--inverseLabelTextColor);
  }

.ProgressBar-backTextContainer-RT0yM {
  color: var(--progressBarBackTextColor);
}

.ProgressBar-backTextContainer-RT0yM.ProgressBar-inverse-Zalm9 {
    color: var(--inverseLabelTextColor);
  }

.ProgressBar-backTextContainer-RT0yM,
.ProgressBar-frontTextContainer-zt7hp {
  position: absolute;
  overflow: hidden;
  width: 0;
  height: 100%;
}

.ProgressBar-backText-UABss,
.ProgressBar-frontText-hTZfF {
  display: flex;
  align-items: center;
  justify-content: center;
  text-align: center;
  font-size: 12px;
  cursor: default;
}

.ProgressBar-small-XrF6k {
  height: 5px;
}

.ProgressBar-small-XrF6k .ProgressBar-backText-UABss,
  .ProgressBar-small-XrF6k .ProgressBar-frontText-hTZfF {
    height: 5px;
  }

.ProgressBar-medium-WxfXU {
  height: 15px;
}

.ProgressBar-medium-WxfXU .ProgressBar-backText-UABss,
  .ProgressBar-medium-WxfXU .ProgressBar-frontText-hTZfF {
    height: 15px;
  }

.ProgressBar-large-oJAS7 {
  height: 20px;
}

.ProgressBar-large-oJAS7 .ProgressBar-backText-UABss,
  .ProgressBar-large-oJAS7 .ProgressBar-frontText-hTZfF {
    height: 20px;
  }

.FavoriteFolderRow-actions-vOUqv {

  width: 70px;
}

.RecentFolderRow-actions-Z_qCn {

  width: 70px;
}

.InteractiveImportSelectFolderModalContent-foldersContainer-Ml12n {
  margin-top: 15px;
}

.InteractiveImportSelectFolderModalContent-foldersTitle-fz9DV {
  border-bottom: 1px solid var(--borderColor);
  font-size: 21px;
}

.InteractiveImportSelectFolderModalContent-buttonsContainer-Zups9 {
  margin-top: 30px;
}

.InteractiveImportSelectFolderModalContent-buttonContainer-VzBje {
  display: flex;
  justify-content: center;

  margin-top: 10px;
}

.InteractiveImportSelectFolderModalContent-button-Q3COb {

  width: 300px;
}

.InteractiveImportSelectFolderModalContent-buttonIcon-XRLz8 {
  margin-right: 5px;
}

.SelectIndexerFlagsModalContent-modalBody-sne5e {

  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
}

.SelectLanguageModalContent-languageInput-qv4lb {
  display: flex;
  margin-bottom: 0;
}

.VirtualTableRow-row-cfNxh {
  display: flex;
  transition: background-color 500ms;
}

  .VirtualTableRow-row-cfNxh:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

@media only screen and (max-width: 992px) {
  .VirtualTableRow-row-cfNxh {
    overflow-x: visible !important;
  }
}

.VirtualTableRow-row-cfNxh {
  display: flex;
  transition: background-color 500ms;
}

  .VirtualTableRow-row-cfNxh:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

@media only screen and (max-width: 992px) {
  .VirtualTableRow-row-cfNxh {
    overflow-x: visible !important;
  }
}

.VirtualTableRowButton-row-MqcqS {
}

.VirtualTableHeader-header-BLqeA {
  display: flex;
}

.VirtualTableHeaderCell-headerCell-oq_lz {
  padding: 8px;
  border: none !important;
  text-align: left;
  font-weight: bold;
}

.VirtualTableHeaderCell-sortIcon-IdM2s {
  margin-left: 10px;
}

@media only screen and (max-width: 992px) {
  .VirtualTableHeaderCell-headerCell-oq_lz {
    white-space: nowrap;
  }
}

.SelectMovieModalTableHeader-title-MqdjD {

  flex: 4 0 140px;
}

.SelectMovieModalTableHeader-year-wbjuC {

  flex: 0 0 70px;
}

.SelectMovieModalTableHeader-imdbId-s7Brn,
.SelectMovieModalTableHeader-tmdbId-VHTom {

  flex: 0 0 110px;
}
.VirtualTableRowCell-cell-_Qpcm {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex-grow: 0;
  flex-shrink: 1;
  white-space: nowrap;
}

@media only screen and (max-width: 992px) {
  .VirtualTableRowCell-cell-_Qpcm {
    white-space: nowrap;
  }
}

.VirtualTableRowCell-cell-_Qpcm {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex-grow: 0;
  flex-shrink: 1;
  white-space: nowrap;
}

@media only screen and (max-width: 992px) {
  .VirtualTableRowCell-cell-_Qpcm {
    white-space: nowrap;
  }
}

.SelectMovieRow-cell-xLG5p {

  display: flex;
  align-items: center;
}

.SelectMovieRow-title-o5EzM {

  flex: 4 0 140px;
}

.SelectMovieRow-year-J0q1L {

  flex: 0 0 70px;
}

.SelectMovieRow-tmdbId-vemhj,
.SelectMovieRow-imdbId-RtVJY {

  flex: 0 0 110px;
}

.ModalFooter-modalFooter-wjkx5 {
  display: flex;
  align-items: center;
  justify-content: flex-end;
  flex-shrink: 0;
  padding: 15px 30px;
  border-top: 1px solid var(--borderColor);
}

  .ModalFooter-modalFooter-wjkx5 a,
  .ModalFooter-modalFooter-wjkx5 button {
    margin-left: 10px;
  }

  .ModalFooter-modalFooter-wjkx5 a:first-child, .ModalFooter-modalFooter-wjkx5 button:first-child {
      margin-left: 0;
    }

@media only screen and (max-width: 768px) {
  .ModalFooter-modalFooter-wjkx5 {
    padding: 15px;
  }
}

.SelectMovieModalContent-modalBody-xDE0t {

  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
}

.SelectMovieModalContent-filterInput-rwFNa {

  flex: 0 0 auto;
  margin-bottom: 20px;
}

.SelectMovieModalContent-scroller-A6dXg {
  min-height: 1px;
}

.SelectMovieModalContent-footer-SwY15 {

  display: flex;
  justify-content: space-between;
  overflow: hidden;
}

.SelectMovieModalContent-path-l3YAF {
  margin-right: 20px;
  color: var(--dimColor);
  word-break: break-word;
}

.SelectMovieModalContent-buttons-Klt9w {
  display: flex;
}

@media only screen and (max-width: 768px) {
  .SelectMovieModalContent-footer-SwY15 {
    display: block;
  }

  .SelectMovieModalContent-path-l3YAF {
    margin-right: 0;
    margin-bottom: 10px;
  }

  .SelectMovieModalContent-buttons-Klt9w {
    justify-content: space-between;
    flex-grow: 1;
  }
}

.SelectReleaseGroupModalContent-modalBody-tIpUk {

  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
}

.TableRowCellButton-cell-_ezEn {
}

.InteractiveImportRowCellPlaceholder-placeholder-WVc4a {
  display: inline-block;
  margin: -8px 0;
  width: 100%;
  height: 25px;
  border: 2px dashed var(--dangerColor);
}

.InteractiveImportRowCellPlaceholder-optional-xZuLy {
  border: 2px dashed var(--gray);
}

.InteractiveImportRow-relativePath-YbGTM {

  word-break: break-all;
}

.InteractiveImportRow-quality-hlvRY,
.InteractiveImportRow-languages-ozFm5 {

  text-align: center;
}

.InteractiveImportRow-label-vgyHk {

  cursor: pointer;
}

.InteractiveImportRow-reprocessing-pGMNS {

  margin-top: 0;
  text-align: start;
}

.InteractiveImportRow-customFormatTooltip-EeuhJ {
  max-width: 250px;
}

.InteractiveImportModalContent-filterContainer-wG6KO {
  display: flex;
  justify-content: flex-end;
  margin-bottom: 10px;
}

.InteractiveImportModalContent-filterText-QWJMj {
  margin-left: 5px;
}

.InteractiveImportModalContent-footer-nniuo {

  justify-content: space-between;
  padding: 15px;
}

.InteractiveImportModalContent-leftButtons-AVUp2,
.InteractiveImportModalContent-rightButtons-LlBFD {
  display: flex;
  flex-wrap: wrap;
  min-width: 0;
}

.InteractiveImportModalContent-leftButtons-AVUp2 {
  flex: 0 1 auto;
}

.InteractiveImportModalContent-rightButtons-LlBFD {
  justify-content: flex-end;
  flex: 1 1 50%;
}

.InteractiveImportModalContent-deleteButton-C7cFS {

  margin-right: 10px;
}

.InteractiveImportModalContent-importMode-bhbIr,
.InteractiveImportModalContent-bulkSelect-a3bN1 {

  margin-right: 10px;
  max-width: 100%;
  width: auto;
}

.InteractiveImportModalContent-errorMessage-ArmVO {
  color: var(--dangerColor);
}

@media only screen and (max-width: 768px) {
    .InteractiveImportModalContent-footer-nniuo .InteractiveImportModalContent-leftButtons-AVUp2,
    .InteractiveImportModalContent-footer-nniuo .InteractiveImportModalContent-rightButtons-LlBFD {
      flex-direction: column;
      gap: 3px;
    }

    .InteractiveImportModalContent-footer-nniuo .InteractiveImportModalContent-leftButtons-AVUp2 {
      align-items: flex-start;
      max-width: -moz-fit-content;
      max-width: fit-content;
    }

    .InteractiveImportModalContent-footer-nniuo .InteractiveImportModalContent-rightButtons-LlBFD {
      align-items: flex-end;
    }

    .InteractiveImportModalContent-footer-nniuo a,
    .InteractiveImportModalContent-footer-nniuo button {
      margin-left: 0;
    }

      .InteractiveImportModalContent-footer-nniuo a:first-child, .InteractiveImportModalContent-footer-nniuo button:first-child {
        margin-bottom: 5px;
      }
}

.QueueStatus-noMessages-a1G0a {
  margin-bottom: 10px;
}

.QueueStatusCell-status-ssPVV {

  width: 30px;
}

.RemoveQueueItemModal-message-CHG47 {
  margin-bottom: 30px;
}

.TimeleftCell-timeleft-eTmq3 {

  width: 100px;
}

.QueueRow-quality-gazz6 {

  width: 150px;
}

.QueueRow-protocol-oceJO {

  width: 100px;
}

.QueueRow-progress-PESGV {

  width: 150px;
}

.QueueRow-customFormatScore-RaT_f {

  width: 55px;
}

.QueueRow-actions-iDDa7 {

  width: 70px;
  text-align: right;
}

.ImdbRating-wrapper-YHIFy {
  display: inline-block;
}

.ImdbRating-image-EBG7Y {
  align-content: center;
  margin-right: 5px;
  vertical-align: -0.125em;
}

.TmdbRating-wrapper-sR4cs {
  display: inline-block;
}

.TmdbRating-image-TmxGo {
  align-content: center;
  margin-right: 5px;
  vertical-align: -0.125em;
}

.MovieDetailsLinks-links-eFF77 {
  display: flex;
  flex-wrap: wrap;
  margin: 0;
}

.MovieDetailsLinks-link-RA9Kf {
  white-space: nowrap;
}

.MovieDetailsLinks-linkLabel-GGMIV {

  cursor: pointer;
}

@media only screen and (max-width: 480px) {
  .MovieDetailsLinks-links-eFF77 {
    display: flex;
    flex-flow: column wrap;
  }
}

.MovieStatusLabel-queue-dZcLa {
  padding-left: 2px;
  border-left: 4px solid var(--queueColor);
}

.MovieStatusLabel-continuing-OxtJc {
  padding-left: 2px;
  border-left: 4px solid var(--primaryColor);
}

.MovieStatusLabel-availNotMonitored-IDhBN {
  padding-left: 2px;
  border-left: 4px solid var(--darkGray);
}

.MovieStatusLabel-ended-Zv66T {
  padding-left: 2px;
  border-left: 4px solid var(--successColor);
}

.MovieStatusLabel-missingMonitored-mGr6p {
  padding-left: 2px;
  border-left: 4px solid var(--dangerColor);
}

.MovieStatusLabel-missingUnmonitored-K4_q5 {
  padding-left: 2px;
  border-left: 4px solid var(--warningColor);
}

.MovieStatusLabel-deleted-ZWP9H {
  padding-left: 2px;
  border-left: 4px solid var(--inverseLabelColor);
  color: var(--dangerColor);
}

.ProgressBar-container-VCeFi {
  position: relative;
  overflow: hidden;
  width: 100%;
  border-radius: 4px;
  background-color: var(--progressBarBackgroundColor);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}

.ProgressBar-progressBar-xAcCf {
  position: relative;
  z-index: 1;
  float: left;
  width: 0;
  height: 100%;
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  color: var(--white);
  transition: width 0.6s ease;
}

.ProgressBar-progressBar-xAcCf.ProgressBar-default-HtiNn {
    background-color: var(--darkGray);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-inverse-Zalm9 {
    background-color: var(--inverseLabelColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-primary-ev7yC {
    background-color: var(--primaryColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-danger-c24TF {
    background-color: var(--dangerColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-danger-c24TF.colorImpaired {
      background: repeating-linear-gradient(90deg, rgb(228, 76, 76), rgb(228, 76, 76) 5px, rgb(204, 68, 68) 5px, rgb(204, 68, 68) 10px);
    }

.ProgressBar-progressBar-xAcCf.ProgressBar-success-l1duR {
    background-color: var(--successColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-purple-P2P7Z {
    background-color: var(--purple);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-warning-vai87 {
    background-color: var(--warningColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-warning-vai87.colorImpaired {
      background: repeating-linear-gradient(45deg, #ffa500, #ffa500 5px, rgb(255, 179, 38) 5px, rgb(255, 179, 38) 10px);
    }

.ProgressBar-progressBar-xAcCf.ProgressBar-info-OnZQe {
    background-color: var(--infoColor);
  }

.ProgressBar-progressBar-xAcCf.ProgressBar-queue-yKtQI {
    background-color: var(--queueColor);
  }

.ProgressBar-frontTextContainer-zt7hp {
  z-index: 1;
  color: var(--progressBarFrontTextColor);
}

.ProgressBar-frontTextContainer-zt7hp.ProgressBar-inverse-Zalm9 {
    color: var(--inverseLabelTextColor);
  }

.ProgressBar-backTextContainer-RT0yM {
  color: var(--progressBarBackTextColor);
}

.ProgressBar-backTextContainer-RT0yM.ProgressBar-inverse-Zalm9 {
    color: var(--inverseLabelTextColor);
  }

.ProgressBar-backTextContainer-RT0yM,
.ProgressBar-frontTextContainer-zt7hp {
  position: absolute;
  overflow: hidden;
  width: 0;
  height: 100%;
}

.ProgressBar-backText-UABss,
.ProgressBar-frontText-hTZfF {
  display: flex;
  align-items: center;
  justify-content: center;
  text-align: center;
  font-size: 12px;
  cursor: default;
}

.ProgressBar-small-XrF6k {
  height: 5px;
}

.ProgressBar-small-XrF6k .ProgressBar-backText-UABss,
  .ProgressBar-small-XrF6k .ProgressBar-frontText-hTZfF {
    height: 5px;
  }

.ProgressBar-medium-WxfXU {
  height: 15px;
}

.ProgressBar-medium-WxfXU .ProgressBar-backText-UABss,
  .ProgressBar-medium-WxfXU .ProgressBar-frontText-hTZfF {
    height: 15px;
  }

.ProgressBar-large-oJAS7 {
  height: 20px;
}

.ProgressBar-large-oJAS7 .ProgressBar-backText-UABss,
  .ProgressBar-large-oJAS7 .ProgressBar-frontText-hTZfF {
    height: 20px;
  }

.MovieIndexProgressBar-progress-ux7Iv {

  border-radius: 0;
  background-color: #5b5b5b;
  color: var(--white);
}

.MovieIndexProgressBar-progressRadius-W9Yb0 {

  border-radius: 0 0 5px 5px;
  background-color: #5b5b5b;
  color: var(--white);
  transition: width 200ms ease;
}

.MovieIndexProgressBar-progressBar-hAbdm {

  transition: width 200ms ease;
}

.AddNewMovieModalContent-container-ynV1e {
  display: flex;
}

.AddNewMovieModalContent-year-ZSPwM {
  margin-left: 5px;
  color: var(--disabledColor);
}

.AddNewMovieModalContent-poster-wvjLk {
  flex: 0 0 170px;
  margin-right: 20px;
  height: 250px;
}

.AddNewMovieModalContent-info-W006x {
  flex-grow: 1;
}

.AddNewMovieModalContent-overview-Fkqwx {
  margin-bottom: 30px;
}

.AddNewMovieModalContent-labelIcon-EcXh5 {
  margin-left: 8px;
}

.AddNewMovieModalContent-searchForMissingMovieLabelContainer-fdu9b {
  display: flex;
  margin-top: 2px;
}

.AddNewMovieModalContent-searchForMissingMovieLabel-KXzo4 {
  margin-right: 8px;
  font-weight: normal;
}

.AddNewMovieModalContent-searchForMissingMovieContainer-v0AfZ {

  flex: 0 1 0;
}

.AddNewMovieModalContent-searchForMissingMovieInput-CReO3 {

  margin-top: 0;
}

.AddNewMovieModalContent-modalFooter-QaqPr {
}

.AddNewMovieModalContent-addButton-XoBKi {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
}

@media only screen and (max-width: 768px) {
  .AddNewMovieModalContent-modalFooter-QaqPr {
    display: block;
    text-align: center;
  }

  .AddNewMovieModalContent-addButton-XoBKi {
    margin-top: 10px;
  }
}

.AddNewMovieSearchResult-searchResult-R02WQ {
  position: relative;
  margin: 20px 0;
  padding: 20px;
  width: 100%;
  color: inherit;
}

.AddNewMovieSearchResult-underlay-EQMwD {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;

  background-color: var(--addMovieBackgroundColor);
  transition: background 500ms;
}

.AddNewMovieSearchResult-underlay-EQMwD:hover {
    background-color: var(--pageBackground);
    box-shadow: 0 0 12px var(--black);
    color: inherit;
    text-decoration: none;
    transition: all 200ms ease-in;
  }

.AddNewMovieSearchResult-overlay-oSncf {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddNewMovieSearchResult-overlay-oSncf a,
  .AddNewMovieSearchResult-overlay-oSncf button {
    pointer-events: all;
  }

.AddNewMovieSearchResult-overlay-oSncf {

  position: relative;
  display: flex;
}

.AddNewMovieSearchResult-poster-DHsWD {
  position: relative;
  display: block;
  margin-right: 20px;
  height: 250px;
  background-color: var(--defaultColor);
}

.AddNewMovieSearchResult-content-nQ7n1 {
  flex: 0 1 100%;
  overflow: hidden;
}

.AddNewMovieSearchResult-titleRow-z1vT6 {
  display: flex;
}

.AddNewMovieSearchResult-titleContainer-_SyAG {
  display: flex;
  align-items: flex-end;
  flex: 0 1 auto;
}

.AddNewMovieSearchResult-title-wEA4S {
  font-weight: 300;
  font-size: 36px;
}

.AddNewMovieSearchResult-year-ysQfm {
  margin-left: 10px;
  color: var(--disabledColor);
}

.AddNewMovieSearchResult-icons-Lz08B {
  display: flex;
  align-items: center;
  justify-content: space-between;
  flex: 1 0 auto;
  height: 55px;
}

.AddNewMovieSearchResult-alreadyExistsIcon-wLMUU {
  margin-left: 10px;
  color: #37bc9b;
  pointer-events: all;
}

.AddNewMovieSearchResult-exclusionIcon-RNebD {
  margin-left: 10px;
  color: var(--dangerColor);
  pointer-events: all;
}

.AddNewMovieSearchResult-overview-bgEzS {
  margin-top: 20px;
}

.AddNewMovieSearchResult-originalLanguage-YnCLC,
.AddNewMovieSearchResult-studio-mI_v0,
.AddNewMovieSearchResult-genres-FxRy4 {
  margin-left: 5px;
}

.AddNewMovieSearchResult-genres-FxRy4 {
  pointer-events: all;
}

.AddNewMovieSearchResult-links-IpTNR {
  margin-left: 5px;
  pointer-events: all;
}

.AddNewMovieSearchResult-posterContainer-lxbB5 {
  position: relative;
}

.AddNewMovieSearchResult-certification-q9ZIf {
  margin-left: 2px;
  padding: 0 5px;
  border: 1px solid;
  border-radius: 5px;
  font-size: 16px;
}

.AddNewMovieSearchResult-runtime-PKxxm {
  margin-left: 8px;
  font-size: 16px;
}

.AddNewMovieSearchResult-statusContainer-ImTEq {
  margin-right: 22px;
  font-weight: bold;
}

@media only screen and (max-width: 992px) {
  .AddNewMovieSearchResult-titleRow-z1vT6 {
    justify-content: space-between;
    overflow: hidden;
  }
}

.AddNewMovie-searchContainer-WyP1I {
  display: flex;
  margin-bottom: 10px;
}

.AddNewMovie-searchIconContainer-kCb1Y {
  width: 58px;
  height: 46px;
  border: 1px solid var(--inputBorderColor);
  border-right: none;
  border-radius: 4px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  background-color: var(--searchIconContainerBackgroundColor);
  text-align: center;
  line-height: 46px;
}

.AddNewMovie-searchInput-gIRe5 {

  height: 46px;
  border-radius: 0;
  font-size: 18px;
}

.AddNewMovie-clearLookupButton-GlGuk {
  border: 1px solid var(--inputBorderColor);
  border-left: none;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.AddNewMovie-message-YvWRW {
  margin-top: 30px;
  text-align: center;
  font-weight: 300;
  font-size: 16px;
}

.AddNewMovie-helpText-S795X {
  margin-bottom: 10px;
  font-size: 24px;
}

.AddNewMovie-noMoviesText-aiXVm {
  margin-top: 80px;
  margin-bottom: 20px;
}

.AddNewMovie-noResults-LHDj4 {
  margin-bottom: 10px;
  font-weight: 300;
  font-size: 30px;
}

.AddNewMovie-searchResults-UB8XP {
  margin-top: 30px;
}

.PageContentFooter-contentFooter-RHpBL {
  display: flex;
  flex: 0 0 auto;
  padding: 20px;
  background-color: var(--pageFooterBackground);
}

@media only screen and (max-width: 768px) {
  .PageContentFooter-contentFooter-RHpBL {
    display: block;
  }
}

@media only screen and (max-width: 1450px) {
  .PageContentFooter-contentFooter-RHpBL {
    flex-wrap: wrap;
  }
}

.ImportMovieFooter-inputContainer-DZuoc {
  margin-right: 20px;
  min-width: 150px;
}

.ImportMovieFooter-label-yts5t {
  margin-bottom: 10px;
  font-weight: bold;
}

.ImportMovieFooter-importButtonContainer-sIDjC {
  display: flex;
  align-items: center;
}

.ImportMovieFooter-importButton-HXWDL {

  height: 35px;
}

.ImportMovieFooter-loadingButton-BqX_G {

  margin-left: 10px;
}

.ImportMovieFooter-loading-Ug7pw {

  margin: 0 10px 0 12px;
  text-align: left;
}

.ImportMovieFooter-importError-PDcrY {
  margin-left: 10px;
}

@media only screen and (max-width: 768px) {
  .ImportMovieFooter-inputContainer-DZuoc {
    margin-top: 10px;
  }

    .ImportMovieFooter-inputContainer-DZuoc:first-child {
      margin-top: 0;
    }

  .ImportMovieFooter-importButtonContainer-sIDjC {
    margin-top: 10px;
  }
}

.VirtualTable-tableContainer-MHSuC {
  width: 100%;
}

.VirtualTable-tableBodyContainer-W0ddE {
  position: relative;
}

.TableHeaderCell-headerCell-aJDuw {
  padding: 8px;
  border: none !important;
  text-align: left;
  font-weight: bold;
}

.TableHeaderCell-sortIcon-zaT8O {
  margin-left: 10px;
}

@media only screen and (max-width: 992px) {
  .TableHeaderCell-headerCell-aJDuw {
    white-space: nowrap;
  }
}

.VirtualTableSelectAllHeaderCell-selectAllHeaderCell-gBYqR {

  flex: 0 0 36px;
}

.VirtualTableSelectAllHeaderCell-input-XcVa4 {

  margin: 0;
}

.ImportMovieHeader-folder-OoH8e {

  flex: 1 0 200px;
}

.ImportMovieHeader-monitor-E_Q6P {

  flex: 0 1 200px;
  min-width: 185px;
}

.ImportMovieHeader-minimumAvailability-aASY7,
.ImportMovieHeader-qualityProfile-zCk34 {

  flex: 0 1 250px;
  min-width: 170px;
}

.ImportMovieHeader-movie-f5lg9 {

  flex: 0 1 400px;
  min-width: 300px;
}

.ImportMovieHeader-detailsIcon-tHQYn {
  margin-left: 8px;
}

.VirtualTableSelectCell-cell-_Uhr3 {

  flex: 0 0 36px;
}

.VirtualTableSelectCell-input-i2Qn8 {

  margin: 0;
}

.ImportMovieTitle-titleContainer-laDQ0 {
  display: flex;
  align-items: center;
}

.ImportMovieTitle-title-kmTMu {
  margin-right: 5px;
}

.ImportMovieTitle-year-jgmLg {
  margin-left: 5px;
  color: var(--disabledColor);
}

.ImportMovieTitle-existing-D5ROn {
  margin-left: 5px;
}

.ImportMovieSearchResult-container-qJVpj {
  display: flex;
  padding: 10px 20px;
  width: 100%;
}

  .ImportMovieSearchResult-container-qJVpj:hover {
    background-color: var(--menuItemHoverBackgroundColor);
  }

.ImportMovieSearchResult-movie-sU5P3 {
  flex: 1 0 0;
  overflow: hidden;
}

.ImportMovieSearchResult-tmdbLink-provN {

  margin-left: auto;
  color: var(--textColor);
}

.ImportMovieSearchResult-tmdbLinkIcon-h0MLC {
  margin-left: 10px;
}

.ImportMovieSelectMovie-button-U4Nux {

  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 6px 16px;
  width: 100%;
  height: 35px;
  border: 1px solid var(--inputBorderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
  box-shadow: inset 0 1px 1px var(--inputBoxShadowColor);
}

.ImportMovieSelectMovie-loading-y5_aL {
  display: inline-block;
}

.ImportMovieSelectMovie-warningIcon-afsFI {
  margin-right: 8px;
}

.ImportMovieSelectMovie-existing-U6e7U {
  margin-left: 5px;
}

.ImportMovieSelectMovie-dropdownArrowContainer-PAYpu {
  right: 16px;
}

.ImportMovieSelectMovie-contentContainer-WvtNQ {
  z-index: 2000;
  margin-top: 4px;
  /* 400px container width with 8px padding on each side */
  width: 384px;
}

.ImportMovieSelectMovie-content-tsBy1 {
  padding: 4px;
  border: 1px solid var(--inputBorderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
}

.ImportMovieSelectMovie-searchContainer-r8QJt {
  display: flex;
}

.ImportMovieSelectMovie-searchIconContainer-aGbGm {
  width: 58px;
  border: 1px solid var(--inputBorderColor);
  border-right: none;
  border-radius: 4px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  background-color: var(--searchIconContainerBackgroundColor);
  text-align: center;
  line-height: 33px;
}

.ImportMovieSelectMovie-searchInput-XcZ9w {

  border-radius: 0;
}

.ImportMovieRow-selectInput-P3dn9 {
}

.ImportMovieRow-folder-Lq7IZ {

  flex: 1 0 200px;
  line-height: 36px;
}

.ImportMovieRow-monitor-lywpQ {

  flex: 0 1 200px;
  min-width: 185px;
}

.ImportMovieRow-minimumAvailability-Z1vHe,
.ImportMovieRow-qualityProfile-b0i85 {

  flex: 0 1 250px;
  min-width: 170px;
}

.ImportMovieRow-movie-j0nJm {

  flex: 0 1 400px;
  min-width: 300px;
}

.ImportMovieRootFolderRow-link-hfOY_ {

  display: block;
}

.ImportMovieRootFolderRow-freeSpace-k1IFV,
.ImportMovieRootFolderRow-unmappedFolders-TFJw8 {

  width: 150px;
}

.ImportMovieRootFolderRow-actions-jJU6h {

  width: 45px;
}

.ImportMovieSelectFolder-header-CHXbA {
  margin-bottom: 40px;
  text-align: center;
  font-weight: 300;
  font-size: 36px;
}

.ImportMovieSelectFolder-tips-URJcj {
  font-size: 20px;
}

.ImportMovieSelectFolder-tip-x4rXX {
  font-size: 14px;
}

.ImportMovieSelectFolder-code-mZ5JV {
  font-size: 12px;
  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.ImportMovieSelectFolder-recentFolders-r9Yq9 {
  margin-top: 40px;
}

.ImportMovieSelectFolder-startImport-jZHoS {
  margin-top: 40px;
  text-align: center;
}

.ImportMovieSelectFolder-importButtonIcon-vC2RM {
  margin-right: 8px;
}

.ImportMovieSelectFolder-addErrorAlert-OTpIS {

  margin: 20px 0;
}

.NoMovie-message-TFmEh {
  margin-top: 10px;
  margin-bottom: 30px;
  text-align: center;
  font-size: 20px;
}

.NoMovie-buttonContainer-z4yY7 {
  margin-top: 20px;
  text-align: center;
}

.QueueDetails-progressBarContainer-wLM1D {
  display: flex;
  justify-content: center;
  width: 100%;
}

.CircularProgressBar-circularProgressBarContainer-m582E {
  position: relative;
  display: inline-block;
  vertical-align: top;
  text-align: center;
}

.CircularProgressBar-circularProgressBar-sVb5D {
  position: absolute;
  top: 0;
  left: 0;
  transform: rotate(-90deg);
  transform-origin: center center;
}

.CircularProgressBar-circularProgressBarText-aGfDa {
  position: absolute;
  width: 100%;
  height: 100%;
  font-weight: bold;
}

.CalendarEvent-event-P9Zg6 {
  position: relative;
  margin: 4px 2px;
  padding: 5px;
  border-bottom: 1px solid var(--calendarBorderColor);
  border-left: 4px solid var(--calendarBorderColor);
}

.CalendarEvent-underlay-I5NFH {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.CalendarEvent-overlay-jadXq {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.CalendarEvent-overlay-jadXq a,
  .CalendarEvent-overlay-jadXq button {
    pointer-events: all;
  }

.CalendarEvent-overlay-jadXq {

  position: relative;
  overflow-x: hidden;
  font-size: 12px;
}

.CalendarEvent-overlay-jadXq.colorImpaired {
    border-left-width: 5px;
  }

.CalendarEvent-info-ScXwS,
.CalendarEvent-movieInfo-iaycP {
  display: flex;
}

.CalendarEvent-movieInfo-iaycP {
  color: var(--calendarTextDim);
}

.CalendarEvent-movieTitle-Ui3GY,
.CalendarEvent-genres-YBLDV,
.CalendarEvent-eventType-t3Sl_ {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
  flex: 1 0 1px;
  margin-right: 10px;
}

.CalendarEvent-movieTitle-Ui3GY {
  color: var(--calendarTextDimAlternate);
  font-size: 14px;
}

.CalendarEvent-statusContainer-QdqhX {
  display: flex;
  align-items: center;
}

.CalendarEvent-statusContainer-QdqhX.fullColor {
    filter: var(--calendarFullColorFilter)
  }

.CalendarEvent-statusIcon-aQUSC {
  margin-left: 3px;
  cursor: default;
  pointer-events: all;
}

/*
 * Status
 */

.CalendarEvent-downloaded-aVyLe {
  border-left-color: var(--successColor) !important;
}

.CalendarEvent-downloaded-aVyLe.fullColor {
    background-color: rgba(39, 194, 76, 0.4) !important;
  }

.CalendarEvent-downloaded-aVyLe.colorImpaired {
    border-left-color: rgb(21, 213, 66) !important;
  }

.CalendarEvent-queue-tm1SZ {
  border-left-color: var(--purple) !important;
}

.CalendarEvent-queue-tm1SZ.fullColor {
    background-color: rgba(122, 67, 182, 0.4) !important;
  }

.CalendarEvent-unmonitored-vL9TJ {
  border-left-color: var(--gray) !important;
}

.CalendarEvent-unmonitored-vL9TJ.fullColor {
    background-color: rgba(173, 173, 173, 0.5) !important;
  }

.CalendarEvent-unmonitored-vL9TJ.colorImpaired {
    background: repeating-linear-gradient(45deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-unmonitored-vL9TJ.fullColor.colorImpaired {
    background: repeating-linear-gradient(45deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarEvent-missingUnmonitored-bCDJL {
  border-left-color: var(--warningColor) !important;
}

.CalendarEvent-missingUnmonitored-bCDJL.fullColor {
    background-color: rgba(255, 165, 0, 0.6) !important;
  }

.CalendarEvent-missingUnmonitored-bCDJL.colorImpaired {
    background: repeating-linear-gradient(90deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-missingUnmonitored-bCDJL.fullColor.colorImpaired {
    background: repeating-linear-gradient(90deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarEvent-missingMonitored-Jnllz {
  border-left-color: var(--dangerColor) !important;
}

.CalendarEvent-missingMonitored-Jnllz.fullColor {
    background-color: rgba(240, 80, 80, 0.6) !important;
  }

.CalendarEvent-missingMonitored-Jnllz.colorImpaired {
    border-left-color: rgb(254, 67, 67) !important;
    background: repeating-linear-gradient(90deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-missingMonitored-Jnllz.fullColor.colorImpaired {
    background: repeating-linear-gradient(90deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarEvent-continuing-zQZbf {
  border-left-color: var(--primaryColor) !important;
}

.CalendarEvent-continuing-zQZbf.fullColor {
    background-color: rgba(93, 156, 236, 0.4) !important;
  }

.CalendarEvent-continuing-zQZbf.colorImpaired {
    background: repeating-linear-gradient(90deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-continuing-zQZbf.fullColor.colorImpaired {
    background: repeating-linear-gradient(90deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.AgendaEvent-event-dWRPa {
  position: relative;
  padding: 5px;
  border-bottom: 1px solid var(--borderColor);
}

.AgendaEvent-underlay-oujnp {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AgendaEvent-underlay-oujnp:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

.AgendaEvent-overlay-YJLNf {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AgendaEvent-overlay-YJLNf a,
  .AgendaEvent-overlay-YJLNf button {
    pointer-events: all;
  }

.AgendaEvent-overlay-YJLNf {

  position: relative;
  display: flex;
  overflow-x: hidden;
  font-size: 14px;
}

.AgendaEvent-overlay-YJLNf.colorImpaired {
    border-left-width: 5px;
  }

.AgendaEvent-eventWrapper-FYVBh {
  display: flex;
  flex: 1 0 1px;
  overflow-x: hidden;
  padding-left: 6px;
  border-left-width: 4px;
  border-left-style: solid;
}

.AgendaEvent-date-bRc76 {
  flex: 0 0 250px;
  font-weight: bold;
}

.AgendaEvent-time-aMJgA {
  flex: 0 0 125px;
  margin-right: 10px;
  border: none !important;
}

.AgendaEvent-movieTitle-kmaFu,
.AgendaEvent-genres-vKT8v {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 0 1 300px;
  margin-right: 10px;
}

.AgendaEvent-releaseIcon-YQ_YK {
  margin-right: 20px;
  width: 25px;
  cursor: default;
  pointer-events: all;
}

.AgendaEvent-statusIcon-RmHma {
  margin-left: 3px;
  cursor: default;
  pointer-events: all;
}

/*
 * Status
 */

.AgendaEvent-downloaded-JseRe {
}

.AgendaEvent-queue-Gb5V4 {
}

.AgendaEvent-unmonitored-F6YTt {
}

.AgendaEvent-missingUnmonitored-OXc1m {
}

.AgendaEvent-missingMonitored-AT2TL {
}

.AgendaEvent-continuing-fDIWC {
}

@media only screen and (max-width: 768px) {
  .AgendaEvent-overlay-YJLNf {
    flex-direction: column;
  }

  .AgendaEvent-eventWrapper-FYVBh {
    display: block;
    flex: 0 0 auto;
  }

  .AgendaEvent-date-bRc76 {
    margin-left: 10px;
  }

  .AgendaEvent-date-bRc76,
  .AgendaEvent-time-aMJgA,
  .AgendaEvent-movieTitle-kmaFu {
    flex: 0 0 100%;
  }
}

.Agenda-agenda-hRnz8 {
  margin-top: 10px;
}

.CalendarEvent-event-P9Zg6 {
  position: relative;
  margin: 4px 2px;
  padding: 5px;
  border-bottom: 1px solid var(--calendarBorderColor);
  border-left: 4px solid var(--calendarBorderColor);
}

.CalendarEvent-underlay-I5NFH {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.CalendarEvent-overlay-jadXq {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.CalendarEvent-overlay-jadXq a,
  .CalendarEvent-overlay-jadXq button {
    pointer-events: all;
  }

.CalendarEvent-overlay-jadXq {

  position: relative;
  overflow-x: hidden;
  font-size: 12px;
}

.CalendarEvent-overlay-jadXq.colorImpaired {
    border-left-width: 5px;
  }

.CalendarEvent-info-ScXwS,
.CalendarEvent-movieInfo-iaycP {
  display: flex;
}

.CalendarEvent-movieInfo-iaycP {
  color: var(--calendarTextDim);
}

.CalendarEvent-movieTitle-Ui3GY,
.CalendarEvent-genres-YBLDV,
.CalendarEvent-eventType-t3Sl_ {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
  flex: 1 0 1px;
  margin-right: 10px;
}

.CalendarEvent-movieTitle-Ui3GY {
  color: var(--calendarTextDimAlternate);
  font-size: 14px;
}

.CalendarEvent-statusContainer-QdqhX {
  display: flex;
  align-items: center;
}

.CalendarEvent-statusContainer-QdqhX.fullColor {
    filter: var(--calendarFullColorFilter)
  }

.CalendarEvent-statusIcon-aQUSC {
  margin-left: 3px;
  cursor: default;
  pointer-events: all;
}

/*
 * Status
 */

.CalendarEvent-downloaded-aVyLe {
  border-left-color: var(--successColor) !important;
}

.CalendarEvent-downloaded-aVyLe.fullColor {
    background-color: rgba(39, 194, 76, 0.4) !important;
  }

.CalendarEvent-downloaded-aVyLe.colorImpaired {
    border-left-color: rgb(21, 213, 66) !important;
  }

.CalendarEvent-queue-tm1SZ {
  border-left-color: var(--purple) !important;
}

.CalendarEvent-queue-tm1SZ.fullColor {
    background-color: rgba(122, 67, 182, 0.4) !important;
  }

.CalendarEvent-unmonitored-vL9TJ {
  border-left-color: var(--gray) !important;
}

.CalendarEvent-unmonitored-vL9TJ.fullColor {
    background-color: rgba(173, 173, 173, 0.5) !important;
  }

.CalendarEvent-unmonitored-vL9TJ.colorImpaired {
    background: repeating-linear-gradient(45deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-unmonitored-vL9TJ.fullColor.colorImpaired {
    background: repeating-linear-gradient(45deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarEvent-missingUnmonitored-bCDJL {
  border-left-color: var(--warningColor) !important;
}

.CalendarEvent-missingUnmonitored-bCDJL.fullColor {
    background-color: rgba(255, 165, 0, 0.6) !important;
  }

.CalendarEvent-missingUnmonitored-bCDJL.colorImpaired {
    background: repeating-linear-gradient(90deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-missingUnmonitored-bCDJL.fullColor.colorImpaired {
    background: repeating-linear-gradient(90deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarEvent-missingMonitored-Jnllz {
  border-left-color: var(--dangerColor) !important;
}

.CalendarEvent-missingMonitored-Jnllz.fullColor {
    background-color: rgba(240, 80, 80, 0.6) !important;
  }

.CalendarEvent-missingMonitored-Jnllz.colorImpaired {
    border-left-color: rgb(254, 67, 67) !important;
    background: repeating-linear-gradient(90deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-missingMonitored-Jnllz.fullColor.colorImpaired {
    background: repeating-linear-gradient(90deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarEvent-continuing-zQZbf {
  border-left-color: var(--primaryColor) !important;
}

.CalendarEvent-continuing-zQZbf.fullColor {
    background-color: rgba(93, 156, 236, 0.4) !important;
  }

.CalendarEvent-continuing-zQZbf.colorImpaired {
    background: repeating-linear-gradient(90deg, var(--colorImpairedGradientDark), var(--colorImpairedGradientDark) 5px, var(--colorImpairedGradient) 5px, var(--colorImpairedGradient) 10px);
  }

.CalendarEvent-continuing-zQZbf.fullColor.colorImpaired {
    background: repeating-linear-gradient(90deg, rgba(244, 245, 246, 0.2), rgba(244, 245, 246, 0.2) 5px, transparent 5px, transparent 10px);
  }

.CalendarDay-day-vbHSD {
  flex: 1 0 14.28%;
  overflow: hidden;
  min-height: 70px;
  border-bottom: 1px solid var(--calendarBorderColor);
  border-left: 1px solid var(--calendarBorderColor);
}

.CalendarDay-isSingleDay-aARSn {
  width: 100%;
}

.CalendarDay-dayOfMonth-Ora3v {
  padding-right: 5px;
  border-bottom: 1px solid var(--calendarBorderColor);
  text-align: right;
}

.CalendarDay-isToday-E7jSB {
  background-color: var(--calendarTodayBackgroundColor);
}

.CalendarDay-isDifferentMonth-dYTOJ {
  color: var(--disabledColor);
}

.CalendarDays-days-bkUmr {
  display: flex;
  border-right: 1px solid var(--calendarBorderColor);
}

.CalendarDays-day-t0Mh6,
.CalendarDays-week-xFvOv,
.CalendarDays-forecast-ICEGg {
  flex-wrap: nowrap;
}

.CalendarDays-month-tpGR5 {
  flex-wrap: wrap;
}

.DayOfWeek-dayOfWeek-D4GRS {
  flex: 1 0 14.28%;
  background-color: var(--calendarBackgroundColor);
  text-align: center;
}

.DayOfWeek-isSingleDay-w4a3G {
  width: 100%;
}

.DayOfWeek-isToday-Ga8JJ {
  background-color: var(--calendarTodayBackgroundColor);
}

.DaysOfWeek-daysOfWeek-DQmbR {
  display: flex;
  margin-top: 10px;
}

.CalendarHeader-header-WC6Sy {
  display: flex;
}

.CalendarHeader-navigationButtons-T91lU {
  flex: 1 1 33%;
  text-align: left;
}

.CalendarHeader-todayButton-DLzYr {

  margin-left: 5px;
}

.CalendarHeader-titleDesktop-qugpW,
.CalendarHeader-titleMobile-IZBwa {
  text-align: center;
  font-size: 18px;
}

.CalendarHeader-titleMobile-IZBwa {
  margin-bottom: 5px;
}

.CalendarHeader-viewButtonsContainer-M0Wmk {
  display: flex;
  justify-content: flex-end;
  flex: 1 1 33%;
}

.CalendarHeader-viewMenu-Vn3qz {

  line-height: 31px;
}

.CalendarHeader-loading-krtud {

  margin-top: 5px;
  margin-right: 10px;
}

@media only screen and (max-width: 768px) {
  .CalendarHeader-navigationButtons-T91lU {
    flex: 1 0 50%;
  }

  .CalendarHeader-viewButtonsContainer-M0Wmk {
    flex: 0 0 100px;
  }
}

.Calendar-calendar-JZlK7 {
  flex-grow: 1;
  width: 100%;
}

.Calendar-calendarContent-r6xna {
  width: 100%;
}

.LegendIconItem-legendIconItem-HRUQm {
  margin-left: 6px;
}

.LegendIconItem-icon-GfrY5 {
  margin-right: 5px;
}

.LegendIconItem-icon-GfrY5.fullColorEvents {
    filter: var(--calendarFullColorFilter)
  }

.LegendItem-legendItem-MGaWB {
  margin: 3px 0;
  margin-right: 6px;
  padding-left: 5px;
  width: 220px;
  border-left-width: 4px;
  border-left-style: solid;
  cursor: default;
}

/*
 * Status
 */

.LegendItem-downloaded-PAFUG {
}

.LegendItem-queue-JlvVZ {
}

.LegendItem-unmonitored-kMf3H {
}

.LegendItem-missingUnmonitored-E291Z {
}

.LegendItem-missingMonitored-x0H_e {
}

.LegendItem-continuing-Jwnl7 {
}

.Legend-legend-wnxxq {
  display: flex;
  flex-wrap: wrap;
  margin-top: 10px;
  padding: 3px 0;
}

.AdvancedSettingsButton-button-CzL_3 {

  position: relative;
}

.AdvancedSettingsButton-labelContainer-Z90Zi {
}

.AdvancedSettingsButton-label-s3_aG {
}

.AdvancedSettingsButton-indicatorContainer-OGWLx {
  position: absolute;
  top: 10px;
  right: 12px;
}

.AdvancedSettingsButton-indicatorBackground-BAO1K {
  color: var(--themeDarkColor);
}

.AdvancedSettingsButton-enabled-iam2W {
  color: var(--successColor);
}

.AdvancedSettingsButton-disabled-QGRYt {
  color: var(--dangerColor);
}

.PageContentBody-contentBody-Hetrs {
  /* 1px for flex-basis so the div grows correctly in Edge/Firefox */
  flex: 1 0 1px;
}

.PageContentBody-innerContentBody-PtigL {
  padding: 20px;
}

@media only screen and (max-width: 768px) {
  .PageContentBody-contentBody-Hetrs {
    flex-basis: auto;
    overflow-y: hidden !important;
  }

  .PageContentBody-innerContentBody-PtigL {
    padding: 10px;
  }
}

.CalendarPage-calendarPageBody-hbV__ {

  display: flex;
}

.CalendarPage-calendarInnerPageBody-KgK5Y {

  display: flex;
  flex-direction: column;
  flex-grow: 1;
  width: 100%;
}

.CalendarPage-errorMessage-yBZTq {
  margin-top: 20px;
  text-align: center;
  font-size: 20px;
}

.PageJumpBarItem-jumpBarItem-Yz0Ev {
  flex: 1 1 25px;
  border-bottom: 1px solid var(--borderColor);
  text-align: center;
  font-weight: bold;
}

  .PageJumpBarItem-jumpBarItem-Yz0Ev:hover {
    color: #777;
  }

  .PageJumpBarItem-jumpBarItem-Yz0Ev:last-child {
    border: none;
  }

.PageJumpBar-jumpBar-NBpLl {
  z-index: 10;
  display: flex;
  align-content: stretch;
  align-items: stretch;
  align-self: stretch;
  justify-content: center;
  flex: 0 0 30px;
}

.PageJumpBar-jumpBarItems-fCD8H {
  display: flex;
  justify-content: space-around;
  flex: 0 0 100%;
  flex-direction: column;
  overflow: hidden;
}

@media only screen and (max-width: 768px) {
  .PageJumpBar-jumpBar-NBpLl {
    display: none;
  }
}

.MovieIndex-pageContentBodyWrapper-kZg9z {
  display: flex;
  flex: 1 0 1px;
  overflow: hidden;
}

.MovieIndex-errorMessage-BMksU {
  margin-top: 20px;
  text-align: center;
  font-size: 20px;
}

.MovieIndex-contentBody-aTJHY {

  position: relative;
  display: flex;
  flex-direction: column;
}

.MovieIndex-postersInnerContentBody-Y0Hw2 {

  display: flex;
  flex-direction: column;
  flex-grow: 1;

  /* 5px less padding than normal to handle poster's 5px margin */
  padding: calc(20px - 5px);
}

.MovieIndex-tableInnerContentBody-_P8Sa {

  display: flex;
  flex-direction: column;
  flex-grow: 1;
}

.MovieIndex-contentBodyContainer-lgyX0 {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
}

@media only screen and (max-width: 768px) {
  .MovieIndex-pageContentBodyWrapper-kZg9z {
    flex-basis: auto;
  }

  .MovieIndex-contentBody-aTJHY {
    flex-basis: 1px;
  }

  .MovieIndex-postersInnerContentBody-Y0Hw2 {
    padding: calc(10px - 5px);
  }
}

.CollectionFooterLabel-label-c5hyu {
  margin-bottom: 3px;
  font-weight: bold;
}

.CollectionFooterLabel-savingIcon-HvL8f {
  margin-left: 8px;
}

.CollectionFooter-inputContainer-nVAnj {
  margin-right: 20px;
  min-width: 150px;
}

.CollectionFooter-buttonContainer-M8mFY {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
}

.CollectionFooter-buttonContainerContent-c1518 {
  flex-grow: 0;
}

.CollectionFooter-buttons-e_eL9 {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
}

.CollectionFooter-addSelectedButton-ALv8N {

  margin-right: 10px;
  height: 35px;
}

.CollectionFooter-excludeSelectedButton-GLHS3 {

  margin-left: 25px;
  height: 35px;
}

@media only screen and (max-width: 768px) {
  .CollectionFooter-inputContainer-nVAnj {
    margin-right: 0;
  }

  .CollectionFooter-buttonContainer-M8mFY {
    justify-content: flex-start;
  }

  .CollectionFooter-buttonContainerContent-c1518 {
    flex-grow: 1;
  }

  .CollectionFooter-buttons-e_eL9 {
    justify-content: space-between;
  }

  .CollectionFooter-selectedMovieLabel-gyP1E {
    text-align: left;
  }
}

.NoMovieCollections-message-bQd35 {
  margin-top: 10px;
  margin-bottom: 30px;
  text-align: center;
  font-size: 20px;
}

.NoMovieCollections-buttonContainer-Hlf93 {
  margin-top: 20px;
  text-align: center;
}

.EditMovieCollectionModalContent-container-kPaGf {
  display: flex;
}

.EditMovieCollectionModalContent-poster-M1FG0 {
  flex: 0 0 170px;
  margin-right: 20px;
  height: 250px;
}

.EditMovieCollectionModalContent-info-RzgsJ {
  flex-grow: 1;
}

.EditMovieCollectionModalContent-overview-QBrTO {
  margin-bottom: 30px;
}

.MonitorToggleButton-toggleButton-fG17x {

  padding: 0;
  font-size: inherit;
}

  .MonitorToggleButton-toggleButton-fG17x.MonitorToggleButton-isDisabled-XFERN {
    color: var(--disabledColor);
    cursor: not-allowed;
  }

.AddNewMovieCollectionMovieModalContent-container-M4LeN {
  display: flex;
}

.AddNewMovieCollectionMovieModalContent-year-epQaY {
  margin-left: 5px;
  color: var(--disabledColor);
}

.AddNewMovieCollectionMovieModalContent-poster-wiNVa {
  flex: 0 0 170px;
  margin-right: 20px;
  height: 250px;
}

.AddNewMovieCollectionMovieModalContent-info-VCS39 {
  flex-grow: 1;
}

.AddNewMovieCollectionMovieModalContent-overview-RLvqv {
  margin-bottom: 30px;
}

.AddNewMovieCollectionMovieModalContent-labelIcon-ta9_q {
  margin-left: 8px;
}

.AddNewMovieCollectionMovieModalContent-searchForMissingMovieLabelContainer-uJFI8 {
  display: flex;
  margin-top: 2px;
}

.AddNewMovieCollectionMovieModalContent-searchForMissingMovieLabel-NddNZ {
  margin-right: 8px;
  font-weight: normal;
}

.AddNewMovieCollectionMovieModalContent-searchForMissingMovieContainer-FZLNt {

  flex: 0 1 0;
}

.AddNewMovieCollectionMovieModalContent-searchForMissingMovieInput-fkKzM {

  margin-top: 0;
}

.AddNewMovieCollectionMovieModalContent-modalFooter-fRD4z {
}

.AddNewMovieCollectionMovieModalContent-addButton-GHhhR {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
}

@media only screen and (max-width: 768px) {
  .AddNewMovieCollectionMovieModalContent-modalFooter-fRD4z {
    display: block;
    text-align: center;
  }

  .AddNewMovieCollectionMovieModalContent-addButton-GHhhR {
    margin-top: 10px;
  }
}

.MoveMovieModal-doNotMoveButton-xsdqk {

  margin-right: auto;
}

.MoveMovieModal-folderRenameMessage-XXweg {
  margin-top: 20px;
}

.EditMovieModalContent-deleteButton-X9KbL {

  margin-right: auto;
}

.EditMovieModalContent-labelIcon-GGj6W {
  margin-left: 8px;
}

.MonitorToggleButton-toggleButton-fG17x {

  padding: 0;
  font-size: inherit;
}

  .MonitorToggleButton-toggleButton-fG17x.MonitorToggleButton-isDisabled-XFERN {
    color: var(--disabledColor);
    cursor: not-allowed;
  }

.CollectionMovie-content-XbVZ3 {
  border-radius: 5px;
  transition: all 200ms ease-in;
}

  .CollectionMovie-content-XbVZ3:hover {
    z-index: 2;
    box-shadow: 0 0 10px var(--black);
    transition: all 200ms ease-in;
  }

  .CollectionMovie-content-XbVZ3:hover .CollectionMovie-poster-QJEDb,
    .CollectionMovie-content-XbVZ3:hover .CollectionMovie-overlayTitle-SKEyv {
      opacity: 0.5;
      transition: opacity 100ms linear 100ms;
    }

  .CollectionMovie-content-XbVZ3:hover .CollectionMovie-overlayHoverTitle-FFxjU {
      opacity: 1;
      transition: opacity 100ms linear 100ms;
    }

.CollectionMovie-posterContainer-nQcY0 {
  position: relative;
}

.CollectionMovie-poster-QJEDb {
  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.CollectionMovie-overlayTitle-SKEyv {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 5px;
  width: 100%;
  height: 100%;
  color: var(--offWhite);
  text-align: center;
  font-size: 20px;
}

.CollectionMovie-overlayHover-__fVT {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  justify-content: flex-end;
  flex-direction: column;
  width: 100%;
  height: 100%;
}

.CollectionMovie-overlayHoverTitle-FFxjU {
  padding: 5px;
  color: var(--offWhite);
  text-align: center;
  font-weight: bold;
  font-size: 15px;
  opacity: 0;
  transition: opacity 0;
}

.CollectionMovie-title-TodUA {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  background-color: #fafbfc;
  text-align: center;
  font-size: 12px;
}

.CollectionMovie-controls-i0BlJ {
  position: absolute;
  bottom: 10px;
  left: 10px;
  z-index: 3;
  border-radius: 4px;
  background-color: #707070;
  color: var(--white);
  font-size: 12px;
  opacity: 0;
  transition: opacity 0;
}

.CollectionMovie-action-VY4SI {
}

.CollectionMovie-action-VY4SI:hover {
    color: var(--radarrYellow);
  }

@media only screen and (max-width: 768px) {
  .CollectionMovie-container-Sp_Xl {
    padding: 5px;
  }
}

.CollectionMovie-editorSelect-vnBEf {
  position: absolute;
  top: 10px;
  z-index: 3;
}

.CollectionMovie-externalLinks-xuJhQ {
  margin-left: 0.5em;
}

.CollectionMovie-link-KEWK5 {

  position: relative;
  display: block;
  background-color: var(--black);
}

.CollectionMovie-monitorToggleButton-JOR0r {

  width: 25px;
  color: var(--white);
}

.CollectionMovie-monitorToggleButton-JOR0r:hover {
    color: var(--iconButtonHoverLightColor);
  }

.CollectionMovie-excluded-JEY4Q {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  width: 0;
  height: 0;
  border-width: 0 25px 25px 0;
  border-style: solid;
  border-color: transparent var(--dangerColor) transparent transparent;
  color: var(--white);
}

.CollectionMovieLabel-movie-BazsZ {
  display: flex;
  align-items: stretch;
  overflow: hidden;
  margin: 2px 4px;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
  cursor: default;
}

.CollectionMovieLabel-movieTitle-rC4bb {
  padding: 0 4px;
}

.CollectionMovieLabel-movieStatus-bZlk1 {
  padding: 0 4px;
  border-left: 4px;
  border-left-style: solid;
  background-color: var(--themeLightColor);
  color: var(--defaultColor);
}

.CollectionMovieLabel-primary-s1ZqO {
  border-color: var(--primaryColor);
}

.CollectionMovieLabel-danger-mrKyC {
  border-color: var(--dangerColor);
}

.CollectionMovieLabel-success-Gas3N {
  border-color: var(--successColor);
}

.CollectionMovieLabel-purple-njfAW {
  border-color: var(--purple);
}

.CollectionMovieLabel-warning-Hjfwp {
  border-color: var(--warningColor);
}

.CollectionMovieLabel-info-CJVKQ {
  border-color: var(--infoColor);
}

.CollectionMovieLabel-queue-Kx3x6 {
  border-color: var(--queueColor);
}

.CollectionOverview-content-xqP_l {
  display: flex;
  flex-grow: 1;
}

.CollectionOverview-editorSelect-GccR4 {
  position: relative;
  top: 0;
  left: 5px;
}

.CollectionOverview-titleRow-rae5e {
  position: relative;
  display: flex;
  justify-content: space-between;
  flex: 0 0 auto;
}

.CollectionOverview-toggleMonitoredContainer-QG1jp {
  align-self: center;
  margin-right: 10px;
}

.CollectionOverview-titleContainer-IZa8T {
  display: flex;
  margin-bottom: 5px;
}

.CollectionOverview-sliderContainer-zoakQ {
  display: block;
}

.CollectionOverview-labelsContainer-PMeTT {
  display: flex;
  flex-wrap: wrap;
}

.CollectionOverview-moviesContainer-iCe0Q {
  margin-bottom: 5px;
}

.CollectionOverview-movie-TOnrJ {
  padding: 7px;
}

.CollectionOverview-info-paK6X {
  display: flex;
  flex: 1 0 1px;
  flex-direction: column;
  overflow: hidden;
  padding-left: 10px;
}

.CollectionOverview-title-pBksD {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  font-weight: 300;
  font-size: 30px;
  line-height: 40px;
}

.CollectionOverview-actions-XaV4J {
  white-space: nowrap;
}

.CollectionOverview-details-XnbEq {
  display: flex;
  justify-content: space-between;
  flex: 1 0 auto;
  margin-bottom: 5px;
}

.CollectionOverview-defaults-O3j4x {
  margin-bottom: 5px;
  font-weight: 300;
  font-size: 20px;
}

.CollectionOverview-detailsLabel-yefRJ {

  margin: 5px 10px 5px 0;
}

.CollectionOverview-path-fOgv_,
.CollectionOverview-status-_6Mva,
.CollectionOverview-genres-okLMR,
.CollectionOverview-qualityProfileName-jVFTZ {
  margin-left: 8px;
  font-weight: 300;
  font-size: 15px;
}

.CollectionOverview-overview-_0zq2 {
  overflow: hidden;
  min-height: 0;
}

.CollectionOverview-monitorToggleButton-gixGl {

  width: 25px;
}

.CollectionOverview-monitorToggleButton-gixGl:hover {
    color: var(--iconButtonHoverLightColor);
  }

@media only screen and (max-width: 768px) {
  .CollectionOverview-navigationButtons-iEbkN {
    display: none;
  }

  .CollectionOverview-title-pBksD {
    overflow: hidden !important;
    max-width: 100%;
    /* 1 */
    text-overflow: ellipsis !important;
    white-space: nowrap !important;

    font-weight: 300;
    font-size: 22px;
  }

  .CollectionOverview-toggleMonitoredContainer-QG1jp {
    align-self: center;
    margin-right: 5px;
  }

  .CollectionOverview-monitorToggleButton-gixGl {

    width: 20px;
  }

    .CollectionOverview-monitorToggleButton-gixGl:hover {
      color: var(--iconButtonHoverLightColor);
    }
}

.CollectionOverviews-grid-O3z4k {
  flex: 1 0 auto;
}

.CollectionOverviews-container-CtRkv:hover .CollectionOverviews-content-E_Y_Q {
      background-color: var(--tableRowHoverBackgroundColor);
    }

.CollectionOverviews-externalLinks-lpjqw {
  margin-right: 0.5em;
}

.NotFound-container-fJ0iq {
  text-align: center;
}

.NotFound-message-Qdgw5 {
  margin: 50px 0;
  text-align: center;
  font-weight: 300;
  font-size: 36px;
}

.NotFound-image-FkW9i {
  height: 350px;
}

.DiscoverMovieFooterLabel-label-Kw8RF {
  margin-bottom: 3px;
  font-weight: bold;
}

.DiscoverMovieFooterLabel-savingIcon-lOnOm {
  margin-left: 8px;
}

.ExcludeMovieModalContent-pathContainer-Y0TaL {
  margin-bottom: 20px;
}

.ExcludeMovieModalContent-pathIcon-i1hDd {
  margin-right: 8px;
}

.ExcludeMovieModalContent-deleteFilesMessage-ldhoa {
  margin-top: 20px;
  color: var(--dangerColor);
}

.DiscoverMovieFooter-inputContainer-opAGW {
  margin-right: 20px;
  min-width: 150px;
}

.DiscoverMovieFooter-buttonContainer-EC3Q4 {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
}

.DiscoverMovieFooter-buttonContainerContent-NK0yA {
  flex-grow: 0;
}

.DiscoverMovieFooter-buttons-LRPjD {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
}

.DiscoverMovieFooter-addSelectedButton-DKkMy {

  margin-right: 10px;
  height: 35px;
}

.DiscoverMovieFooter-excludeSelectedButton-jTFAd {

  margin-left: 25px;
  height: 35px;
}

@media only screen and (max-width: 768px) {
  .DiscoverMovieFooter-inputContainer-opAGW {
    margin-right: 0;
  }

  .DiscoverMovieFooter-buttonContainer-EC3Q4 {
    justify-content: flex-start;
  }

  .DiscoverMovieFooter-buttonContainerContent-NK0yA {
    flex-grow: 1;
  }

  .DiscoverMovieFooter-buttons-LRPjD {
    justify-content: space-between;
  }

  .DiscoverMovieFooter-selectedMovieLabel-JJ3HT {
    text-align: left;
  }
}

.NoDiscoverMovie-message-EwCya {
  margin-top: 10px;
  margin-bottom: 30px;
  text-align: center;
  font-size: 20px;
}

.NoDiscoverMovie-buttonContainer-N_Xqp {
  margin-top: 20px;
  text-align: center;
}

.ImportListList-lists-lAKKb {
  flex: 1 0 auto;
}

.DiscoverMovieOverviewInfoRow-infoRow-r_Otk {
  flex: 0 0 21px;
  margin: 2px 0;
}

.DiscoverMovieOverviewInfoRow-icon-Sr2lC {
  margin-right: 5px;
  width: 25px !important;
  text-align: center;
}

.DiscoverMovieOverviewInfo-infos-obnt7 {
  display: flex;
  flex: 0 0 250px;
  flex-direction: column;
  margin-left: 10px;
}

@media only screen and (max-width: 768px) {
  .DiscoverMovieOverviewInfo-infos-obnt7 {
    margin-left: 0;
  }
}

.DiscoverMovieOverview-content-y0iAo {
  display: flex;
  flex-grow: 1;
}

.DiscoverMovieOverview-poster-V_bvd {
  position: relative;
}

.DiscoverMovieOverview-editorSelect-Wx2rZ {
  position: absolute;
  top: 0;
  left: 5px;
  z-index: 3;
}

.DiscoverMovieOverview-posterContainer-MY3Ek {
  position: relative;
}

.DiscoverMovieOverview-link-PO5ln {

  display: block;
  color: var(--defaultColor);
}

.DiscoverMovieOverview-link-PO5ln:hover {
    color: var(--defaultColor);
    text-decoration: none;
  }

.DiscoverMovieOverview-alreadyExistsIcon-Jck5V {
  margin-left: 10px;
  color: #37bc9b;
  pointer-events: all;
}

.DiscoverMovieOverview-exclusionIcon-fdSwl {
  margin-left: 10px;
  color: var(--dangerColor);
  pointer-events: all;
}

.DiscoverMovieOverview-info-bDkFm {
  display: flex;
  flex: 1 0 1px;
  flex-direction: column;
  overflow: hidden;
  padding-left: 10px;
}

.DiscoverMovieOverview-titleRow-q3vcV {
  display: flex;
  justify-content: space-between;
  flex: 0 0 auto;
  margin-bottom: 5px;
  line-height: 32px;
}

.DiscoverMovieOverview-lists-WOejv {
  display: flex;
  margin-bottom: 5px;
}

.DiscoverMovieOverview-title-i1myl {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 1 0 1px;
  font-weight: 300;
  font-size: 30px;
  line-height: 1;
}

.DiscoverMovieOverview-actions-t8eRr {
  white-space: nowrap;
}

.DiscoverMovieOverview-details-t95cY {
  display: flex;
  justify-content: space-between;
  flex: 1 0 auto;
}

.DiscoverMovieOverview-overviewContainer-z1clK {
  display: flex;
  justify-content: space-between;
  flex: 0 1 1000px;
  flex-direction: column;
}

.DiscoverMovieOverview-overview-hMIdL {

  overflow: hidden;
  min-height: 0;
}

@media only screen and (max-width: 768px) {
  .DiscoverMovieOverview-overview-hMIdL {
    display: none;
  }
}

.DiscoverMovieOverviews-grid-sBFCM {
  flex: 1 0 auto;
}

.DiscoverMovieOverviews-container-tF68u:hover .DiscoverMovieOverviews-content-Dc2ZP {
      background-color: var(--tableRowHoverBackgroundColor);
    }

.DiscoverMovieOverviews-externalLinks-gsHz8 {
  margin-right: 0.5em;
}

.RottenTomatoRating-wrapper-Wt1w5 {
  display: inline-block;
}

.RottenTomatoRating-image-HoF9G {
  align-content: center;
  margin-right: 5px;
  vertical-align: -0.125em;
}

.TraktRating-wrapper-JOPcO {
  display: inline-block;
}

.TraktRating-image-seN4U {
  align-content: center;
  margin-right: 5px;
  vertical-align: -0.125em;
}

.DiscoverMoviePosterInfo-info-Y2wbw {
  background-color: var(--movieBackgroundColor);
  text-align: center;
  font-size: 12px;
}

.DiscoverMoviePoster-content-qeiIu {
  transition: all 200ms ease-in;
}

  .DiscoverMoviePoster-content-qeiIu:hover {
    z-index: 2;
    box-shadow: 0 0 12px var(--black);
    transition: all 200ms ease-in;
  }

  .DiscoverMoviePoster-content-qeiIu:hover .DiscoverMoviePoster-controls-xTZNb {
      opacity: 0.9;
      transition: opacity 200ms linear 150ms;
    }

.DiscoverMoviePoster-posterContainer-FwYfa {
  position: relative;
}

.DiscoverMoviePoster-link-I0PH3 {

  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.DiscoverMoviePoster-externalLinks-lareh {
  margin-right: 0.5em;
  margin-left: 0.5em;
}

.DiscoverMoviePoster-overlayTitle-y2osW {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 5px;
  width: 100%;
  height: 100%;
  color: var(--offWhite);
  text-align: center;
  font-size: 20px;
}

.DiscoverMoviePoster-title-GxC81 {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  background-color: var(--movieBackgroundColor);
  text-align: center;
  font-size: 12px;
}

.DiscoverMoviePoster-excluded-bDxaG {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  width: 0;
  height: 0;
  border-width: 0 25px 25px 0;
  border-style: solid;
  border-color: transparent var(--dangerColor) transparent transparent;
  color: var(--white);
}

.DiscoverMoviePoster-existing-nxeR9 {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1;
  width: 0;
  height: 0;
  border-width: 25px 25px 0 0;
  border-style: solid;
  border-color: #37bc9b transparent transparent;
  color: var(--white);
}

.DiscoverMoviePoster-controls-xTZNb {
  position: absolute;
  bottom: 10px;
  left: 10px;
  z-index: 3;
  border-radius: 4px;
  background-color: #707070;
  color: var(--white);
  font-size: 12px;
  opacity: 0;
  transition: opacity 0;
}

.DiscoverMoviePoster-editorSelect-rlsR2 {
  position: absolute;
  top: 10px;
  left: 10px;
  z-index: 3;
}

.DiscoverMoviePoster-action-QxZVO {
}

.DiscoverMoviePoster-action-QxZVO:hover {
    color: var(--radarrYellow);
  }

@media only screen and (max-width: 768px) {
  .DiscoverMoviePoster-container-EOUP3 {
    padding: 5px;
  }
}

.DiscoverMoviePosters-grid-LsiJ6 {
  flex: 1 0 auto;
}

.DiscoverMovieHeader-status-UboHT {

  flex: 0 0 30px;
}

.DiscoverMovieHeader-collection-Q4Q4W,
.DiscoverMovieHeader-sortTitle-JUIJD {

  flex: 4 0 110px;
}

.DiscoverMovieHeader-studio-oBqwP {

  flex: 2 0 90px;
}

.DiscoverMovieHeader-inCinemas-sVOOL,
.DiscoverMovieHeader-physicalRelease-BI9OR,
.DiscoverMovieHeader-digitalRelease-D6CnQ,
.DiscoverMovieHeader-genres-x_T7P {

  flex: 0 0 180px;
}

.DiscoverMovieHeader-originalLanguage-Uyq4J {

  flex: 1 0 125px;
}

.DiscoverMovieHeader-tmdbRating-wr8RA,
.DiscoverMovieHeader-imdbRating-onA1W,
.DiscoverMovieHeader-rottenTomatoesRating-KVygl,
.DiscoverMovieHeader-traktRating-GBuG4,
.DiscoverMovieHeader-runtime-Vgs5s,
.DiscoverMovieHeader-year-w70T5 {

  flex: 0 0 90px;
}

.DiscoverMovieHeader-popularity-OmtFF {

  flex: 0 0 100px;
}

.DiscoverMovieHeader-lists-okF78 {

  flex: 1 0 110px;
}

.DiscoverMovieHeader-certification-BOJ3p {

  flex: 0 0 115px;
}

.DiscoverMovieHeader-isTrending-TGfQO,
.DiscoverMovieHeader-isPopular-BSuU1,
.DiscoverMovieHeader-isRecommendation-OWFMy {

  flex: 0 0 30px;
}

.DiscoverMovieHeader-actions-DvRUL {

  flex: 0 1 90px;
}

.MoviePopularityIndex-popularityIcon-bUKfw {
  margin-right: 2px;
  width: 12px !important;
  text-align: center;
}
.ListMovieStatusCell-statusIcon-JOOwq {
  width: 20px !important;
}

.DiscoverMovieRow-cell-lqMNK {

  display: flex;
  align-items: center;
}

.DiscoverMovieRow-status-_rK5V {

  flex: 0 0 30px;
}

.DiscoverMovieRow-alreadyExistsIcon-WDAS0 {
  width: 20px !important;
  color: #37bc9b;
  pointer-events: all;
}

.DiscoverMovieRow-exclusionIcon-GW08o {
  width: 20px !important;
  color: var(--dangerColor);
  pointer-events: all;
}

.DiscoverMovieRow-collection-SzzEb,
.DiscoverMovieRow-sortTitle-hkM66 {

  flex: 4 0 110px;
}

.DiscoverMovieRow-studio-zvXyl {

  flex: 2 0 90px;
}

.DiscoverMovieRow-inCinemas-m525l,
.DiscoverMovieRow-physicalRelease-UgQxp,
.DiscoverMovieRow-digitalRelease-X1Ewg,
.DiscoverMovieRow-genres-ngcRl {

  flex: 0 0 180px;
}

.DiscoverMovieRow-certification-Q6B_i {

  flex: 0 0 115px;
}

.DiscoverMovieRow-originalLanguage-kmnG4 {

  flex: 1 0 125px;
}

.DiscoverMovieRow-tmdbRating-pCf_s,
.DiscoverMovieRow-imdbRating-pnuo9,
.DiscoverMovieRow-rottenTomatoesRating-MDyaF,
.DiscoverMovieRow-traktRating-RO8wC,
.DiscoverMovieRow-runtime-Tkn3Z,
.DiscoverMovieRow-year-s4hle {

  flex: 0 0 90px;
}

.DiscoverMovieRow-popularity-wvz4I {

  flex: 0 0 100px;
}

.DiscoverMovieRow-lists-l0TTt {

  flex: 1 0 110px;
}

.DiscoverMovieRow-isTrending-UoBzW,
.DiscoverMovieRow-isPopular-FqUfi,
.DiscoverMovieRow-isRecommendation-qNCsh {

  flex: 0 0 30px;
}

.DiscoverMovieRow-actions-StBgv {

  flex: 0 1 90px;
  min-width: 60px;
}

.DiscoverMovieRow-checkInput-UBjI7 {

  margin-top: 0;
}

.DiscoverMovieRow-statusIcon-TBMFP {
  width: 20px !important;
  text-align: center;
}

.DiscoverMovieRow-externalLinks-QqrBd {
  margin-right: 0.5em;
}

.VirtualTable-tableContainer-MHSuC {
  width: 100%;
}

.VirtualTable-tableBodyContainer-W0ddE {
  position: relative;
}

.DiscoverMovieTable-tableContainer-ckAxc {

  flex: 1 0 auto;
}

.InfoLabel-label-Wzh9H {
  display: inline-block;
  margin: 2px;
  color: var(--white);
  /** text-align: center; **/
  white-space: nowrap;
  line-height: 1;
  cursor: default;
}

.InfoLabel-name-NH4Ts {
  margin-bottom: 2px;
  color: var(--helpTextColor);
  font-size: 10px;
}

/** Kinds **/

.InfoLabel-default-E_bcO {
  color: inherit;
}

/** Sizes **/

.InfoLabel-small-IGdqv {
  padding: 1px 3px;
  font-size: 11px;
}

.InfoLabel-medium-F0bfF {
  padding: 2px 5px;
  font-size: 12px;
}

.InfoLabel-large-nQsou {
  padding: 3px 7px;
  font-size: 14px;
}

/** Outline **/

.InfoLabel-outline-cJaK3 {
  background-color: var(--white);
}

.DeleteMovieModalContent-pathContainer-kO_OD {
  margin-bottom: 20px;
}

.DeleteMovieModalContent-pathIcon-GH7e9 {
  margin-right: 8px;
}

.DeleteMovieModalContent-folderPath-uwV2T {
  font-weight: bold;
  font-family: var(--defaultFontFamily);
}

.DeleteMovieModalContent-deleteFilesMessage-s6kFt {
  margin-top: 20px;
  color: var(--dangerColor);
}

.DeleteMovieModalContent-deleteFilesMessage-s6kFt .DeleteMovieModalContent-deleteCount-G40bz {
    margin-top: 20px;
    color: var(--warningColor);
  }

.MovieHistoryRow-actions-SVCD3 {

  min-width: 70px;
}

.MovieHistoryRow-sourceTitle-x2TjG {

  word-break: break-word;
}

.MovieHistoryRow-customFormatScore-azPE4 {

  width: 55px;
}

.MovieCollectionLabel-monitorToggleButton-jkuXb {

  width: 15px;
}

  .MovieCollectionLabel-monitorToggleButton-jkuXb:hover {
    color: var(--iconButtonHoverLightColor);
  }

.PageMenuButton-menuButton-xRzLO {

  position: relative;
}

  .PageMenuButton-menuButton-xRzLO:hover {
    color: #666;
  }

.PageMenuButton-indicatorContainer-POVDu {
  position: absolute;
  top: 10px;
  left: 10px;
}

.PageMenuButton-label-Jm2ou {
  margin-left: 5px;
}

.SelectDownloadClientRow-downloadClient-xQOZi {
  display: flex;
  justify-content: space-between;
  padding: 8px;
  border-bottom: 1px solid var(--borderColor);
}

.OverrideMatchData-link-PKQNa {

  width: 100%;
}

.OverrideMatchData-placeholder-mDuC1 {
  display: inline-block;
  margin: -2px 0;
  width: 100%;
  outline: 2px dashed var(--dangerColor);
  outline-offset: -2px;
}

.OverrideMatchData-optional-YwTls {
  outline: 2px dashed var(--gray);
}

.OverrideMatchModalContent-label-ydHUJ {

  cursor: pointer;
}

.OverrideMatchModalContent-item-ASVat {
  display: block;
  margin-bottom: 5px;
  margin-left: 50px;
}

.OverrideMatchModalContent-footer-MpAPK {

  display: flex;
  justify-content: space-between;
  overflow: hidden;
}

.OverrideMatchModalContent-error-aKJAK {
  margin-right: 20px;
  color: var(--dangerColor);
  word-break: break-word;
}

.OverrideMatchModalContent-buttons-r21Pi {
  display: flex;
}

@media only screen and (max-width: 768px) {
  .OverrideMatchModalContent-item-ASVat {
    margin-left: 0;
  }

  .OverrideMatchModalContent-footer-MpAPK {
    display: block;
  }

  .OverrideMatchModalContent-error-aKJAK {
    margin-right: 0;
    margin-bottom: 10px;
  }

  .OverrideMatchModalContent-buttons-r21Pi {
    justify-content: space-between;
    flex-grow: 1;
  }
}

.InteractiveSearchRow-protocol-b6LO7 {

  width: 80px;
}

.InteractiveSearchRow-titleContent-U2HxT {
  display: flex;
  align-items: center;
  justify-content: space-between;
  word-break: break-all;
}

.InteractiveSearchRow-indexer-d6vdv {

  width: 85px;
}

.InteractiveSearchRow-quality-Dfyom,
.InteractiveSearchRow-languages-O4K6A {
}

.InteractiveSearchRow-quality-Dfyom {
  white-space: nowrap;
}

.InteractiveSearchRow-languages-O4K6A {
  width: 100px;
}

.InteractiveSearchRow-customFormatScore-_bMLv {

  width: 55px;
  font-weight: bold;
  cursor: default;
}

.InteractiveSearchRow-rejected-Zg0fy,
.InteractiveSearchRow-indexerFlags-WmlTF {

  width: 50px;
}

.InteractiveSearchRow-age-_Al2v,
.InteractiveSearchRow-size-gI6mO {

  white-space: nowrap;
}

.InteractiveSearchRow-peers-KAl97 {

  width: 75px;
}

.InteractiveSearchRow-history-eOHwm {

  width: 75px;
}

.InteractiveSearchRow-blocklist-DkIKc {
  margin-left: 5px;
}

.InteractiveSearchRow-download-VeAgn {

  width: 80px;
}

.InteractiveSearchRow-manualDownloadContent-Akkjh {
  position: relative;
  display: inline-block;
  margin: 0 2px;
  width: 22px;
  height: 20.39px;
  vertical-align: middle;
  line-height: 20.39px;
}

.InteractiveSearchRow-manualDownloadContent-Akkjh:hover {
    color: var(--iconButtonHoverColor);
  }

.InteractiveSearchRow-interactiveIcon-LzVGJ {
  position: absolute;
  top: 4px;
  left: 0;
  /* width: 100%; */
  text-align: center;
}

.InteractiveSearchRow-downloadIcon-Yb6Yj {
  position: absolute;
  top: 7px;
  left: 8px;
  /* width: 100%; */
  text-align: center;
}

.InteractiveSearch-filterMenuContainer-fP7Zp {
  display: flex;
  justify-content: flex-end;
  margin-bottom: 10px;
}

.InteractiveSearch-alert-Ccmqf {

  margin-top: 10px;
}

.MovieFileRowCellPlaceholder-placeholder-nYldU {
  display: inline-block;
  margin: -8px 0;
  width: 100%;
  height: 25px;
  border: 2px dashed var(--dangerColor);
}

.MovieFileEditorRow-relativePath-VWAkB {

  word-break: break-all;
}

.MovieFileEditorRow-quality-wGizK,
.MovieFileEditorRow-formats-MHJ_Z,
.MovieFileEditorRow-language-E46u2 {
}

.MovieFileEditorRow-language-E46u2 {
  width: 100px;
}

.MovieFileEditorRow-rejected-sCkJa,
.MovieFileEditorRow-download-b316f {

  width: 50px;
}

.MovieFileEditorRow-age-v7eVu,
.MovieFileEditorRow-size-oBzPx {

  white-space: nowrap;
}

.MovieFileEditorRow-languages-Fwzrf,
.MovieFileEditorRow-audio-_yut7,
.MovieFileEditorRow-video-lV3Hv,
.MovieFileEditorRow-actions-u1W2r {

  width: 100px;
}

.MovieFileEditorRow-audioLanguages-jpxm8,
.MovieFileEditorRow-videoDynamicRangeType-AHI4G,
.MovieFileEditorRow-subtitles-GpLj3 {

  width: 165px;
}

.MovieFileEditorRow-releaseGroup-i5gAc,
.MovieFileEditorRow-dateAdded-NRyoi {

  width: 120px;
}

.MovieFileEditorRow-customFormatScore-w4f7e {

  width: 55px;
}

.MovieFileEditorRow-indexerFlags-Ittgy {

  width: 50px;
}

.MovieFileEditorTableContent-actions-BKq0h {
  display: flex;
  margin-right: auto;
}

.MovieFileEditorTableContent-selectInput-scRNf {
  margin-left: 10px;
}

.MovieFileEditorTableContent-blankpad-sYscw {
  padding-top: 10px;
  padding-bottom: 10px;
  padding-left: 2em;
}

.MovieFileEditorTable-container-_tNir {
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
}

  .MovieFileEditorTable-container-_tNir:last-of-type {
    margin-bottom: 0;
  }

.ExtraFileRow-relativePath-uC88V {

  word-break: break-all;
}

.ExtraFileRow-extension-ObLTn,
.ExtraFileRow-type-ctZ36 {
}

.ExtraFileTableContent-actions-u9vkA {
  display: flex;
  margin-right: auto;
}

.ExtraFileTableContent-blankpad-JlcGd {
  padding-top: 10px;
  padding-bottom: 10px;
  padding-left: 2em;
}

.ExtraFileTable-container-qahaK {
  margin-top: 20px;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
}

  .ExtraFileTable-container-qahaK:last-of-type {
    margin-bottom: 0;
  }

.OrganizePreviewRow-row-rLTEj {
  display: flex;
  margin-bottom: 5px;
  padding: 5px 0;
  border-bottom: 1px solid var(--borderColor);
}

  .OrganizePreviewRow-row-rLTEj:last-of-type {
    margin-bottom: 0;
    padding-bottom: 0;
    border-bottom: none;
  }

.OrganizePreviewRow-selectedContainer-IbbiT {
  margin-right: 30px;
}

.OrganizePreviewRow-path-H586p {
  margin-left: 10px;
}

.OrganizePreviewModalContent-path-yhz8C {
  margin-left: 5px;
  font-weight: bold;
}

.OrganizePreviewModalContent-standardMovieFormat-fIzfY {
  margin-left: 5px;
  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.OrganizePreviewModalContent-previews-QQ9Ez {
  margin-top: 10px;
}

.OrganizePreviewModalContent-selectAllInputContainer-utcdu {
  margin-right: auto;
  line-height: 30px;
}

.OrganizePreviewModalContent-selectAllInput-w6Apl {

  margin: 0;
}

.MovieCreditPosters-grid-pGCER {
  flex: 1 0 auto;
}

.MovieCreditPosters-movie-uq5V8 {
  padding: 10px;
}

.MovieCreditPosters-container-BJcMS {
  padding: 10px;
}

.MovieCreditPosters-sliderContainer-OcqiL {
  --swiper-navigation-color: var(--white);

  display: block;
}

.EditImportListModalContent-deleteButton-snrok {

  margin-right: auto;
}

.EditImportListModalContent-labelIcon-tJxZ5 {
  margin-left: 8px;
}

.EditImportListModalContent-message-mgth4 {

  margin-bottom: 30px;
}

.MovieCreditPoster-content-mqrYr {
  transition: all 200ms ease-in;
}

  .MovieCreditPoster-content-mqrYr:hover {
    z-index: 2;
    box-shadow: 0 0 12px var(--black);
    transition: all 200ms ease-in;
  }

  .MovieCreditPoster-content-mqrYr:hover .MovieCreditPoster-controls-_H23m {
      opacity: 0.9;
      transition: opacity 200ms linear 150ms;
    }

.MovieCreditPoster-posterContainer-jElSL {
  position: relative;
}

.MovieCreditPoster-poster-YHOqS {
  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.MovieCreditPoster-overlayTitle-sMK62 {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 5px;
  width: 100%;
  height: 100%;
  color: var(--offWhite);
  text-align: center;
  font-size: 20px;
}

.MovieCreditPoster-title-wArQs {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  background-color: var(--movieBackgroundColor);
  text-align: center;
  font-size: 12px;
}

.MovieCreditPoster-toggleMonitoredContainer-u8_75 {
  position: absolute;
  top: 10px;
  z-index: 3;
}

.MovieCreditPoster-monitorToggleButton-x4fK5 {

  width: 25px;
  color: var(--white);
}

.MovieCreditPoster-monitorToggleButton-x4fK5:hover {
    color: var(--iconButtonHoverLightColor);
  }

.MovieCreditPoster-controls-_H23m {
  position: absolute;
  bottom: 10px;
  left: 10px;
  z-index: 3;
  border-radius: 4px;
  background-color: #707070;
  color: var(--white);
  font-size: 12px;
  opacity: 0;
  transition: opacity 0;
}

.MovieCreditPoster-action-Eym2S {
}

.MovieCreditPoster-action-Eym2S:hover {
    color: var(--iconButtonHoverLightColor);
  }

@media only screen and (max-width: 768px) {
  .MovieCreditPoster-container-wPZsM {
    padding: 5px;
  }
}

.MovieCreditPoster-externalLinks-qfhtG {
  margin: 0 2px;
}

.MovieCreditPoster-externalLinkLabel-dZQnC {

  cursor: pointer;
}

.MovieReleaseDates-dateIcon-Hnf9R {
  display: inline-block;
  padding-right: 10px;
  width: 30px;
  text-align: center;
}

.MovieTitlesTable-blankpad-rzGhA {
  padding-top: 10px;
  padding-bottom: 10px;
  padding-left: 2em;
}

.MovieTitlesTable-container-d22qO {
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--inputBackgroundColor);
}

.MovieTitlesTable-container-d22qO:last-of-type {
    margin-bottom: 0;
  }

.InfoLabel-label-Wzh9H {
  display: inline-block;
  margin: 2px;
  color: var(--white);
  /** text-align: center; **/
  white-space: nowrap;
  line-height: 1;
  cursor: default;
}

.InfoLabel-name-NH4Ts {
  margin-bottom: 2px;
  color: var(--helpTextColor);
  font-size: 10px;
}

/** Kinds **/

.InfoLabel-default-E_bcO {
  color: inherit;
}

/** Sizes **/

.InfoLabel-small-IGdqv {
  padding: 1px 3px;
  font-size: 11px;
}

.InfoLabel-medium-F0bfF {
  padding: 2px 5px;
  font-size: 12px;
}

.InfoLabel-large-nQsou {
  padding: 3px 7px;
  font-size: 14px;
}

/** Outline **/

.InfoLabel-outline-cJaK3 {
  background-color: var(--white);
}

.MovieDetails-innerContentBody-ZFMpt {
  padding: 0;
}

.MovieDetails-header-FEq6F {
  position: relative;
  width: 100%;
  height: 425px;
}

.MovieDetails-errorMessage-Mpvwv {
  margin-top: 20px;
  text-align: center;
  font-size: 20px;
}

.MovieDetails-backdrop-xLWPd {
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 100%;
  background-size: cover;
}

.MovieDetails-backdropOverlay-enPTs {
  position: absolute;
  width: 100%;
  height: 100%;
  background: var(--black);
  opacity: 0.7;
}

.MovieDetails-headerContent-LU2fx {
  display: flex;
  padding: 30px;
  width: 100%;
  height: 100%;
  color: var(--white);
}

.MovieDetails-poster-Qp_05 {
  z-index: 2;
  flex-shrink: 0;
  margin-right: 35px;
  width: 250px;
  height: 368px;
}

.MovieDetails-info-ykf8t {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  overflow: hidden;
}

.MovieDetails-titleRow-Z2heu {
  position: relative;
  display: flex;
  justify-content: space-between;
  flex: 0 0 auto;
}

.MovieDetails-titleContainer-s3R0R {
  display: flex;
  margin-bottom: 5px;
}

.MovieDetails-title-yaEzx {
  font-weight: 300;
  font-size: 50px;
  line-height: 60px;
}

.MovieDetails-toggleMonitoredContainer-bGWSE {
  align-self: center;
  margin-right: 10px;
}

.MovieDetails-monitorToggleButton-APdLa {

  width: 40px;
}

.MovieDetails-monitorToggleButton-APdLa:hover {
    color: var(--iconButtonHoverLightColor);
  }

.MovieDetails-alternateTitlesIconContainer-QpXFR {
  align-self: flex-end;
  margin-left: 20px;
}

.MovieDetails-filterIcon-XoVQ7 {
  float: right;
}

.MovieDetails-movieNavigationButtons-ttiAZ {
  position: absolute;
  right: 0;
  white-space: nowrap;
}

.MovieDetails-movieNavigationButton-b8M4Y {

  margin-left: 5px;
  width: 30px;
  color: #e1e2e3;
  white-space: nowrap;
}

.MovieDetails-movieNavigationButton-b8M4Y:hover {
    color: var(--iconButtonHoverLightColor);
  }

.MovieDetails-details-dEDRX {
  margin-bottom: 8px;
  padding-left: 7px;
  font-weight: 300;
  font-size: 20px;
}

.MovieDetails-links-RgCzv,
.MovieDetails-rating-gwOHo,
.MovieDetails-year-FZGC1,
.MovieDetails-runtime-_q_iv {
  margin-right: 14px;
}

.MovieDetails-certification-uctzJ {
  margin-right: 15px;
  padding: 0 5px;
  border: 1px solid;
  border-radius: 5px;
}

.MovieDetails-detailsLabel-yEMVH {

  margin: 5px 10px 5px 0;
}

.MovieDetails-detailsInfoLabel-o7IZQ {

  margin: 5px 10px 5px 0;
}

.MovieDetails-path-UGxp_,
.MovieDetails-sizeOnDisk-vp0I9,
.MovieDetails-qualityProfileName-RNI2f,
.MovieDetails-statusName-N_KwB,
.MovieDetails-originalLanguage-h8ELA,
.MovieDetails-studio-msMUn,
.MovieDetails-collection-fJzbV,
.MovieDetails-genres-LWKII {
  font-weight: 300;
  font-size: 17px;
}

.MovieDetails-overview-kEtB2 {
  flex: 1 0 0;
  margin-top: 8px;
  min-height: 0;
  text-wrap: balance;
  font-size: 15px;
}

.MovieDetails-contentContainer-m5gIt {
  padding: 20px;
}

.MovieDetails-tabList-EpZo2 {
  margin: 0;
  padding: 0;
  border-bottom: 1px solid var(--lightGray);
}

.MovieDetails-tab-Zc0iA {
  position: relative;
  bottom: -1px;
  display: inline-block;
  padding: 6px 12px;
  border: 1px solid transparent;
  border-top: none;
  list-style: none;
  cursor: pointer;
}

.MovieDetails-selectedTab-tx8_A {
  border-bottom: 4px solid var(--linkColor);
}

.MovieDetails-tabContent-ojQSW {
  margin-top: 20px;
}

@media only screen and (max-width: 768px) {
  .MovieDetails-contentContainer-m5gIt {
    padding: 20px 0;
  }

  .MovieDetails-headerContent-LU2fx {
    padding: 15px;
  }

  .MovieDetails-title-yaEzx {
    font-weight: 300;
    font-size: 30px;
    line-height: 30px;
  }
}

@media only screen and (max-width: 1200px) {
  .MovieDetails-poster-Qp_05,
  .MovieDetails-movieNavigationButtons-ttiAZ {
    display: none;
  }

  .MovieDetails-certification-uctzJ,
  .MovieDetails-links-RgCzv,
  .MovieDetails-rating-gwOHo,
  .MovieDetails-year-FZGC1,
  .MovieDetails-runtime-_q_iv {
    margin-right: 9px;
  }

  .MovieDetails-details-dEDRX {
    font-size: 19px;
  }
}

.MovieIndexFooter-footer-nXiiF {
  display: flex;
  flex-wrap: wrap;
  margin-top: 20px;
  font-size: 12px;
}

.MovieIndexFooter-legendItem-C5Hpq {
  display: flex;
  margin-bottom: 4px;
  line-height: 16px;
}

.MovieIndexFooter-legendItemColor-FkuL3 {
  margin-right: 8px;
  width: 30px;
  height: 16px;
  border-radius: 4px;
}

.MovieIndexFooter-queue-ql14D {

  background-color: var(--queueColor);
}

.MovieIndexFooter-continuing-Ja2bn {

  background-color: var(--primaryColor);
}

.MovieIndexFooter-availNotMonitored-WJx2C {

  background-color: var(--darkGray);
}

.MovieIndexFooter-ended-YVumZ {

  background-color: var(--successColor);
}

.MovieIndexFooter-missingMonitored-qt_m6 {

  background-color: var(--dangerColor);
}

.MovieIndexFooter-missingMonitored-qt_m6.colorImpaired {
    background: repeating-linear-gradient(90deg, var(--dangerColor), var(--dangerColor) 5px, var(--dangerColor) 5px, var(--dimColor) 10px);
  }

.MovieIndexFooter-missingUnmonitored-XuZyx {

  background-color: var(--warningColor);
}

.MovieIndexFooter-missingUnmonitored-XuZyx.colorImpaired {
    background: repeating-linear-gradient(45deg, var(--warningColor), var(--warningColor) 5px, var(--warningColor) 5px, var(--dimColor) 10px);
  }

.MovieIndexFooter-statistics-EX8uE {
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
}

@media (max-width: 1200px) {
  .MovieIndexFooter-statistics-EX8uE {
    display: block;
  }
}

@media (max-width: 768px) {
  .MovieIndexFooter-footer-nXiiF {
    display: block;
  }

  .MovieIndexFooter-statistics-EX8uE {
    display: flex;
    margin-top: 20px;
  }
}

.TagList-tags-AT8ST {
  flex: 1 0 auto;
}

.MovieIndexPosterSelect-checkButton-o0JGH {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 3;
  width: 100%;
  height: 100%;
}

.MovieIndexPosterSelect-checkContainer-HI4ax {
  position: absolute;
  top: 8px;
  left: 8px;
  width: 20px;
  height: 20px;
  border-radius: 50%;
  background-color: var(--defaultColor);
}

.MovieIndexPosterSelect-selected-MCMBa {
  color: var(--primaryColor);
}

.MovieIndexPosterSelect-unselected-JHJyd {
  color: var(--white);
}

.MovieIndexPosterSelect-checkButton-o0JGH:hover .MovieIndexPosterSelect-selected-MCMBa {
      color: var(--white);
    }

.MovieIndexPosterSelect-checkButton-o0JGH:hover .MovieIndexPosterSelect-unselected-JHJyd {
      color: var(--primaryColor);
    }

.MovieIndexOverviewInfoRow-infoRow-isLLk {
  flex: 0 0 21px;
  margin: 2px 0;
}

.MovieIndexOverviewInfoRow-icon-yfFsz {
  margin-right: 5px;
  width: 25px !important;
  text-align: center;
}

.MovieIndexOverviewInfo-infos-BRPyP {
  display: flex;
  flex: 0 0 250px;
  flex-direction: column;
  margin-left: 10px;
}

@media only screen and (max-width: 768px) {
  .MovieIndexOverviewInfo-infos-BRPyP {
    margin-left: 0;
  }
}

.MovieIndexOverview-content-OYdmn {
  display: flex;
  flex-grow: 1;
}

.MovieIndexOverview-poster-ci2iR {
  position: relative;
}

.MovieIndexOverview-editorSelect-_1wpR {
  position: absolute;
  top: 0;
  left: 5px;
  z-index: 3;
}

.MovieIndexOverview-posterContainer-nNMlw {
  position: relative;
}

.MovieIndexOverview-link-MS8Nr {

  display: block;
  color: var(--defaultColor);
}

.MovieIndexOverview-link-MS8Nr:hover {
    color: var(--defaultColor);
    text-decoration: none;
  }

.MovieIndexOverview-deleted-AW0Gy {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  width: 0;
  height: 0;
  border-width: 0 25px 25px 0;
  border-style: solid;
  border-color: transparent var(--gray) transparent transparent;
  color: var(--white);
}

.MovieIndexOverview-info-oESxH {
  display: flex;
  flex: 1 0 1px;
  flex-direction: column;
  overflow: hidden;
  padding-left: 10px;
}

.MovieIndexOverview-titleRow-yfell {
  display: flex;
  justify-content: space-between;
  flex: 0 0 auto;
  margin-bottom: 10px;
  line-height: 32px;
}

.MovieIndexOverview-title-VqDgM {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 1 0 1px;
  font-weight: 300;
  font-size: 30px;
}

.MovieIndexOverview-actions-I8heZ {
  white-space: nowrap;
}

.MovieIndexOverview-details-TwnsQ {
  display: flex;
  justify-content: space-between;
  flex: 1 0 auto;
}

.MovieIndexOverview-overviewContainer-Fbsfd {
  display: flex;
  justify-content: space-between;
  flex: 0 1 1000px;
  flex-direction: column;
}

.MovieIndexOverview-overview-CVIat {

  overflow: hidden;
  min-height: 0;
}

.MovieIndexOverview-tags-Q7APX {
  display: flex;
  justify-content: space-around;
  overflow: hidden;
}

@media only screen and (max-width: 768px) {
  .MovieIndexOverview-overview-CVIat {
    display: none;
  }
}

.MovieIndexOverview-externalLinks-rV68E {
  margin-right: 0.5em;
}

.MovieIndexOverview-queue-YIJvW {
  padding-left: 2px;
  border-left: 4px solid var(--queueColor);
}

.MovieIndexPoster-content-EcQfG {
  transition: all 200ms ease-in;
}

  .MovieIndexPoster-content-EcQfG:hover {
    z-index: 2;
    box-shadow: 0 0 12px var(--black);
    transition: all 200ms ease-in;
  }

  .MovieIndexPoster-content-EcQfG:hover .MovieIndexPoster-controls-wC0zX {
      opacity: 0.9;
      transition: opacity 200ms linear 150ms;
    }

.MovieIndexPoster-posterContainer-RqOOf {
  position: relative;
}

.MovieIndexPoster-poster-yWZHK {
  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.MovieIndexPoster-overlayTitle-rchvK {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 5px;
  width: 100%;
  height: 100%;
  color: var(--offWhite);
  text-align: center;
  font-size: 20px;
}

.MovieIndexPoster-title-jXLGH {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  background-color: var(--movieBackgroundColor);
  text-align: center;
  font-size: 12px;
}

.MovieIndexPoster-controls-wC0zX {
  position: absolute;
  bottom: 10px;
  left: 10px;
  z-index: 3;
  border-radius: 4px;
  background-color: #707070;
  color: var(--white);
  font-size: 12px;
  opacity: 0;
  transition: opacity 0;
}

.MovieIndexPoster-action-wX4EJ {
}

.MovieIndexPoster-action-wX4EJ:hover {
    color: var(--radarrYellow);
  }

@media only screen and (max-width: 768px) {
  .MovieIndexPoster-container-W4svh {
    padding: 5px;
  }
}

.MovieIndexPoster-tags-WpPoz {
  display: flex;
  align-items: center;
  justify-content: space-around;
  padding: 0 3px;
  height: 21px;
  background-color: var(--movieBackgroundColor);
}

.MovieIndexPoster-tagsList-iPYsl {
  display: flex;
  overflow: hidden;
}

.MovieIndexPoster-deleted-fFmsq {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  width: 0;
  height: 0;
  border-width: 0 25px 25px 0;
  border-style: solid;
  border-color: transparent var(--gray) transparent transparent;
  color: var(--white);
}

.MovieIndexPoster-editorSelect-F8pBj {
  position: absolute;
  top: 10px;
  left: 10px;
  z-index: 3;
}

.MovieIndexPoster-externalLinks-u3B0H {
  margin-left: 0.5em;
}

.MovieIndexPoster-link-tskJp {

  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.MovieIndexPoster-nextAiring-MmFQw {
  background-color: #fafbfc;
  text-align: center;
  font-size: 12px;
}

.MovieIndexPosterInfo-info-iEzEw {
  background-color: var(--movieBackgroundColor);
  text-align: center;
  font-size: 12px;
}

.MovieIndexPosterInfo-title-ZAj5E {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
}

.MovieIndexPosterInfo-tags-QOd0J {
}

.MovieIndexPosterInfo-tagsList-x68uo {
}

.MovieIndexPoster-content-EcQfG {
  transition: all 200ms ease-in;
}

  .MovieIndexPoster-content-EcQfG:hover {
    z-index: 2;
    box-shadow: 0 0 12px var(--black);
    transition: all 200ms ease-in;
  }

  .MovieIndexPoster-content-EcQfG:hover .MovieIndexPoster-controls-wC0zX {
      opacity: 0.9;
      transition: opacity 200ms linear 150ms;
    }

.MovieIndexPoster-posterContainer-RqOOf {
  position: relative;
}

.MovieIndexPoster-poster-yWZHK {
  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.MovieIndexPoster-overlayTitle-rchvK {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 5px;
  width: 100%;
  height: 100%;
  color: var(--offWhite);
  text-align: center;
  font-size: 20px;
}

.MovieIndexPoster-title-jXLGH {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  background-color: var(--movieBackgroundColor);
  text-align: center;
  font-size: 12px;
}

.MovieIndexPoster-controls-wC0zX {
  position: absolute;
  bottom: 10px;
  left: 10px;
  z-index: 3;
  border-radius: 4px;
  background-color: #707070;
  color: var(--white);
  font-size: 12px;
  opacity: 0;
  transition: opacity 0;
}

.MovieIndexPoster-action-wX4EJ {
}

.MovieIndexPoster-action-wX4EJ:hover {
    color: var(--radarrYellow);
  }

@media only screen and (max-width: 768px) {
  .MovieIndexPoster-container-W4svh {
    padding: 5px;
  }
}

.MovieIndexPoster-tags-WpPoz {
  display: flex;
  align-items: center;
  justify-content: space-around;
  padding: 0 3px;
  height: 21px;
  background-color: var(--movieBackgroundColor);
}

.MovieIndexPoster-tagsList-iPYsl {
  display: flex;
  overflow: hidden;
}

.MovieIndexPoster-deleted-fFmsq {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  width: 0;
  height: 0;
  border-width: 0 25px 25px 0;
  border-style: solid;
  border-color: transparent var(--gray) transparent transparent;
  color: var(--white);
}

.MovieIndexPoster-editorSelect-F8pBj {
  position: absolute;
  top: 10px;
  left: 10px;
  z-index: 3;
}

.MovieIndexPoster-externalLinks-u3B0H {
  margin-left: 0.5em;
}

.MovieIndexPoster-link-tskJp {

  position: relative;
  display: block;
  background-color: var(--defaultColor);
}

.MovieIndexPoster-nextAiring-MmFQw {
  background-color: #fafbfc;
  text-align: center;
  font-size: 12px;
}

.DeleteMovieModalContent-message-SbHKu {
  margin-top: 20px;
  margin-bottom: 10px;
}

.DeleteMovieModalContent-pathContainer-YiNEZ {
  margin-left: 5px;
}

.DeleteMovieModalContent-path-hpUgR {
  margin-left: 5px;
  color: var(--dangerColor);
  font-weight: bold;
}

.DeleteMovieModalContent-statistics-yk0LK {
  margin-left: 5px;
  color: var(--warningColor);
}

.DeleteMovieModalContent-deleteFilesMessage-K0w3U {
  margin-top: 20px;
  color: var(--warningColor);
}

.EditMoviesModalContent-modalFooter-gHsNV {

  justify-content: space-between;
}

.EditMoviesModalContent-selected-ReHHI {
  font-weight: bold;
}

@media only screen and (max-width: 480px) {
  .EditMoviesModalContent-modalFooter-gHsNV {
    flex-direction: column;
    gap: 10px;
  }
}

.OrganizeMoviesModalContent-renameIcon-OcwsN {
  margin-left: 5px;
}

.OrganizeMoviesModalContent-message-TpkEd {
  margin-top: 20px;
  margin-bottom: 10px;
}

.TagsModalContent-renameIcon-wc7rg {
  margin-left: 5px;
}

.TagsModalContent-message-vtjNy {
  margin-top: 20px;
  margin-bottom: 10px;
}

.TagsModalContent-result-v6Y79 {
  padding-top: 4px;
}

.PageContentFooter-contentFooter-RHpBL {
  display: flex;
  flex: 0 0 auto;
  padding: 20px;
  background-color: var(--pageFooterBackground);
}

@media only screen and (max-width: 768px) {
  .PageContentFooter-contentFooter-RHpBL {
    display: block;
  }
}

@media only screen and (max-width: 1450px) {
  .PageContentFooter-contentFooter-RHpBL {
    flex-wrap: wrap;
  }
}

.MovieIndexSelectFooter-footer-cqCnQ {

  align-items: center;
}

.MovieIndexSelectFooter-buttons-C8jss {
  display: flex;
}

.MovieIndexSelectFooter-actionButtons-l9ngv,
.MovieIndexSelectFooter-deleteButtons-DrnJH {
  display: flex;
  gap: 10px;
}

.MovieIndexSelectFooter-deleteButtons-DrnJH {
  margin-left: 50px;
}

.MovieIndexSelectFooter-selected-QMP03 {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
  font-weight: bold;
}

@media only screen and (max-width: 992px) {
  .MovieIndexSelectFooter-buttons-C8jss {
    justify-content: center;
    width: 100%;
  }

  .MovieIndexSelectFooter-selected-QMP03 {
    justify-content: center;
    margin-bottom: 20px;
    width: 100%;
    order: -1;
  }
}

@media only screen and (max-width: 768px) {
  .MovieIndexSelectFooter-footer-cqCnQ {
    display: flex;
    flex-direction: column;
  }

  .MovieIndexSelectFooter-buttons-C8jss {
    flex-direction: column;
    margin-top: 20px;
    gap: 20px;
  }

  .MovieIndexSelectFooter-actionButtons-l9ngv {
    flex-wrap: wrap;
  }

  .MovieIndexSelectFooter-actionButtons-l9ngv,
  .MovieIndexSelectFooter-deleteButtons-DrnJH {
    display: flex;
    justify-content: center;
  }

  .MovieIndexSelectFooter-deleteButtons-DrnJH {
    margin-left: 0;
  }

  .MovieIndexSelectFooter-selected-QMP03 {
    justify-content: center;
    order: -1;
  }
}

.MovieStatusCell-status-XFJul {

  width: 60px;
}

.MovieStatusCell-statusIcon-QQe6l {
  width: 20px !important;
  text-align: center;
}

.MovieIndexRow-cell-Xl9QP {

  display: flex;
  align-items: center;
}

.MovieIndexRow-status-cuom0 {

  flex: 0 0 60px;
}

.MovieIndexRow-collection-mm1EI,
.MovieIndexRow-originalTitle-_llHF,
.MovieIndexRow-sortTitle-o9duu {

  flex: 4 0 110px;
}

.MovieIndexRow-minimumAvailability-RhlvD {

  flex: 0 0 140px;
}

.MovieIndexRow-studio-F904P {

  flex: 2 0 90px;
}

.MovieIndexRow-originalLanguage-n5ctS,
.MovieIndexRow-qualityProfileId-fZMw9 {

  flex: 1 0 125px;
}

.MovieIndexRow-releaseGroups-ttoOY,
.MovieIndexRow-inCinemas-USBp8,
.MovieIndexRow-physicalRelease-jxUVK,
.MovieIndexRow-digitalRelease-VId5i,
.MovieIndexRow-releaseDate-GDtTY,
.MovieIndexRow-genres-Q_0lm,
.MovieIndexRow-keywords-ucdis {

  flex: 0 0 180px;
}

.MovieIndexRow-added-rfm6P,
.MovieIndexRow-popularity-y81bi,
.MovieIndexRow-runtime-saRhx {

  flex: 0 0 100px;
}

.MovieIndexRow-movieStatus-uYrl8 {

  display: flex;
  justify-content: center;
  flex: 0 0 150px;
  flex-direction: column;
}

.MovieIndexRow-certification-hI1RP {

  flex: 0 0 90px;
}

.MovieIndexRow-year-L6lBm {

  flex: 0 0 80px;
}

.MovieIndexRow-path-ccsNN {

  flex: 1 0 150px;
}

.MovieIndexRow-sizeOnDisk-VDAQT {

  flex: 0 0 120px;
}

.MovieIndexRow-imdbRating-xWbrg,
.MovieIndexRow-tmdbRating-zEtQT,
.MovieIndexRow-rottenTomatoesRating-vJt4t,
.MovieIndexRow-traktRating-iCPKC {

  flex: 0 0 80px;
}

.MovieIndexRow-tags-goPcR {

  flex: 1 0 60px;
}

.MovieIndexRow-actions-bzjId {

  flex: 0 1 90px;
  min-width: 90px;
}

.MovieIndexRow-checkInput-UbCz9 {

  margin-top: 0;
}

.MovieIndexRow-externalLinks-cKPhe {
  margin: 0 2px;
  width: 22px;
  text-align: center;
}

.MovieIndexTableHeader-status-O1yt8 {

  flex: 0 0 60px;
}

.MovieIndexTableHeader-collection-aZDnc,
.MovieIndexTableHeader-originalTitle-pPuPv,
.MovieIndexTableHeader-sortTitle-v7Fy2 {

  flex: 4 0 110px;
}

.MovieIndexTableHeader-minimumAvailability-gyOxu {

  flex: 0 0 140px;
}

.MovieIndexTableHeader-studio-BupGj {

  flex: 2 0 90px;
}

.MovieIndexTableHeader-originalLanguage-thjw4,
.MovieIndexTableHeader-qualityProfileId-u01UN {

  flex: 1 0 125px;
}

.MovieIndexTableHeader-releaseGroups-rrgXb,
.MovieIndexTableHeader-inCinemas-ug5Vz,
.MovieIndexTableHeader-physicalRelease-wgHn9,
.MovieIndexTableHeader-digitalRelease-ChiAG,
.MovieIndexTableHeader-releaseDate-sCGMu,
.MovieIndexTableHeader-genres-XogIR,
.MovieIndexTableHeader-keywords-aNRlU {

  flex: 0 0 180px;
}

.MovieIndexTableHeader-added-diuNJ,
.MovieIndexTableHeader-popularity-Scufo,
.MovieIndexTableHeader-runtime-mwTwq {

  flex: 0 0 100px;
}

.MovieIndexTableHeader-movieStatus-nQgge {

  flex: 0 0 150px;
}

.MovieIndexTableHeader-certification-I1llH {

  flex: 0 0 90px;
}

.MovieIndexTableHeader-year-cxvKq {

  flex: 0 0 80px;
}

.MovieIndexTableHeader-path-KqGHw {

  flex: 1 0 150px;
}

.MovieIndexTableHeader-sizeOnDisk-y5iMh {

  flex: 0 0 120px;
}

.MovieIndexTableHeader-imdbRating-_gux0,
.MovieIndexTableHeader-tmdbRating-uO7Oq,
.MovieIndexTableHeader-rottenTomatoesRating-vXRac,
.MovieIndexTableHeader-traktRating-NXwZA {

  flex: 0 0 80px;
}

.MovieIndexTableHeader-tags-sg8mb {

  flex: 1 0 60px;
}

.MovieIndexTableHeader-actions-Hnq3y {

  flex: 0 1 90px;
}

.MovieIndexTable-tableScroller-QkFM5 {
  position: relative;
}

.MovieIndexTable-row-MZIas {
  transition: background-color 500ms;
}

.MovieIndexTable-row-MZIas:hover {
    background-color: var(--tableRowHoverBackgroundColor);
  }

.ParseResultItem-item-fq1V3 {
  display: flex;
}

.ParseResultItem-title-Jvbx7 {
  margin-right: 20px;
  width: 250px;
  text-align: right;
  font-weight: bold;
}

@media (max-width: 768px) {
  .ParseResultItem-item-fq1V3 {
    display: block;
    margin-bottom: 10px;
  }

  .ParseResultItem-title-Jvbx7 {
    text-align: left;
  }
}

.ParseResult-container-pfU9F {
  display: flex;
  flex-wrap: wrap;
}

.ParseResult-column-v9q7Q {
  flex: 0 0 50%;
}

.ParseModalContent-inputContainer-l4Hf8 {
  display: flex;
  margin-bottom: 10px;
}

.ParseModalContent-inputIconContainer-d9BJp {
  width: 58px;
  height: 46px;
  border: 1px solid var(--inputBorderColor);
  border-right: none;
  border-radius: 4px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  background-color: var(--inputIconContainerBackgroundColor);
  text-align: center;
  line-height: 46px;
}

.ParseModalContent-input-O1c7r {

  height: 46px;
  border-radius: 0;
  font-size: 18px;
}

.ParseModalContent-clearButton-Z5YHE {
  border: 1px solid var(--inputBorderColor);
  border-left: none;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.ParseModalContent-message-ILozf {
  margin-top: 30px;
  text-align: center;
  font-weight: 300;
  font-size: 16px;
}

.ParseModalContent-helpText-AH6wq {
  margin-bottom: 10px;
  font-size: 24px;
}

.Card-card-aoesq {
  position: relative;
  margin: 10px;
  padding: 10px;
  border-radius: 3px;
  background-color: var(--cardBackgroundColor);
  box-shadow: 0 0 10px 1px var(--cardShadowColor);
  color: var(--defaultColor);
}

.Card-underlay-bObAW {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.Card-overlay-WuJz0 {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.Card-overlay-WuJz0 a,
  .Card-overlay-WuJz0 button {
    pointer-events: all;
  }

.Card-overlay-WuJz0 {

  position: relative;
}

.TextArea-input-E794O {

  flex-grow: 1;
  min-height: 200px;
  resize: vertical;
}

.TextArea-readOnly-ysBOQ {
  background-color: #eee;
}

.TextArea-hasError-tL5zd {
}

.TextArea-hasWarning-qW1kz {
}

.ImportCustomFormatModalContent-input-pByC1 {

  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.Card-card-aoesq {
  position: relative;
  margin: 10px;
  padding: 10px;
  border-radius: 3px;
  background-color: var(--cardBackgroundColor);
  box-shadow: 0 0 10px 1px var(--cardShadowColor);
  color: var(--defaultColor);
}

.Card-underlay-bObAW {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.Card-overlay-WuJz0 {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.Card-overlay-WuJz0 a,
  .Card-overlay-WuJz0 button {
    pointer-events: all;
  }

.Card-overlay-WuJz0 {

  position: relative;
}

.AddSpecificationItem-specification-ifqAt {

  position: relative;
  width: 300px;
  height: 100px;
}

.AddSpecificationItem-underlay-w1aRk {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AddSpecificationItem-overlay-5g_Xp {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddSpecificationItem-overlay-5g_Xp a,
  .AddSpecificationItem-overlay-5g_Xp button {
    pointer-events: all;
  }

.AddSpecificationItem-overlay-5g_Xp {

  padding: 10px;
}

.AddSpecificationItem-name-VwWrp {
  text-align: center;
  font-weight: lighter;
  font-size: 24px;
}

.AddSpecificationItem-actions-MMs3Y {
  margin-top: 20px;
  text-align: right;
}

.AddSpecificationItem-presetsMenu-oMDbn {

  display: inline-block;
  margin: 0 5px;
}

.AddSpecificationItem-presetsMenuButton-AfrGQ {
}

.AddSpecificationItem-presetsMenuButton-AfrGQ::after {
    margin-left: 5px;
    content: '\25BE';
  }

.AddSpecificationModalContent-specifications-x_4O_ {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
}

.EditSpecificationModalContent-deleteButton-c9rQ4 {

  margin-right: auto;
}

.Specification-customFormat-eMwyx {

  width: 300px;
}

.Specification-nameContainer-RnvUM {
  display: flex;
  justify-content: space-between;
}

.Specification-name-CCiQR {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Specification-cloneButton-u1JT_ {

  height: 36px;
}

.Specification-labels-KH_af {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.Specification-tooltipLabel-ffdMM {

  margin: 0;
  border: none;
}

.CustomFormat-customFormat-bQGEb {

  width: 300px;
}

.CustomFormat-nameContainer-kd6SP {
  display: flex;
  justify-content: space-between;
}

.CustomFormat-name-tDmWt {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.CustomFormat-buttons-eI3y1 {
  flex: 0 0 auto;
}

.CustomFormat-cloneButton-Alwpt {

  height: 36px;
}

.CustomFormat-formats-z88F4 {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.CustomFormat-tooltipLabel-UmJ9l {

  margin: 0;
  border: none;
}

.CustomFormat-label-mIDsS {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  max-width: 100%;
}

.EditCustomFormatModalContent-deleteButton-YRaYD {

  margin-right: auto;
}

.EditCustomFormatModalContent-rightButtons-cMlfm {
  justify-content: flex-end;
  margin-right: auto;
}

.EditCustomFormatModalContent-addSpecification-ziqyR {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
  font-size: 45px;
}

.EditCustomFormatModalContent-center-CwrAN {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.EditCustomFormatModalContent-customFormats-qVU9p {
  display: flex;
  flex-wrap: wrap;
}

.ExportCustomFormatModalContent-button-eh1Jq {

  position: relative;
}

.CustomFormat-customFormat-bQGEb {

  width: 300px;
}

.CustomFormat-nameContainer-kd6SP {
  display: flex;
  justify-content: space-between;
}

.CustomFormat-name-tDmWt {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.CustomFormat-buttons-eI3y1 {
  flex: 0 0 auto;
}

.CustomFormat-cloneButton-Alwpt {

  height: 36px;
}

.CustomFormat-formats-z88F4 {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.CustomFormat-tooltipLabel-UmJ9l {

  margin: 0;
  border: none;
}

.CustomFormat-label-mIDsS {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  max-width: 100%;
}

.CustomFormats-customFormats-B875M {
  display: flex;
  flex-wrap: wrap;
}

.CustomFormats-addCustomFormat-RgATG {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
  font-size: 45px;
}

.CustomFormats-center-W2JPX {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.ManageCustomFormatsEditModalContent-modalFooter-zjkFe {

  justify-content: space-between;
}

.ManageCustomFormatsEditModalContent-selected-boz8Z {
  font-weight: bold;
}

@media only screen and (max-width: 480px) {
  .ManageCustomFormatsEditModalContent-modalFooter-zjkFe {
    flex-direction: column;
    gap: 10px;
  }
}

.ManageCustomFormatsModalRow-name-KDdaF,
.ManageCustomFormatsModalRow-includeCustomFormatWhenRenaming-IUUOz {

  word-break: break-all;
}

.ManageCustomFormatsModalRow-actions-wlLi1 {

  width: 40px;
}

.ManageCustomFormatsModalContent-leftButtons-sXYPu,
.ManageCustomFormatsModalContent-rightButtons-dvVA5 {
  display: flex;
  flex: 1 0 50%;
  flex-wrap: wrap;
}

.ManageCustomFormatsModalContent-rightButtons-dvVA5 {
  justify-content: flex-end;
}

.ManageCustomFormatsModalContent-deleteButton-h3hL3 {

  margin-right: 10px;
}

.AddDownloadClientItem-downloadClient-oMifk {

  position: relative;
  width: 300px;
  height: 100px;
}

.AddDownloadClientItem-underlay-oxdhA {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AddDownloadClientItem-overlay-rlyny {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddDownloadClientItem-overlay-rlyny a,
  .AddDownloadClientItem-overlay-rlyny button {
    pointer-events: all;
  }

.AddDownloadClientItem-overlay-rlyny {

  padding: 10px;
}

.AddDownloadClientItem-name-iXjGD {
  text-align: center;
  font-weight: lighter;
  font-size: 24px;
}

.AddDownloadClientItem-actions-qbQIO {
  margin-top: 20px;
  text-align: right;
}

.AddDownloadClientItem-presetsMenu-V3Cfm {

  display: inline-block;
  margin: 0 5px;
}

.AddDownloadClientItem-presetsMenuButton-C3eVP {
}

.AddDownloadClientItem-presetsMenuButton-C3eVP::after {
    margin-left: 5px;
    content: '\25BE';
  }

.AddDownloadClientModalContent-downloadClients-Oi2LK {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
}

.EditDownloadClientModalContent-deleteButton-dwUEi {

  margin-right: auto;
}

.EditDownloadClientModalContent-message-XIiHZ {

  margin-bottom: 30px;
}

.DownloadClient-downloadClient-wZ1JM {

  width: 290px;
}

.DownloadClient-name-eDUtm {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.DownloadClient-enabled-SSDPC {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.DownloadClient-downloadClient-wZ1JM {

  width: 290px;
}

.DownloadClient-name-eDUtm {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.DownloadClient-enabled-SSDPC {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.DownloadClients-downloadClients-yJxlI {
  display: flex;
  flex-wrap: wrap;
}

.DownloadClients-addDownloadClient-pW5Mv {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
}

.DownloadClients-center-WmFhO {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.ManageDownloadClientsEditModalContent-modalFooter-lujmM {

  justify-content: space-between;
}

.ManageDownloadClientsEditModalContent-selected-OpTW9 {
  font-weight: bold;
}

@media only screen and (max-width: 480px) {
  .ManageDownloadClientsEditModalContent-modalFooter-lujmM {
    flex-direction: column;
    gap: 10px;
  }
}

.ManageDownloadClientsModalRow-name-tXtzB,
.ManageDownloadClientsModalRow-enable-cd4Aq,
.ManageDownloadClientsModalRow-tags-l762O,
.ManageDownloadClientsModalRow-priority-kDQJC,
.ManageDownloadClientsModalRow-removeCompletedDownloads-pLVmi,
.ManageDownloadClientsModalRow-removeFailedDownloads-J9yDQ,
.ManageDownloadClientsModalRow-implementation-P7X40 {

  word-break: break-all;
}
.TagsModalContent-renameIcon-cVYe8 {
  margin-left: 5px;
}

.TagsModalContent-message-zRYdW {
  margin-top: 20px;
  margin-bottom: 10px;
}

.TagsModalContent-result-poJQI {
  padding-top: 4px;
}

.ManageDownloadClientsModalContent-leftButtons-T17BS,
.ManageDownloadClientsModalContent-rightButtons-EvNoz {
  display: flex;
  flex: 1 0 50%;
  flex-wrap: wrap;
}

.ManageDownloadClientsModalContent-rightButtons-EvNoz {
  justify-content: flex-end;
}

.ManageDownloadClientsModalContent-deleteButton-irV2f {

  margin-right: 10px;
}

.EditRemotePathMappingModalContent-body-PE4id {

  flex: 1 1 430px;
}

.EditRemotePathMappingModalContent-deleteButton-ZAVCm {

  margin-right: auto;
}

.RemotePathMapping-remotePathMapping-Jy6fO {
  display: flex;
  align-items: stretch;
  margin-bottom: 10px;
  height: 30px;
  border-bottom: 1px solid var(--borderColor);
  line-height: 30px;
}

.RemotePathMapping-host-o0xdT {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 0 1 300px;
}

.RemotePathMapping-path-T3frI {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 0 1 400px;
}

.RemotePathMapping-actions-sV1xS {
  display: flex;
  justify-content: flex-end;
  flex: 1 0 auto;
  padding-right: 10px;
}

.RemotePathMappings-remotePathMappingsHeader-TcQ3F {
  display: flex;
  margin-bottom: 10px;
  padding-right: 24px;
  font-weight: bold;
}

.RemotePathMappings-host-LzeXa {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 0 1 300px;
}

.RemotePathMappings-path-yhMRC {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  flex: 0 1 400px;
}

.RemotePathMappings-addRemotePathMapping-rGEoO {
  display: flex;
  justify-content: flex-end;
  padding-right: 10px;
}

.RemotePathMappings-addButton-xS9B4 {
  text-align: center;
}

.EditImportListExclusionModalContent-body-vc_c_ {

  flex: 1 1 430px;
}

.EditImportListExclusionModalContent-deleteButton-q8gjG {

  margin-right: auto;
}

.ImportListExclusionRow-actions-_EXJg {

  width: 35px;
  white-space: nowrap;
}

.ImportListExclusions-actions-IV8p_ {

  width: 35px;
  white-space: nowrap;
}

.AddImportListItem-list-oFr_m {

  position: relative;
  width: 300px;
  height: 100px;
}

.AddImportListItem-underlay-eQ6Rc {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AddImportListItem-overlay-SV_VG {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddImportListItem-overlay-SV_VG a,
  .AddImportListItem-overlay-SV_VG button {
    pointer-events: all;
  }

.AddImportListItem-overlay-SV_VG {

  padding: 10px;
}

.AddImportListItem-name-ww4lQ {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  text-align: center;
  font-weight: lighter;
  font-size: 24px;
}

.AddImportListItem-actions-CpSnE {
  margin-top: 20px;
  text-align: right;
}

.AddImportListItem-presetsMenu-TZXKp {

  display: inline-block;
  margin: 0 5px;
}

.AddImportListItem-presetsMenuButton-hxJ1r {
}

.AddImportListItem-presetsMenuButton-hxJ1r::after {
    margin-left: 5px;
    content: '\25BE';
  }

.AddImportListModalContent-lists-gojEB {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
}

.ImportList-list-c7gQt {

  width: 290px;
}

.ImportList-nameContainer-uRT07 {
  display: flex;
  justify-content: space-between;
}

.ImportList-name-Wx4wM {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.ImportList-cloneButton-VLJrO {

  height: 36px;
}

.ImportList-enabled-C_uMU {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.ImportList-list-c7gQt {

  width: 290px;
}

.ImportList-nameContainer-uRT07 {
  display: flex;
  justify-content: space-between;
}

.ImportList-name-Wx4wM {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.ImportList-cloneButton-VLJrO {

  height: 36px;
}

.ImportList-enabled-C_uMU {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.ImportLists-lists-vKPjg {
  display: flex;
  flex-wrap: wrap;
}

.ImportLists-addList-gGcxK {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
}

.ImportLists-center-f_Mdw {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.ManageImportListsEditModalContent-modalFooter-vOLBE {

  justify-content: space-between;
}

.ManageImportListsEditModalContent-selected-snufW {
  font-weight: bold;
}

@media only screen and (max-width: 480px) {
  .ManageImportListsEditModalContent-modalFooter-vOLBE {
    flex-direction: column;
    gap: 10px;
  }
}

.ManageImportListsModalRow-name-jCmYl,
.ManageImportListsModalRow-tags-WVEIX,
.ManageImportListsModalRow-enabled-ajtLC,
.ManageImportListsModalRow-enableAuto-f2wm2,
.ManageImportListsModalRow-minimumAvailability-zcWAn,
.ManageImportListsModalRow-qualityProfileId-Q8GRF,
.ManageImportListsModalRow-rootFolderPath-FzmIs,
.ManageImportListsModalRow-implementation-LVthP {

  word-break: break-all;
}

.TagsModalContent-renameIcon-p0YsH {
  margin-left: 5px;
}

.TagsModalContent-message-XHnCK {
  margin-top: 20px;
  margin-bottom: 10px;
}

.TagsModalContent-result-SDxiV {
  padding-top: 4px;
}

.ManageImportListsModalContent-leftButtons-P1y81,
.ManageImportListsModalContent-rightButtons-luPS3 {
  display: flex;
  flex: 1 0 50%;
  flex-wrap: wrap;
}

.ManageImportListsModalContent-rightButtons-luPS3 {
  justify-content: flex-end;
}

.ManageImportListsModalContent-deleteButton-Zgfud {

  margin-right: 10px;
}

.AddIndexerItem-indexer-tTo8N {

  position: relative;
  width: 300px;
  height: 100px;
}

.AddIndexerItem-underlay-u2paU {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AddIndexerItem-overlay-Z0Tf4 {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddIndexerItem-overlay-Z0Tf4 a,
  .AddIndexerItem-overlay-Z0Tf4 button {
    pointer-events: all;
  }

.AddIndexerItem-overlay-Z0Tf4 {

  padding: 10px;
}

.AddIndexerItem-name-us4Tk {
  text-align: center;
  font-weight: lighter;
  font-size: 24px;
}

.AddIndexerItem-actions-u_UFM {
  margin-top: 20px;
  text-align: right;
}

.AddIndexerItem-presetsMenu-a2J0h {

  display: inline-block;
  margin: 0 5px;
}

.AddIndexerItem-presetsMenuButton-HCMQr {
}

.AddIndexerItem-presetsMenuButton-HCMQr::after {
    margin-left: 5px;
    content: '\25BE';
  }

.AddIndexerModalContent-indexers-zh7Wv {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
}

.EditIndexerModalContent-deleteButton-gyzhH {

  margin-right: auto;
}

.Indexer-indexer-KNEbl {

  width: 290px;
}

.Indexer-nameContainer-iKZDb {
  display: flex;
  justify-content: space-between;
}

.Indexer-name-FoGnv {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Indexer-cloneButton-eTzP5 {

  height: 36px;
}

.Indexer-enabled-alXzS {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.Indexer-indexer-KNEbl {

  width: 290px;
}

.Indexer-nameContainer-iKZDb {
  display: flex;
  justify-content: space-between;
}

.Indexer-name-FoGnv {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Indexer-cloneButton-eTzP5 {

  height: 36px;
}

.Indexer-enabled-alXzS {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.Indexers-indexers-CV9Qr {
  display: flex;
  flex-wrap: wrap;
}

.Indexers-addIndexer-RmEIL {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
}

.Indexers-center-GKwQP {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.ManageIndexersEditModalContent-modalFooter-vZ7Ni {

  justify-content: space-between;
}

.ManageIndexersEditModalContent-selected-AIOM2 {
  font-weight: bold;
}

@media only screen and (max-width: 480px) {
  .ManageIndexersEditModalContent-modalFooter-vZ7Ni {
    flex-direction: column;
    gap: 10px;
  }
}

.ManageIndexersModalRow-name-hpa0l,
.ManageIndexersModalRow-tags-H3xmx,
.ManageIndexersModalRow-enableRss-p0XNi,
.ManageIndexersModalRow-enableAutomaticSearch-PZHf0,
.ManageIndexersModalRow-enableInteractiveSearch-iIJEt,
.ManageIndexersModalRow-priority-PTS6N,
.ManageIndexersModalRow-implementation-DkTDw {

  word-break: break-all;
}
.TagsModalContent-renameIcon-g4MBi {
  margin-left: 5px;
}

.TagsModalContent-message-jZkJe {
  margin-top: 20px;
  margin-bottom: 10px;
}

.TagsModalContent-result-HDHRf {
  padding-top: 4px;
}

.ManageIndexersModalContent-leftButtons-zb78b,
.ManageIndexersModalContent-rightButtons-NdpSY {
  display: flex;
  flex: 1 0 50%;
  flex-wrap: wrap;
}

.ManageIndexersModalContent-rightButtons-NdpSY {
  justify-content: flex-end;
}

.ManageIndexersModalContent-deleteButton-YJFbP {

  margin-right: 10px;
}

.RootFolderRow-link-zblA4 {
}

.RootFolderRow-unavailablePath-ygS2p {
  display: flex;
  align-items: center;
}

.RootFolderRow-unavailableLabel-d_l6T {

  margin-left: 10px;
}

.RootFolderRow-freeSpace-Zzpi0,
.RootFolderRow-unmappedFolders-oPsl9 {

  width: 150px;
}

.RootFolderRow-actions-zB4PR {

  width: 45px;
}

.NamingOption-option-OKNvA {
  display: flex;
  align-items: stretch;
  flex-wrap: wrap;
  margin: 3px;
  border: 1px solid var(--borderColor);
}

  .NamingOption-option-OKNvA:hover .NamingOption-token-of4IX {
      background-color: var(--popoverTitleBackgroundInverseColor);
    }

  .NamingOption-option-OKNvA:hover .NamingOption-example-kZLgU {
      background-color: var(--popoverTitleBorderInverseColor);
    }

.NamingOption-small-vYnmm {
  width: 490px;
}

.NamingOption-large-p2cXH {
  width: 100%;
}

.NamingOption-token-of4IX {
  flex: 0 0 50%;
  padding: 6px;
  background-color: var(--popoverTitleBackgroundColor);
  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.NamingOption-example-kZLgU {
  display: flex;
  align-items: center;
  align-self: stretch;
  justify-content: space-between;
  flex: 0 0 50%;
  padding: 6px;
  background-color: var(--popoverBodyBackgroundColor);
}

.NamingOption-example-kZLgU .NamingOption-footNotes-k9vwL {
    padding: 2px;
    color: #aaa;
  }

.NamingOption-title-tq5Wz {
  text-transform: none;
}

.NamingOption-lower-HoDkb {
  text-transform: lowercase;
}

.NamingOption-upper-pA7T0 {
  text-transform: uppercase;
}

.NamingOption-isFullFilename-uqt7V .NamingOption-token-of4IX,
  .NamingOption-isFullFilename-uqt7V .NamingOption-example-kZLgU {
    flex: 1 0 auto;
  }

@media only screen and (max-width: 768px) {
  .NamingOption-option-OKNvA.NamingOption-small-vYnmm {
    width: 100%;
  }
}

@media only screen and (max-width: 480px) {
  .NamingOption-token-of4IX,
  .NamingOption-example-kZLgU {
    flex: 1 0 auto;
  }
}

.NamingModal-groups-DrUz_ {
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  margin-bottom: 20px;
}

.NamingModal-namingSelectContainer-OFvkv {
  display: flex;
  justify-content: flex-end;
}

.NamingModal-namingSelect-p7fJH {

  margin-left: 10px;
  width: 200px;
}

.NamingModal-footNote-uR3xH {
  display: flex;
  color: var(--helpTextColor);
}

.NamingModal-footNote-uR3xH .NamingModal-identifier-xO7Wj {
    margin-top: 8px;
    margin-right: 5px;
    padding: 2px;
  }

.NamingModal-footNote-uR3xH code {
    padding: 0 1px;
    border: 1px solid var(--borderColor);
    background-color: var(--modalCloseButtonHoverColor);
    color: var(--movieBackgroundColor);
  }

.Naming-namingInput-k33Yg {

  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
}

.AddRootFolder-addRootFolderButtonContainer-u8P7c {
  margin-top: 20px;
}

.AddRootFolder-importButtonIcon-jUpzw {
  margin-right: 8px;
}

.EditMetadataModalContent-message-rNLay {

  margin-bottom: 30px;
}

.Metadata-metadata-OpuUq {

  width: 290px;
}

.Metadata-name-LB94N {
  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Metadata-section-GlYvh {
  margin-top: 10px;
}

.Metadatas-metadatas-a1EOe {
  display: flex;
  flex-wrap: wrap;
}

.AddNotificationItem-notification-Zc9Sv {

  position: relative;
  width: 300px;
  height: 100px;
}

.AddNotificationItem-underlay-uEE6z {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AddNotificationItem-overlay-qT9ml {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddNotificationItem-overlay-qT9ml a,
  .AddNotificationItem-overlay-qT9ml button {
    pointer-events: all;
  }

.AddNotificationItem-overlay-qT9ml {

  padding: 10px;
}

.AddNotificationItem-name-PxZPX {
  text-align: center;
  font-weight: lighter;
  font-size: 24px;
}

.AddNotificationItem-actions-C_hYg {
  margin-top: 20px;
  text-align: right;
}

.AddNotificationItem-presetsMenu-Ytltx {

  display: inline-block;
  margin: 0 5px;
}

.AddNotificationItem-presetsMenuButton-POKVo {
}

.AddNotificationItem-presetsMenuButton-POKVo::after {
    margin-left: 5px;
    content: '\25BE';
  }

.AddNotificationModalContent-notifications-wmzKT {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
}

.NotificationEventItems-events-dl1MD {
  margin-top: 10px;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.EditNotificationModalContent-deleteButton-zgPAx {

  margin-right: auto;
}

.EditNotificationModalContent-message-TWNtp {

  margin-bottom: 30px;
}

.Notification-notification-UPK7V {

  width: 290px;
}

.Notification-name-vjjgY {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Notification-enabled-rQjVY {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.Notification-notification-UPK7V {

  width: 290px;
}

.Notification-name-vjjgY {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Notification-enabled-rQjVY {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.Notifications-notifications-nFbpD {
  display: flex;
  flex-wrap: wrap;
}

.Notifications-addNotification-MUPKM {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
}

.Notifications-center-aimuW {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.EditDelayProfileModalContent-deleteButton-IBLBk {

  margin-right: auto;
}

.DelayProfile-delayProfile-eXshH {
  display: flex;
  align-items: stretch;
  margin-bottom: 10px;
  height: 30px;
  border-bottom: 1px solid var(--borderColor);
  line-height: 30px;
}

.DelayProfile-column-QGVxD {
  flex: 0 0 200px;
}

.DelayProfile-actions-qipWX {
  display: flex;
}

.DelayProfile-dragHandle-j8RVk {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-left: auto;
  width: 40px;
  text-align: center;
  cursor: grab;
}

.DelayProfile-dragIcon-oPeXV {
  top: 0;
}

.DelayProfile-isDragging-B6sbj {
  opacity: 0.25;
}

.DelayProfile-editButton-wv0Wk {
  width: 40px;
  text-align: center;
}

.DelayProfileDragPreview-dragPreview-addkn {
  opacity: 0.75;
}

.DelayProfileDragSource-delayProfileDragSource-RZyIB {
  padding: 4px 0;
}

.DelayProfileDragSource-delayProfilePlaceholder-GSTr5 {
  width: 100%;
  height: 30px;
  border-bottom: 1px dotted #aaa;
}

.DelayProfileDragSource-delayProfilePlaceholderBefore-jVKmf {
  margin-bottom: 8px;
}

.DelayProfileDragSource-delayProfilePlaceholderAfter-q93hD {
  margin-top: 8px;
}

.DelayProfiles-horizontalScroll-CWdci {
  overflow-x: auto;
}

.DelayProfiles-delayProfiles-hoyqr {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.DelayProfiles-delayProfilesHeader-yAz4j {
  display: flex;
  margin-bottom: 10px;
  font-weight: bold;
}

.DelayProfiles-column-Ycnjz {
  flex: 0 0 200px;
}

.DelayProfiles-tags-ipx5u {
  flex: 1 0 auto;
}

.DelayProfiles-addDelayProfile-_z7mB {
  display: flex;
  justify-content: flex-end;
}

.DelayProfiles-addButton-iFXnd {
  width: 40px;
  text-align: center;
}

@media only screen and (max-width: 768px) {
  .DelayProfiles-horizontalScroll-CWdci {
    overflow-y: hidden;
    width: 100%;
  }
}

.QualityProfileFormatItem-qualityProfileFormatItemContainer-sSQHW {
  display: flex;
  padding: 4px 0;
  width: 100%;
}

.QualityProfileFormatItem-qualityProfileFormatItem-yrgJj {
  display: flex;
  align-items: stretch;
  width: 100%;
  border: 1px solid #aaa;
  border-radius: 4px;
  background: var(--modalBackgroundColor);
}

.QualityProfileFormatItem-formatNameContainer-sDM7L {
  display: flex;
  flex-grow: 1;
  margin-bottom: 0;
  margin-left: 14px;
  width: 100%;
  font-weight: normal;
  line-height: 30px;
  cursor: text;
}

.QualityProfileFormatItem-formatName-F9UbI {
  display: flex;
  flex-grow: 1;
}

.QualityProfileFormatItem-scoreContainer-lLqJR {
  display: flex;
  flex-grow: 0;
}

.QualityProfileFormatItem-scoreInput-awUEJ {

  width: 100px;
  height: 30px;
  border: unset;
  border-radius: unset;
  background-color: unset;
}

.QualityProfileFormatItems-formats-lyjb9 {
  margin-top: 10px;
  /* TODO: This should consider the number of languages in the list */
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.QualityProfileFormatItems-headerContainer-BuDwk {
  display: flex;
  font-weight: bold;
  line-height: 35px;
}

.QualityProfileFormatItems-headerTitle-zrt2s {
  display: flex;
  flex-grow: 1;
}

.QualityProfileFormatItems-headerScore-rwvsN {
  display: flex;
  flex-grow: 0;
  padding-left: 16px;
  width: 100px;
}

.QualityProfileFormatItems-addCustomFormatMessage-Y8Tof {
  max-width: 550px;
  color: var(--helpTextColor);
  text-align: center;
  font-weight: 300;
  font-size: 20px;
}

.QualityProfileItem-qualityProfileItem-TEAK6 {
  display: flex;
  align-items: stretch;
  width: 100%;
  border: 1px solid #aaa;
  border-radius: 4px;
  background: var(--inputBackgroundColor);
}

  .QualityProfileItem-qualityProfileItem-TEAK6.QualityProfileItem-isInGroup-v0tnK {
    border-style: dashed;
  }

.QualityProfileItem-checkInputContainer-XOmYl {
  position: relative;
  margin-right: 4px;
  margin-bottom: 5px;
  margin-left: 8px;
}

.QualityProfileItem-checkInput-NtKME {

  margin-top: 5px;
}

.QualityProfileItem-qualityNameContainer-ws1Xl {
  display: flex;
  flex-grow: 1;
  margin-bottom: 0;
  margin-left: 2px;
  font-weight: normal;
  line-height: 30px;
  cursor: pointer;
}

.QualityProfileItem-qualityName-UDxBT.QualityProfileItem-isInGroup-v0tnK {
    margin-left: 14px;
  }

.QualityProfileItem-qualityName-UDxBT.QualityProfileItem-notAllowed-KHOV9 {
    color: #c6c6c6;
  }

.QualityProfileItem-createGroupButton-NYwja {

  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-right: 5px;
  margin-left: 8px;
  width: 20px;
}

.QualityProfileItem-dragHandle-fkDC9 {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-left: auto;
  width: 40px;
  text-align: center;
  cursor: grab;
}

.QualityProfileItem-dragIcon-G0p9C {
  top: 0;
}

.QualityProfileItem-isDragging-NU2zj {
  opacity: 0.25;
}

.QualityProfileItem-isPreview-L8xaf .QualityProfileItem-qualityName-UDxBT {
    margin-left: 14px;
  }

.QualityProfileItem-isPreview-L8xaf .QualityProfileItem-qualityName-UDxBT.QualityProfileItem-isInGroup-v0tnK {
      margin-left: 28px;
    }

.QualityProfileItemDragPreview-dragPreview-NbgaE {
  width: 380px;
  opacity: 0.75;
}

.QualityProfileItem-qualityProfileItem-TEAK6 {
  display: flex;
  align-items: stretch;
  width: 100%;
  border: 1px solid #aaa;
  border-radius: 4px;
  background: var(--inputBackgroundColor);
}

  .QualityProfileItem-qualityProfileItem-TEAK6.QualityProfileItem-isInGroup-v0tnK {
    border-style: dashed;
  }

.QualityProfileItem-checkInputContainer-XOmYl {
  position: relative;
  margin-right: 4px;
  margin-bottom: 5px;
  margin-left: 8px;
}

.QualityProfileItem-checkInput-NtKME {

  margin-top: 5px;
}

.QualityProfileItem-qualityNameContainer-ws1Xl {
  display: flex;
  flex-grow: 1;
  margin-bottom: 0;
  margin-left: 2px;
  font-weight: normal;
  line-height: 30px;
  cursor: pointer;
}

.QualityProfileItem-qualityName-UDxBT.QualityProfileItem-isInGroup-v0tnK {
    margin-left: 14px;
  }

.QualityProfileItem-qualityName-UDxBT.QualityProfileItem-notAllowed-KHOV9 {
    color: #c6c6c6;
  }

.QualityProfileItem-createGroupButton-NYwja {

  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-right: 5px;
  margin-left: 8px;
  width: 20px;
}

.QualityProfileItem-dragHandle-fkDC9 {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-left: auto;
  width: 40px;
  text-align: center;
  cursor: grab;
}

.QualityProfileItem-dragIcon-G0p9C {
  top: 0;
}

.QualityProfileItem-isDragging-NU2zj {
  opacity: 0.25;
}

.QualityProfileItem-isPreview-L8xaf .QualityProfileItem-qualityName-UDxBT {
    margin-left: 14px;
  }

.QualityProfileItem-isPreview-L8xaf .QualityProfileItem-qualityName-UDxBT.QualityProfileItem-isInGroup-v0tnK {
      margin-left: 28px;
    }

.QualityProfileItemGroup-qualityProfileItemGroup-uZqur {
  width: 100%;
  border: 1px solid #aaa;
  border-radius: 4px;
  background: var(--inputBackgroundColor);
}

  .QualityProfileItemGroup-qualityProfileItemGroup-uZqur.QualityProfileItemGroup-editGroups-jmmBq {
    background: var(--inputBackgroundColor);
  }

.QualityProfileItemGroup-qualityProfileItemGroupInfo-Kou2X {
  display: flex;
  align-items: stretch;
  width: 100%;
}

.QualityProfileItemGroup-checkInputContainer-XDuB_ {

  display: flex;
  align-items: center;
}

.QualityProfileItemGroup-checkInput-bCDDy {
}

.QualityProfileItemGroup-nameInput-WZ6mI {

  margin-top: 4px;
  margin-right: 10px;
}

.QualityProfileItemGroup-nameContainer-WXC2r {
  display: flex;
  align-items: center;
  flex-grow: 1;
}

.QualityProfileItemGroup-name-mH2mG {
  flex-shrink: 0;
}

.QualityProfileItemGroup-name-mH2mG.QualityProfileItemGroup-notAllowed-ESbqc {
    color: #c6c6c6;
  }

.QualityProfileItemGroup-groupQualities-ANIg_ {
  display: flex;
  justify-content: flex-end;
  flex-grow: 1;
  flex-wrap: wrap;
  margin: 2px 0 2px 10px;
}

.QualityProfileItemGroup-qualityNameContainer-lwJWU {
  display: flex;
  align-items: stretch;
  flex-grow: 1;
  margin-bottom: 0;
  margin-left: 2px;
  font-weight: normal;
}

.QualityProfileItemGroup-qualityNameLabel-nMell {

  cursor: pointer;
}

.QualityProfileItemGroup-deleteGroupButton-p85Qd {

  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-right: 5px;
  margin-left: 8px;
  width: 20px;
}

.QualityProfileItemGroup-dragHandle-NSzyO {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  margin-left: auto;
  width: 40px;
  text-align: center;
  cursor: grab;
}

.QualityProfileItemGroup-dragIcon-rmBVO {
  top: 0;
}

.QualityProfileItemGroup-isDragging-JtSGM {
  opacity: 0.25;
}

.QualityProfileItemGroup-items-B4dxR {
  margin: 0 50px 0 35px;
}

.QualityProfileItemDragSource-qualityProfileItemDragSource-NwZEi {
  padding: 4px 0;
}

.QualityProfileItemDragSource-qualityProfileItemPlaceholder-ORYGX {
  width: 100%;
  height: 30px;
  border: 1px dotted #aaa;
  border-radius: 4px;
}

.QualityProfileItemDragSource-qualityProfileItemPlaceholderBefore-BWGOW {
  margin-bottom: 8px;
}

.QualityProfileItemDragSource-qualityProfileItemPlaceholderAfter-oWcx8 {
  margin-top: 8px;
}

.QualityProfileItems-editGroupsButton-d3Isx {

  margin-top: 10px;
}

.QualityProfileItems-editGroupsButtonIcon-JdP1h {
  margin-right: 8px;
}

.QualityProfileItems-qualities-EdMt0 {
  margin-top: 10px;
  transition: min-height 200ms;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.EditQualityProfileModalContent-formGroupsContainer-hjomj {
  display: flex;
  flex-wrap: wrap;
}

.EditQualityProfileModalContent-formGroupWrapper-RN2SQ,
.EditQualityProfileModalContent-formatItemLarge-gnp2n {
  flex: 0 0 calc(650px - 100px);
}

.EditQualityProfileModalContent-deleteButtonContainer-SvWk_ {
  margin-right: auto;
}

.EditQualityProfileModalContent-formatItemSmall-MG3__ {
  display: none;
}

@media only screen and (max-width: calc(1200px + 100px)) {
  .EditQualityProfileModalContent-formGroupsContainer-hjomj {
    display: block;
  }

  .EditQualityProfileModalContent-formatItemSmall-MG3__ {
    display: block;
  }

  .EditQualityProfileModalContent-formatItemLarge-gnp2n {
    display: none;
  }
}

.QualityProfile-qualityProfile-jkXPx {

  width: 300px;
}

.QualityProfile-nameContainer-pK4Yv {
  display: flex;
  justify-content: space-between;
}

.QualityProfile-name-jAtfw {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.QualityProfile-cloneButton-Y4jVX {

  height: 36px;
}

.QualityProfile-qualities-XTEvs {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.QualityProfile-tooltipLabel-jEOdt {

  margin: 0;
  border: none;
}

.QualityProfile-qualityProfile-jkXPx {

  width: 300px;
}

.QualityProfile-nameContainer-pK4Yv {
  display: flex;
  justify-content: space-between;
}

.QualityProfile-name-jAtfw {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.QualityProfile-cloneButton-Y4jVX {

  height: 36px;
}

.QualityProfile-qualities-XTEvs {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.QualityProfile-tooltipLabel-jEOdt {

  margin: 0;
  border: none;
}

.QualityProfiles-qualityProfiles-Npuli {
  display: flex;
  flex-wrap: wrap;
}

.QualityProfiles-addQualityProfile-L9M_D {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
  font-size: 45px;
}

.QualityProfiles-center-_sP2Z {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.EditReleaseProfileModalContent-deleteButton-tiNge {

  margin-right: auto;
}

.EditReleaseProfileModalContent-tagInternalInput-oAV2V {

  flex: 0 0 100%;
}


.ReleaseProfileItem-releaseProfile-fRe2I {

  width: 290px;
}

.ReleaseProfileItem-enabled-We3KE {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.ReleaseProfileItem-name-pEIVV {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.ReleaseProfileItem-label-ayfSY {

  max-width: 100%;
}

.ReleaseProfileItem-releaseProfile-fRe2I {

  width: 290px;
}

.ReleaseProfileItem-enabled-We3KE {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
}

.ReleaseProfileItem-name-pEIVV {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.ReleaseProfileItem-label-ayfSY {

  max-width: 100%;
}

.ReleaseProfiles-releaseProfiles-kkFx2 {
  display: flex;
  flex-wrap: wrap;
}

.ReleaseProfiles-addReleaseProfile-Cxevu {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
}

.ReleaseProfiles-center-ubhNh {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.QualityDefinition-qualityDefinition-EV5u_ {
  display: flex;
  align-content: stretch;
  margin: 5px 0;
  padding-top: 5px;
  height: 45px;
  border-top: 1px solid var(--borderColor);
}

.QualityDefinition-quality-crm2x,
.QualityDefinition-title-ZZZOU {
  flex: 0 1 250px;
  padding-right: 20px;
  line-height: 40px;
}

.QualityDefinition-sizeLimit-Wkn6n {
  flex: 0 1 500px;
  padding-right: 30px;
}

.QualityDefinition-slider-i9tTc {
  width: 100%;
  height: 20px;
}

.QualityDefinition-track-zCjk9 {
  top: 9px;
  margin: 0 5px;
  height: 3px;
  background-color: var(--sliderAccentColor);
  box-shadow: 0 0 0 #000;
}

.QualityDefinition-track-zCjk9:nth-child(3n + 1) {
    background-color: #ddd;
  }

.QualityDefinition-thumb-Buzo8 {
  top: 1px;
  z-index: 0 !important;
  width: 18px;
  height: 18px;
  border: 3px solid var(--sliderAccentColor);
  border-radius: 50%;
  background-color: var(--white);
  text-align: center;
  cursor: pointer;
}

.QualityDefinition-sizes-McnDO {
  display: flex;
  justify-content: space-between;
}

.QualityDefinition-megabytesPerMinute-thTbm {
  display: flex;
  justify-content: space-between;
  flex: 0 0 400px;
}

.QualityDefinition-sizeInput-_Ky1y {

  display: inline-block;
  margin-left: 5px;
  padding: 6px;
  width: 75px;
}

@media only screen and (max-width: 768px) {
  .QualityDefinition-qualityDefinition-EV5u_ {
    flex-wrap: wrap;
    height: auto;
  }

    .QualityDefinition-qualityDefinition-EV5u_:first-child {
      border-top: none;
    }

  .QualityDefinition-qualityDefinition-EV5u_:first-child {
    border-top: none;
  }

  .QualityDefinition-quality-crm2x {
    font-weight: bold;
    line-height: inherit;
  }

  .QualityDefinition-sizeLimit-Wkn6n {
    margin-top: 10px;
  }
}

.QualityDefinitions-header-zPMYR {
  display: flex;
  font-weight: bold;
}

.QualityDefinitions-quality-YI2P0,
.QualityDefinitions-title-Xzibg {
  flex: 0 1 250px;
}

.QualityDefinitions-sizeLimit-MyefH {
  flex: 0 1 500px;
}

.QualityDefinitions-megabytesPerMinute-a9_A5 {
  flex: 0 0 250px;
}

.QualityDefinitions-sizeLimitHelpTextContainer-GMjYa {
  display: flex;
  justify-content: flex-end;
  margin-top: 20px;
  max-width: 1000px;
}

.QualityDefinitions-sizeLimitHelpText-yMOuO {
  max-width: 500px;
  color: var(--helpTextColor);
}

@media only screen and (max-width: 768px) {
  .QualityDefinitions-header-zPMYR {
    display: none;
  }
    .QualityDefinitions-definitions-acRUM:first-child {
      border-top: none;
    }
}

.ResetQualityDefinitionsModalContent-messageContainer-4w7E0 {
  margin-bottom: 20px;
}

.Settings-link-errh1 {

  border-bottom: 1px solid #e5e5e5;
  color: var(--textColor);
  font-size: 21px;
}

  .Settings-link-errh1:hover {
    color: #616573;
    text-decoration: none;
  }

.Settings-summary-eUl9k {
  margin-top: 10px;
  margin-bottom: 30px;
  color: var(--helpTextColor);
}

.AddSpecificationItem-specification-NieD2 {

  position: relative;
  width: 300px;
  height: 100px;
}

.AddSpecificationItem-underlay-RIODZ {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
}

.AddSpecificationItem-overlay-ag9EZ {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.AddSpecificationItem-overlay-ag9EZ a,
  .AddSpecificationItem-overlay-ag9EZ button {
    pointer-events: all;
  }

.AddSpecificationItem-overlay-ag9EZ {

  padding: 10px;
}

.AddSpecificationItem-name-hPY01 {
  text-align: center;
  font-weight: lighter;
  font-size: 24px;
}

.AddSpecificationItem-actions-UG_vZ {
  margin-top: 20px;
  text-align: right;
}

.AddSpecificationItem-presetsMenu-Xl4AW {

  display: inline-block;
  margin: 0 5px;
}

.AddSpecificationItem-presetsMenuButton-ZVH9g {
}

.AddSpecificationItem-presetsMenuButton-ZVH9g::after {
    margin-left: 5px;
    content: '\25BE';
  }

.AddSpecificationModalContent-specifications-c_llu {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
}

.EditSpecificationModalContent-deleteButton-dR0rN {

  margin-right: auto;
}

.Specification-autoTagging-eWXw_ {

  width: 300px;
}

.Specification-nameContainer-nI8Ky {
  display: flex;
  justify-content: space-between;
}

.Specification-name-DJkOw {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.Specification-cloneButton-NjYsY {

  height: 36px;
}

.Specification-labels-hsKc3 {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.Specification-tooltipLabel-bhJXn {

  margin: 0;
  border: none;
}

.AutoTagging-autoTagging-vkEJc {

  width: 300px;
}

.AutoTagging-nameContainer-b06qv {
  display: flex;
  justify-content: space-between;
}

.AutoTagging-name-siJT3 {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.AutoTagging-cloneButton-zxltW {

  height: 36px;
}

.AutoTagging-formats-Q02RV {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.AutoTagging-tooltipLabel-lyXVZ {

  margin: 0;
  border: none;
}

.EditAutoTaggingModalContent-deleteButton-IqN1V {

  margin-right: auto;
}

.EditAutoTaggingModalContent-rightButtons-FQU6u {
  justify-content: flex-end;
  margin-right: auto;
}

.EditAutoTaggingModalContent-addSpecification-FAAat {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
  font-size: 45px;
}

.EditAutoTaggingModalContent-center-x4Ueu {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.EditAutoTaggingModalContent-autoTaggings-biKav {
  display: flex;
  flex-wrap: wrap;
}

.AutoTagging-autoTagging-vkEJc {

  width: 300px;
}

.AutoTagging-nameContainer-b06qv {
  display: flex;
  justify-content: space-between;
}

.AutoTagging-name-siJT3 {
  overflow: hidden !important;
  max-width: 100%;
  /* 1 */
  text-overflow: ellipsis !important;
  white-space: nowrap !important;

  margin-bottom: 20px;
  font-weight: 300;
  font-size: 24px;
}

.AutoTagging-cloneButton-zxltW {

  height: 36px;
}

.AutoTagging-formats-Q02RV {
  display: flex;
  flex-wrap: wrap;
  margin-top: 5px;
  pointer-events: all;
}

.AutoTagging-tooltipLabel-lyXVZ {

  margin: 0;
  border: none;
}

.AutoTaggings-autoTaggings-l32Gg {
  display: flex;
  flex-wrap: wrap;
}

.AutoTaggings-addAutoTagging-CgYiY {

  background-color: var(--cardAlternateBackgroundColor);
  color: var(--gray);
  text-align: center;
  font-size: 45px;
}

.AutoTaggings-center-xDaiv {
  display: inline-block;
  padding: 5px 20px 0;
  border: 1px solid var(--borderColor);
  border-radius: 4px;
  background-color: var(--cardCenterBackgroundColor);
}

.TagDetailsModalContent-items-B5hu6 {
  display: flex;
  flex-wrap: wrap;
}

.TagDetailsModalContent-item-kiFnZ {
  flex: 0 0 100%;
}

.TagDetailsModalContent-restriction-hY7YJ {
  margin-bottom: 5px;
  padding-bottom: 5px;
  border-bottom: 1px solid var(--borderColor);
}

.TagDetailsModalContent-restriction-hY7YJ:last-child {
    margin: 0;
    padding: 0;
    border-bottom: none;
  }

.TagDetailsModalContent-deleteButton-Zhy3Y {

  margin-right: auto;
}

.Tag-tag-B2rUn {

  flex: 150px 0 1;
}

.Tag-label-jmGXS {
  margin-bottom: 20px;
  white-space: nowrap;
  font-weight: 300;
  font-size: 24px;
}

.Tags-tags-MyS6m {
  display: flex;
  flex-wrap: wrap;
}

.RestoreBackupModalContent-additionalInfo-Xoijl {
  flex-grow: 1;
  color: #777;
}

.RestoreBackupModalContent-steps-cQe_F {
  margin-top: 20px;
}

.RestoreBackupModalContent-step-ydzZd {
  display: flex;
  font-size: 16px;
  line-height: 20px;
}

.RestoreBackupModalContent-stepState-n5Yp1 {
  margin-right: 8px;
}

@media only screen and (max-width: 768px) {
  composes: ModalFooter-modalFooter-wjkx5;

  flex-wrap: wrap;
}

.BackupRow-type-cEm0B {

  width: 20px;
  text-align: center;
}

.BackupRow-actions-jEOfc {

  width: 70px;
}

.LogsTableDetailsModal-detailsText-qjU64 {

  display: block;
  margin: 0 0 10.5px;
  padding: 10px;
  border: 1px solid #ccc;
  border-radius: 4px;
  background-color: var(--logEventsBackgroundColor);
  color: var(--textColor);
  white-space: pre;
  word-wrap: break-word;
  word-break: break-all;
  font-size: 13px;
  font-family: "Ubuntu Mono", Menlo, Monaco, Consolas, "Courier New", monospace;;
  line-height: 1.52857143;
}

.LogsTableRow-level-nTilo {

  width: 20px;
}

.LogsTableRow-info-ZdpwB {
  color: #1e90ff;
}

.LogsTableRow-debug-tF08B {
  color: #808080;
}

.LogsTableRow-trace-nN2fD {
  color: #d3d3d3;
}

.LogsTableRow-warn-Gc7Iz {
  color: var(--warningColor);
}

.LogsTableRow-error-qpcON {
  color: var(--dangerColor);
}

.LogsTableRow-fatal-SMfsG {
  color: var(--purple);
}

.LogsTableRow-actions-yQCnd {

  width: 45px;
}

.LogFilesTableRow-download-aHq_I {

  width: 100px;
}

.DescriptionList-descriptionList-o7bt3 {
  margin-top: 0;
  margin-bottom: 0;
}

.About-descriptionList-Ubr6l {

  margin-bottom: 10px;
}

.DiskSpace-space-Pgv0A {

  width: 150px;
}

.styles-logo-WwFI0 {
  margin: auto;
  padding: 9px;
}

.styles-logoContainer-VtmaF {
  display: inline-block;
  margin: 0.5em;
  width: 50px;
  height: 50px;
  outline: none;
  border: solid 1px #e6e6e6;
  border-radius: 0.5em;
  background: #f8f8ff;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
  cursor: pointer;
}

.Health-legend-aUEiW {
  display: flex;
  justify-content: space-between;
}

.Health-loading-qxbW3 {

  margin-top: 2px;
  margin-left: 10px;
  text-align: left;
}

.Health-status-QbfEq {
  width: 20px;
}

.Health-healthOk-mf6pA {
  margin-bottom: 25px;
}

.Health-actions-BR6oB {

  min-width: 90px;
}

.QueuedTaskRowNameCell-commandName-wXKoI {
  display: inline-block;
  min-width: 220px;
}

.QueuedTaskRowNameCell-userAgent-EbkpU {
  color: #b0b0b0;
}

.QueuedTaskRow-trigger-TgEBj {

  width: 50px;
}

.QueuedTaskRow-triggerContent-IhBio {
  display: flex;
  justify-content: space-between;
  width: 100%;
}

.QueuedTaskRow-queued-MHcI5,
.QueuedTaskRow-started-oukkt,
.QueuedTaskRow-ended-TBdCJ {

  width: 180px;
}

.QueuedTaskRow-duration-EJQc1 {

  width: 100px;
}

.QueuedTaskRow-actions-QYryf {

  width: 60px;
}

.ScheduledTaskRow-interval-pe_BC {

  width: 150px;
}

.ScheduledTaskRow-lastExecution-Xf4fD,
.ScheduledTaskRow-lastDuration-MKdDv,
.ScheduledTaskRow-nextExecution-dSCD3 {

  width: 180px;
}

.ScheduledTaskRow-actions-t2m8V {

  width: 20px;
}

.Updates-messageContainer-nvvHm {
  display: flex;
  margin-bottom: 20px;
}

.Updates-upToDateIcon-jwFdy {
  color: #37bc9b;
  font-size: 30px;
}

.Updates-message-zg2_G {
  padding-left: 5px;
  font-size: 18px;
  line-height: 30px;
}

.Updates-loading-bdWcM {

  margin-top: 5px;
  margin-left: auto;
}

.Updates-update-m07_m {
  margin-top: 20px;
}

.Updates-info-KSvcv {
  display: flex;
  align-items: center;
  margin-bottom: 10px;
  padding-bottom: 5px;
  border-bottom: 1px solid #e5e5e5;
}

.Updates-version-RDMv4 {
  font-size: 21px;
}

.Updates-space-lc7tw {
  padding: 0 5px;
}

.Updates-date-NpIbP {
  font-size: 16px;
}

.Updates-label-hat6K {

  margin-left: 10px;
  font-size: 14px;
}

.MovieSearchCell-movieSearchCell-fCkew {

  width: 70px;
  white-space: nowrap;
}

.MovieStatus-center-gvFw4 {
  display: flex;
  justify-content: center;
}

.CutoffUnmetRow-languages-GJLvA,
.CutoffUnmetRow-status-gMMPe {

  width: 100px;
}

.MissingRow-status-okItJ {

  width: 100px;
}


/*# sourceMappingURL=527-95b2ed23a28278037b1d.css.map*/